@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,11 +30,11 @@ int main(int argc, char **argv)
 		QTranslator translator;
 
 		//Loads the ui translation for crashhandler
-		translator.load(QLocale::system().name(), GlobalAttributes::LANGUAGES_DIR);
+		translator.load(QLocale::system().name(), GlobalAttributes::LanguagesDir);
 		app.installTranslator(&translator);
 
-		CrashHandlerForm crashhandler(args.size() > 1 && args[1]==CrashHandlerForm::ANALYSIS_MODE);
-		PgModelerUiNS::resizeDialog(&crashhandler);
+		CrashHandlerForm crashhandler(args.size() > 1 && args[1]==CrashHandlerForm::AnalysisMode);
+		PgModelerUiNs::resizeDialog(&crashhandler);
 		crashhandler.show();
 		app.exec();
 
@@ -44,6 +44,6 @@ int main(int argc, char **argv)
 	{
 		QTextStream out(stdout);
 		out << e.getExceptionsText();
-		return(e.getErrorType());
+		return(enum_cast(e.getErrorCode()));
 	}
 }
