@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include "baserelationship.h"
 #include "xmlparser.h"
 #include "roundedrectitem.h"
+#include "textpolygonitem.h"
 
 class BaseObjectView: public QObject, public QGraphicsItemGroup {
 	private:
@@ -46,6 +47,11 @@ class BaseObjectView: public QObject, public QGraphicsItemGroup {
 		 is incremented each time an object is selected. */
 		static unsigned global_sel_order;
 
+		/*! \brief Stores the current status for object's compact view display.
+		 * In compact view the alias of object's are shown instead of name. Also, data types and constraint types are hidden,
+		 * as well the table's extended area is collapsed by default */
+		static bool compact_view;
+
 		/*! \brief Stores the selection order of the current object. This attribute is used to
 		 know when an item was selected before another in the scene because the implementation of
 		 the method QGraphicsScene :: selectedItem() the selected objects are returned without
@@ -53,11 +59,8 @@ class BaseObjectView: public QObject, public QGraphicsItemGroup {
 		 mainly when creating relationships between tables. */
 		unsigned sel_order;
 
-		//! \brief Graphical text for the position info
-		QGraphicsSimpleTextItem *pos_info_txt;
-
-		//! \brief Graphical object (rectangle) of the position info
-		QGraphicsRectItem *pos_info_rect;
+		//! \brief This item display the current object position on the scene
+		TextPolygonItem *pos_info_item;
 
 		//! \brief Stores the objects bounding rect
 		QRectF bounding_rect;
@@ -80,17 +83,17 @@ class BaseObjectView: public QObject, public QGraphicsItemGroup {
 		//! \brief Graphical text for the sql disabled info
 		QGraphicsSimpleTextItem *sql_disabled_txt;
 
+		//! \brief This items is used to display the sql disabled status of the object
+		TextPolygonItem *sql_disabled_item;
+
 		//! \brief Stores the object font configuration
 		static map<QString, QTextCharFormat> font_config;
 
 		//! \brief Stores the object colors configuration
 		static map<QString, vector<QColor>> color_config;
 
-		//! \brief Resizes to the specified dimension the passed polygon
-		void resizePolygon(QPolygonF &pol, double width, double height);
-
 		//! \brief Configures the objects shadow polygon
-		void configureObjectShadow(void);
+		void configureObjectShadow(void) {}
 
 		//! \brief Configures the object selection polygon
 		void configureObjectSelection(void);
@@ -110,13 +113,16 @@ class BaseObjectView: public QObject, public QGraphicsItemGroup {
 
 		void setSelectionOrder(bool selected);
 
-	public:
-		static constexpr double VERT_SPACING=2.0f,
-		HORIZ_SPACING=2.0f,
-		DEFAULT_FONT_SIZE=9.0f,
-		OBJ_BORDER_WIDTH=0.85f;
+		//! \brief Defines in which layer the object is visible
+		void setLayer(unsigned layer);
 
-		static constexpr int OBJ_ALPHA_CHANNEL=128;
+	public:
+		static constexpr double VertSpacing=2.0,
+		HorizSpacing=2.0,
+		DefaultFontSize=9.0,
+		ObjectBorderWidth=0.85;
+
+		static constexpr int ObjectAlphaChannel=128;
 
 		BaseObjectView(BaseObject *object=nullptr);
 		virtual ~BaseObjectView(void);
@@ -128,7 +134,7 @@ class BaseObjectView: public QObject, public QGraphicsItemGroup {
 		QVariant itemChange(GraphicsItemChange change, const QVariant &value);
 
 		//! \brief Returns the object that is representend by the graphical object
-		BaseObject *getSourceObject(void);
+		BaseObject *getUnderlyingObject(void);
 
 		//! \brief Loads the font / color styels for the objects from a XML configuration file
 		static void loadObjectsStyle(void);
@@ -153,6 +159,10 @@ class BaseObjectView: public QObject, public QGraphicsItemGroup {
 
 		static bool isPlaceholderEnabled(void);
 
+		static void setCompactViewEnabled(bool value);
+
+		static bool isCompactViewEnabled(void);
+
 		//! \brief Sets the  font style for the specified element id
 		static void setFontStyle(const QString &id, QTextCharFormat font_fmt);
 
@@ -183,6 +193,9 @@ class BaseObjectView: public QObject, public QGraphicsItemGroup {
 		//! \brief Returns the current factor between the default font size and the current defined one
 		static double getFontFactor(void);
 
+		//! \brief Returns the layer in which the object is visible
+		unsigned getLayer(void);
+
 	protected slots:
 		//! \brief Make the basic object operations
 		void __configureObject(void);
@@ -196,6 +209,8 @@ class BaseObjectView: public QObject, public QGraphicsItemGroup {
 
 		//! \brief Signal emmited whenever the width or height of the table changes
 		void s_objectDimensionChanged(void);
+
+	friend class ObjectsScene;
 };
 
 #endif
