@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 #ifndef TABLE_VIEW_H
 #define TABLE_VIEW_H
 
-#include "table.h"
+#include "physicaltable.h"
 #include "basetableview.h"
 #include "tabletitleview.h"
 #include "tableobjectview.h"
@@ -37,7 +37,7 @@ class TableView: public BaseTableView {
 		map<TableObject *, vector<QPointF>> conn_points;
 
 	public:
-		TableView(Table *table);
+		TableView(PhysicalTable *table);
 		QPointF getConnectionPoints(TableObject *tab_obj, unsigned pnt_type);
 
 	private slots:
