@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,5 +28,5 @@ to store objects attributes and used by SchemaParser, XMLParser and several othe
 
 #include <map>
 #include <QString>
-typedef std::map<QString, QString> attribs_map;
+using attribs_map = std::map<QString, QString>;
 #endif
