@@ -1,6 +1,6 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 #ifndef BASE_OBJECT_H
 #define BASE_OBJECT_H
 
-#include "parsersattributes.h"
+#include "attributes.h"
 #include "exception.h"
 #include "pgsqltypes.h"
 #include "schemaparser.h"
@@ -34,44 +34,49 @@
 #include <QRegExp>
 #include <QStringList>
 #include <QTextStream>
+#include <type_traits>
 
-enum ObjectType {
-	OBJ_COLUMN,
-	OBJ_CONSTRAINT,
-	OBJ_FUNCTION,
-	OBJ_TRIGGER,
-	OBJ_INDEX,
-	OBJ_RULE,
-	OBJ_TABLE,
-	OBJ_VIEW,
-	OBJ_DOMAIN,
-	OBJ_SCHEMA,
-	OBJ_AGGREGATE,
-	OBJ_OPERATOR,
-	OBJ_SEQUENCE,
-	OBJ_ROLE,
-	OBJ_CONVERSION,
-	OBJ_CAST,
-	OBJ_LANGUAGE,
-	OBJ_TYPE,
-	OBJ_TABLESPACE,
-	OBJ_OPFAMILY,
-	OBJ_OPCLASS,
-	OBJ_DATABASE,
-	OBJ_COLLATION,
-	OBJ_EXTENSION,
-	OBJ_EVENT_TRIGGER,
-	OBJ_POLICY,
-	OBJ_RELATIONSHIP,
-	OBJ_TEXTBOX,
-	OBJ_PERMISSION,
-	OBJ_PARAMETER,
-	OBJ_TYPE_ATTRIBUTE,
-	OBJ_TAG,
-	OBJ_GENERIC_SQL,
-	BASE_RELATIONSHIP,
-	BASE_OBJECT,
-	BASE_TABLE
+enum class ObjectType: unsigned {
+	Column,
+	Constraint,
+	Function,
+	Trigger,
+	Index,
+	Rule,
+	Table,
+	View,
+	Domain,
+	Schema,
+	Aggregate,
+	Operator,
+	Sequence,
+	Role,
+	Conversion,
+	Cast,
+	Language,
+	Type,
+	Tablespace,
+	OpFamily,
+	OpClass,
+	Database,
+	Collation,
+	Extension,
+	EventTrigger,
+	Policy,
+	ForeignDataWrapper,
+	ForeignServer,
+	ForeignTable,
+	UserMapping,
+	Relationship,
+	Textbox,
+	Permission,
+	Parameter,
+	TypeAttribute,
+	Tag,
+	GenericSql,
+	BaseRelationship,
+	BaseObject,
+	BaseTable
 };
 
 class BaseObject {
@@ -82,12 +87,14 @@ class BaseObject {
 		//! \brief Indicates the the cached code enabled
 		static bool use_cached_code;
 
-		//! \brief Stores the database wich the object belongs
-		BaseObject *database;
+		static bool escape_comments;
 
 		//! \brief Stores the set of special (valid) chars that forces the object's name quoting
 		static const QByteArray special_chars;
 
+		//! \brief Stores the database wich the object belongs
+		BaseObject *database;
+
 	protected:
 		SchemaParser schparser;
 
@@ -105,7 +112,7 @@ class BaseObject {
 		unsigned object_id;
 
 		//! \brief Objects type count declared on enum ObjectType
-		static const int OBJECT_TYPE_COUNT=37;
+		static constexpr unsigned ObjectTypeCount=enum_cast(ObjectType::BaseTable) + 1;
 
 		/*! \brief Indicates whether the object is protected or not.
 		 A protected object indicates that it can not suffer changes in position
@@ -131,20 +138,21 @@ class BaseObject {
 
 		//! \brief Stores the cached xml and sql code
 		QString cached_code[2],
+
 		//! \brief Stores the xml code in reduced form
 		cached_reduced_code;
 
 		/*! \brief This map stores the name of each object type associated to a schema file
 		 that generates the object's code definition */
-		static QString objs_schemas[OBJECT_TYPE_COUNT];
+		static const QString objs_schemas[ObjectTypeCount];
 
 		/*! \brief This map associates the object type to a keyword on
 		 SQL language that represents the object */
-		static QString objs_sql[OBJECT_TYPE_COUNT];
+		static const QString objs_sql[ObjectTypeCount];
 
 		/*! \brief Stores the name of the type of objects to be used in error messages formatting
 		 and others operations that envolves object type name */
-		static QString obj_type_names[OBJECT_TYPE_COUNT];
+		static const QString obj_type_names[ObjectTypeCount];
 
 		/*! \brief Role that is owner of the object. Some objects cannot be associated to a role
 		 so if one is assigned to the object an error will be raised */
@@ -164,22 +172,29 @@ class BaseObject {
 
 		//! \brief Comments related to object
 		QString comment,
+
 		//! \brief Object's name (in PostgreSQL accepted format)
 		obj_name,
 
+		//! \brief Object's alias (human readable / friendly) name
+		alias,
+
 		//! \brief The set of SQL commands appended on the objectc's definition
 		appended_sql,
 
 		//! \brief The set of SQL commands prepended on the objectc's definition
 		prepended_sql;
 
-
 		/*! \brief Stores the attributes and their values ​​shaped in strings to be used
 		 by SchemaParser on the object's code definition creation. The attribute
 		 name related to model objects are defined in ParsersAttributes namespace. */
-		attribs_map attributes;
+		attribs_map attributes,
 
-		/*! \brief Type of object, may have one of the values ​​of the enum ObjectType OBJ_*
+		/*! \brief Stores the attributes and their vales which can be used by the
+		 * searching mechanism to match patters */
+		search_attribs;
+
+		/*! \brief Type of object, may have one of the values ​​of the enum ObjectType
 		 It was used a numeric type to avoid the use excessive of RTTI. */
 		ObjectType obj_type;
 
@@ -224,9 +239,16 @@ class BaseObject {
 
 		static QString getAlterDefinition(QString sch_name, attribs_map &attribs, bool ignore_ukn_attribs=false, bool ignore_empty_attribs=false);
 
+		QString getAlterCommentDefinition(BaseObject *object, attribs_map attributes);
+
 	public:
 		//! \brief Maximum number of characters that an object name on PostgreSQL can have
-		static const int OBJECT_NAME_MAX_LENGTH=63;
+		static constexpr int ObjectNameMaxLength=63;
+
+		/*! \brief The default number of objects supposed to be stored in objects list.
+		 * This values is just a reference (hint) and is used to preallocate (reserve) space on vectors which handle objects
+		 * to avoid excessive allocation/deallocation by resizing the vectors due to insert operation */
+		static constexpr unsigned DefMaxObjectCount=20;
 
 		BaseObject(void);
 		BaseObject(bool system_obj);
@@ -271,12 +293,21 @@ class BaseObject {
 		//! \brief Returns the current value of the global object id counter
 		static unsigned getGlobalId(void);
 
+		static void setEscapeComments(bool value);
+
+		static bool isEscapeComments(void);
+
 		//! \brief Defines the comment of the object that will be attached to its SQL definition
 		virtual void setComment(const QString &comment);
 
 		//! \brief Defines the objects name. If the passed name isn't valid it'll raise an error
 		virtual void setName(const QString &name);
 
+		/*! \brief Defines the object's alias (human readable / friendly name). An alias is used when the database model is being
+		 * displayed in compact view. This method raises an error when the provided name is larger than 63 bytes
+		 * (the same rule for PostgreSQL names length) */
+		virtual void setAlias(const QString &alias);
+
 		//! \brief Toggles the object's modify protection
 		virtual void setProtected(bool value);
 
@@ -319,12 +350,19 @@ class BaseObject {
 		 the parameter 'prepend_schema' includes the schema name on the objects name (defult) */
 		virtual QString getName(bool format=false, bool prepend_schema=true);
 
+		//! \brief Returns the object's alias (user friendly) name
+		virtual QString getAlias(void);
+
 		//! \brief Returns the name of the object with schema name (when available) prepended by default
 		virtual QString getSignature(bool format=true);
 
-		//! \brief Retorns the object's comment
+		//! \brief Returns the object's comment (in raw form)
 		QString getComment(void);
 
+		/*! \brief Returns the object's comment in such way that the quotes are escaped as well,
+		 * if escape_special_chars is true, any line break and tabulation is returned in form \n and \t */
+		QString getEscapedComment(bool escape_special_chars);
+
 		//! \brief Returns the object's type
 		ObjectType getObjectType(void);
 
@@ -407,6 +445,9 @@ class BaseObject {
 		//! \brief Returns if the specified type accepts the use of DROP commands
 		static bool acceptsDropCommand(ObjectType obj_type);
 
+		//! \brief Returns if the specified type accepts an alias (friendly name)
+		static bool acceptsAlias(ObjectType obj_type);
+
 		//! \brief Returns if the object accepts to have a schema assigned
 		bool acceptsSchema(void);
 
@@ -435,6 +476,8 @@ class BaseObject {
 				This method has no effect when the cached code support is disables. See enableCachedCode() */
 		virtual void setCodeInvalidated(bool value);
 
+		virtual void configureSearchAttributes(void);
+
 		//! \brief Returns if the code (sql and xml) is invalidated
 		bool isCodeInvalidated(void);
 
@@ -448,7 +491,7 @@ class BaseObject {
 		static void enableCachedCode(bool value);
 
 		/*! \brief Returns the valid object types in a vector. The types
-		BASE_OBJECT, TYPE_ATTRIBUTE and BASE_TABLE aren't included in return vector.
+		ObjectType::ObjBaseObject, TYPE_ATTRIBUTE and ObjectType::ObjBaseTable aren't included in return vector.
 		By default table objects (columns, trigger, constraints, etc) are included. To
 		avoid the insertion of these types set the boolean param to false. */
 		static vector<ObjectType> getObjectTypes(bool inc_table_objs=true, vector<ObjectType> exclude_types={});
@@ -456,7 +499,7 @@ class BaseObject {
 		/*! \brief Returns the valid object types that are child or grouped under the specified type.
 	This method works a litte different from getObjectTypes() since this latter returns all valid types
 	and this one returns only the valid types for the current specified type. For now the only accepted
-	types are OBJ_DATABASE, OBJ_SCHEMA and OBJ_TABLE */
+	types are ObjectType::Database, ObjectType::Schema, ObjectType::Table, ObjectType::ForeignTable */
 		static vector<ObjectType> getChildObjectTypes(ObjectType obj_type);
 
 		/*! \brief Sets the default version when generating the SQL code. This affects all instances of classes that
@@ -466,6 +509,9 @@ class BaseObject {
 		//! \brief Returns the current version for SQL code generation
 		static QString getPgSQLVersion(void);
 
+		//! \brief Returns the set of attributes used by the search mechanism
+		attribs_map getSearchAttributes(void);
+
 		friend class DatabaseModel;
 		friend class ModelValidationHelper;
 		friend class DatabaseImportHelper;
