@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -88,27 +88,26 @@ class BaseRelationship: public BaseGraphicObject  {
 
 		virtual QString getDropDefinition(bool) final { return(""); }
 
-	protected:
 		void setReferenceForeignKey(Constraint *reference_fk);
-		Constraint *getReferenceForeignKey(void);
 
 	public:
 		//! \brief Constants used to assign the type to relationship
-		static const unsigned RELATIONSHIP_11=10, //! \brief One to one
-		RELATIONSHIP_1N=11, //! \brief One to many
-		RELATIONSHIP_NN=12, //! \brief Many to many
-		RELATIONSHIP_GEN=13, //! \brief Generalization (Inheritance)
-		RELATIONSHIP_DEP=14, //! \brief Dependency (table-view) / Copy (table-table)
-		RELATIONSHIP_FK=15; //! \brief Relationship generated by creating a foreign key manually on a table
+		static constexpr unsigned Relationship11=10, //! \brief One to one
+		Relationship1n=11, //! \brief One to many
+		RelationshipNn=12, //! \brief Many to many
+		RelationshipGen=13, //! \brief Generalization (Inheritance)
+		RelationshipDep=14, //! \brief Dependency (table-view) / Copy (table-table)
+		RelationshipPart=15,//! \brief Partitioning relationship
+		RelationshipFk=16; //! \brief Relationship generated by creating a foreign key manually on a table
 
 		//! \brief Constats used to reference the relationship labels
-		static const unsigned SRC_CARD_LABEL=0,
-		DST_CARD_LABEL=1,
-		REL_NAME_LABEL=2;
+		static constexpr unsigned SrcCardLabel=0,
+		DstCardLabel=1,
+		RelNameLabel=2;
 
 		//! \brief Constants used to reference the source and destination tables
-		static const unsigned SRC_TABLE=0,
-		DST_TABLE=1;
+		static constexpr unsigned SrcTable=0,
+		DstTable=1;
 
 		BaseRelationship(BaseRelationship *rel);
 
@@ -162,6 +161,8 @@ class BaseRelationship: public BaseGraphicObject  {
 
 		void resetLabelsDistance(void);
 
+		Constraint *getReferenceForeignKey(void);
+
 		//! \brief Assigns one relationship to other making the appropriate attribute copy
 		void operator = (BaseRelationship &rel);
 
@@ -171,6 +172,10 @@ class BaseRelationship: public BaseGraphicObject  {
 
 		virtual QString getAlterDefinition(BaseObject *) { return(""); }
 
+		static QString getRelationshipTypeName(unsigned rel_type, bool is_view = false);
+
+		QString getRelationshipTypeName(void);
+
 		friend class DatabaseModel;
 		friend class RelationshipWidget;
 		friend class ModelWidget;
