@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,45 +20,45 @@
 
 Cast::Cast(void)
 {
-	obj_type=OBJ_CAST;
+	obj_type=ObjectType::Cast;
 	cast_function=nullptr;
-	cast_type=EXPLICIT;
+	cast_type=Explicit;
 	is_in_out=false;
-	attributes[ParsersAttributes::SOURCE_TYPE]=QString();
-	attributes[ParsersAttributes::DEST_TYPE]=QString();
-	attributes[ParsersAttributes::CAST_TYPE]=QString();
-	attributes[ParsersAttributes::IO_CAST]=QString();
-	attributes[ParsersAttributes::FUNCTION]=QString();
+	attributes[Attributes::SourceType]=QString();
+	attributes[Attributes::DestType]=QString();
+	attributes[Attributes::CastType]=QString();
+	attributes[Attributes::IoCast]=QString();
+	attributes[Attributes::Function]=QString();
 }
 
-void Cast::setDataType(unsigned type_idx, PgSQLType type)
+void Cast::setDataType(unsigned type_idx, PgSqlType type)
 {
 	//Check if the type index is valid
-	if(type_idx<=DST_TYPE)
+	if(type_idx<=DstType)
 	{
 		//Raises an error if the passed data type is null
 		if((*type).isEmpty())
-			throw Exception(Exception::getErrorMessage(ERR_ASG_NULL_TYPE_OBJECT)
+			throw Exception(Exception::getErrorMessage(ErrorCode::AsgNullTypeObject)
 							.arg(this->getName())
-							.arg(BaseObject::getTypeName(OBJ_CAST)),
-							ERR_ASG_NULL_TYPE_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+							.arg(BaseObject::getTypeName(ObjectType::Cast)),
+							ErrorCode::AsgNullTypeObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 		setCodeInvalidated(this->types[type_idx] != type);
 		this->types[type_idx]=type;
 	}
 	else
 		//Raises an error if the type index is invalid
-		throw Exception(ERR_REF_TYPE_INV_INDEX,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::RefTypeInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	//Configures the cast name (in form of signature: cast(src_type, dst_type) )
-	this->obj_name=QString("cast(%1,%2)").arg(~types[SRC_TYPE]).arg(~types[DST_TYPE]);
+	this->obj_name=QString("cast(%1,%2)").arg(~types[SrcType]).arg(~types[DstType]);
 }
 
 void Cast::setCastType(unsigned cast_type)
 {
 	//Raises an error if the user tries to assign an invalid cast type
-	if(cast_type > IMPLICIT)
-		throw Exception(ERR_ASG_INV_TYPE_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+	if(cast_type > Implicit)
+		throw Exception(ErrorCode::AsgInvalidTypeObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	setCodeInvalidated(this->cast_type != cast_type);
 	this->cast_type=cast_type;
@@ -74,29 +74,29 @@ void Cast::setCastFunction(Function *cast_func)
 {
 	unsigned param_count;
 	bool error=false;
-	PgSQLType ret_type;
+	PgSqlType ret_type;
 
 	if(!cast_func)
-		throw Exception(Exception::getErrorMessage(ERR_ASG_NOT_ALOC_FUNCTION)
+		throw Exception(Exception::getErrorMessage(ErrorCode::AsgNotAllocatedFunction)
 						.arg(this->getName())
-						.arg(BaseObject::getTypeName(OBJ_CAST)),
-						ERR_ASG_NOT_ALOC_FUNCTION,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+						.arg(BaseObject::getTypeName(ObjectType::Cast)),
+						ErrorCode::AsgNotAllocatedFunction,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	//Retrieve the cast function parameter count for specific validations
 	param_count=cast_func->getParameterCount();
 
 	//Raises an error if the function don't have at least 1 parameter or a maximum of 3
 	if(param_count==0 || param_count > 3)
-		throw Exception(Exception::getErrorMessage(ERR_ASG_FUNC_INV_PARAM_COUNT)
+		throw Exception(Exception::getErrorMessage(ErrorCode::AsgFunctionInvalidParamCount)
 						.arg(this->getName())
-						.arg(BaseObject::getTypeName(OBJ_CAST)),
-						ERR_ASG_FUNC_INV_PARAM_COUNT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+						.arg(BaseObject::getTypeName(ObjectType::Cast)),
+						ErrorCode::AsgFunctionInvalidParamCount,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 	else
 	{
 		/* Error condition 1: Check if the first function parameter data type differs
 		 from cast source data type */
-		error=(cast_func->getParameter(0).getType()!=this->types[SRC_TYPE] &&
-					!cast_func->getParameter(0).getType().canCastTo(this->types[SRC_TYPE]));
+		error=(cast_func->getParameter(0).getType()!=this->types[SrcType] &&
+					!cast_func->getParameter(0).getType().canCastTo(this->types[SrcType]));
 
 		/* Error condition 2: Check if the second function parameter data type
 		 is different from 'integer' */
@@ -110,30 +110,30 @@ void Cast::setCastFunction(Function *cast_func)
 
 		//In case some error condition is reached raises an error
 		if(error)
-			throw Exception(Exception::getErrorMessage(ERR_ASG_FUNCTION_INV_PARAMS)
+			throw Exception(Exception::getErrorMessage(ErrorCode::AsgFunctionInvalidParameters)
 							.arg(this->getName())
-							.arg(BaseObject::getTypeName(OBJ_CAST)),
-							ERR_ASG_FUNCTION_INV_PARAMS,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+							.arg(BaseObject::getTypeName(ObjectType::Cast)),
+							ErrorCode::AsgFunctionInvalidParameters,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 	}
 
 	/* Raises an error if the return type of the function differs from the destination data type.
 			If the types can be casted between them no error is returned */
 	ret_type=cast_func->getReturnType();
 
-	if(ret_type!=this->types[DST_TYPE] && !ret_type.canCastTo(this->types[DST_TYPE]))
-		throw Exception(Exception::getErrorMessage(ERR_ASG_FUNCTION_INV_RET_TYPE)
+	if(ret_type!=this->types[DstType] && !ret_type.canCastTo(this->types[DstType]))
+		throw Exception(Exception::getErrorMessage(ErrorCode::AsgFunctionInvalidReturnType)
 						.arg(this->getName())
-						.arg(BaseObject::getTypeName(OBJ_CAST)),
-						ERR_ASG_FUNCTION_INV_RET_TYPE,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+						.arg(BaseObject::getTypeName(ObjectType::Cast)),
+						ErrorCode::AsgFunctionInvalidReturnType,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	setCodeInvalidated(cast_function != cast_func);
 	this->cast_function=cast_func;
 }
 
-PgSQLType Cast::getDataType(unsigned type_idx)
+PgSqlType Cast::getDataType(unsigned type_idx)
 {
-	if(type_idx > DST_TYPE)
-		throw Exception(ERR_REF_TYPE_INV_INDEX,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+	if(type_idx > DstType)
+		throw Exception(ErrorCode::RefTypeInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	return(this->types[type_idx]);
 }
@@ -155,7 +155,7 @@ unsigned Cast::getCastType(void)
 
 QString Cast::getDropDefinition(bool cascade)
 {
-	attributes[ParsersAttributes::SIGNATURE].replace(QString(","), QString(" AS "));
+	attributes[Attributes::Signature].replace(QString(","), QString(" AS "));
 	return(BaseObject::getDropDefinition(cascade));
 }
 
@@ -164,43 +164,53 @@ QString Cast::getCodeDefinition(unsigned def_type)
 	QString code_def=getCachedCode(def_type, false);
 	if(!code_def.isEmpty()) return(code_def);
 
-	if(def_type==SchemaParser::SQL_DEFINITION)
+	if(def_type==SchemaParser::SqlDefinition)
 	{
-		attributes[ParsersAttributes::SOURCE_TYPE]=(*types[SRC_TYPE]);
-		attributes[ParsersAttributes::DEST_TYPE]=(*types[DST_TYPE]);
+		attributes[Attributes::SourceType]=(*types[SrcType]);
+		attributes[Attributes::DestType]=(*types[DstType]);
 	}
 	else
 	{
-		attributes[ParsersAttributes::SOURCE_TYPE]=types[SRC_TYPE].getCodeDefinition(def_type);
-		attributes[ParsersAttributes::DEST_TYPE]=types[DST_TYPE].getCodeDefinition(def_type);
+		attributes[Attributes::SourceType]=types[SrcType].getCodeDefinition(def_type);
+		attributes[Attributes::DestType]=types[DstType].getCodeDefinition(def_type);
 	}
 
 	if(!is_in_out && cast_function)
 	{
-		if(def_type==SchemaParser::SQL_DEFINITION)
-			attributes[ParsersAttributes::FUNCTION]=cast_function->getSignature();
+		if(def_type==SchemaParser::SqlDefinition)
+			attributes[Attributes::Function]=cast_function->getSignature();
 		else
-			attributes[ParsersAttributes::FUNCTION]=cast_function->getCodeDefinition(def_type, true);
+			attributes[Attributes::Function]=cast_function->getCodeDefinition(def_type, true);
 	}
 	else
-		attributes[ParsersAttributes::IO_CAST]=(is_in_out ? ParsersAttributes::_TRUE_ : QString());
+		attributes[Attributes::IoCast]=(is_in_out ? Attributes::True : QString());
 
-	if(cast_type==ASSIGNMENT)
-		attributes[ParsersAttributes::CAST_TYPE]=ParsersAttributes::ASSIGNMENT;
-	else if(cast_type==IMPLICIT)
-		attributes[ParsersAttributes::CAST_TYPE]=ParsersAttributes::IMPLICIT;
+	if(cast_type==Assignment)
+		attributes[Attributes::CastType]=Attributes::Assignment;
+	else if(cast_type==Implicit)
+		attributes[Attributes::CastType]=Attributes::Implicit;
 	else
-		attributes[ParsersAttributes::CAST_TYPE]=QString();
+		attributes[Attributes::CastType]=QString();
 
-	if(def_type==SchemaParser::SQL_DEFINITION)
-		attributes[ParsersAttributes::CAST_TYPE]=attributes[ParsersAttributes::CAST_TYPE].toUpper();
+	if(def_type==SchemaParser::SqlDefinition)
+		attributes[Attributes::CastType]=attributes[Attributes::CastType].toUpper();
 
 	return(BaseObject::__getCodeDefinition(def_type));
 }
 
 QString Cast::getSignature(bool)
 {
-	attributes[ParsersAttributes::SIGNATURE]=this->getName().remove(QString("cast"));
+	attributes[Attributes::Signature]=this->getName().remove(QString("cast"));
 	return(BaseObject::getSignature(false));
 }
 
+void Cast::configureSearchAttributes(void)
+{
+	QStringList arg_types;
+
+	BaseObject::configureSearchAttributes();
+
+	arg_types += *types[0];
+	arg_types += *types[1];
+	search_attribs[Attributes::Type] = arg_types.join("; ");
+}
