@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,50 +20,50 @@
 
 Conversion::Conversion(void)
 {
-	obj_type=OBJ_CONVERSION;
+	obj_type=ObjectType::Conversion;
 	conversion_func=nullptr;
 	is_default=false;
-	attributes[ParsersAttributes::DEFAULT]=QString();
-	attributes[ParsersAttributes::SRC_ENCODING]=QString();
-	attributes[ParsersAttributes::DST_ENCODING]=QString();
-	attributes[ParsersAttributes::FUNCTION]=QString();
+	attributes[Attributes::Default]=QString();
+	attributes[Attributes::SrcEncoding]=QString();
+	attributes[Attributes::DstEncoding]=QString();
+	attributes[Attributes::Function]=QString();
 }
 
 void Conversion::setEncoding(unsigned encoding_idx, EncodingType encoding_type)
 {
 	//Checks if the encoding index is valid
-	if(encoding_idx<=DST_ENCODING)
+	if(encoding_idx<=DstEncoding)
 	{
 		//If the passed enconding type is null an error is raised
 		if((~encoding_type).isEmpty())
-			throw Exception(Exception::getErrorMessage(ERR_ASG_NULL_TYPE_OBJECT)
+			throw Exception(Exception::getErrorMessage(ErrorCode::AsgNullTypeObject)
 							.arg(this->getName())
-							.arg(BaseObject::getTypeName(OBJ_CONVERSION)),
-							ERR_ASG_NULL_TYPE_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+							.arg(BaseObject::getTypeName(ObjectType::Conversion)),
+							ErrorCode::AsgNullTypeObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 		//Assigns the encoding to the conversion in the specified index
 		this->encodings[encoding_idx]=encoding_type;
 	}
 	else
 		//Raises an error if the encoding index is invalid
-		throw Exception(ERR_REF_TYPE_INV_INDEX,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::RefTypeInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 }
 
 void Conversion::setConversionFunction(Function *conv_func)
 {
 	//Raises an error in case the passed conversion function is null
 	if(!conv_func)
-		throw Exception(Exception::getErrorMessage(ERR_ASG_NOT_ALOC_FUNCTION)
+		throw Exception(Exception::getErrorMessage(ErrorCode::AsgNotAllocatedFunction)
 						.arg(this->getName(true))
-						.arg(BaseObject::getTypeName(OBJ_CONVERSION)),
-						ERR_ASG_NOT_ALOC_FUNCTION,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+						.arg(BaseObject::getTypeName(ObjectType::Conversion)),
+						ErrorCode::AsgNotAllocatedFunction,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 	/* The conversion function must have 5 parameters if it's not the case
 		raises an error. */
 	else if(conv_func->getParameterCount()!=5)
-		throw Exception(Exception::getErrorMessage(ERR_ASG_FUNC_INV_PARAM_COUNT)
+		throw Exception(Exception::getErrorMessage(ErrorCode::AsgFunctionInvalidParamCount)
 						.arg(this->getName(true))
-						.arg(BaseObject::getTypeName(OBJ_CONVERSION)),
-						ERR_ASG_FUNC_INV_PARAM_COUNT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+						.arg(BaseObject::getTypeName(ObjectType::Conversion)),
+						ErrorCode::AsgFunctionInvalidParamCount,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 	/* Raises an error if the function parameters does not following the type order:
 		interger, integer, cstring, internal, integer */
 	else if(conv_func->getParameter(0).getType()!=QString("integer") ||
@@ -71,16 +71,16 @@ void Conversion::setConversionFunction(Function *conv_func)
 			conv_func->getParameter(2).getType()!=QString("cstring") ||
 			conv_func->getParameter(3).getType()!=QString("internal") ||
 			conv_func->getParameter(4).getType()!=QString("integer"))
-		throw Exception(Exception::getErrorMessage(ERR_ASG_FUNCTION_INV_PARAMS)
+		throw Exception(Exception::getErrorMessage(ErrorCode::AsgFunctionInvalidParameters)
 						.arg(this->getName(true))
-						.arg(BaseObject::getTypeName(OBJ_CONVERSION)),
-						ERR_ASG_FUNCTION_INV_PARAMS,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+						.arg(BaseObject::getTypeName(ObjectType::Conversion)),
+						ErrorCode::AsgFunctionInvalidParameters,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 	//Raises an error if the conversion function return type is not 'void'
 	else if(conv_func->getReturnType()!=QString("void"))
-		throw Exception(Exception::getErrorMessage(ERR_ASG_FUNCTION_INV_RET_TYPE)
+		throw Exception(Exception::getErrorMessage(ErrorCode::AsgFunctionInvalidReturnType)
 						.arg(this->getName(true))
-						.arg(BaseObject::getTypeName(OBJ_CONVERSION)),
-						ERR_ASG_FUNCTION_INV_RET_TYPE,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+						.arg(BaseObject::getTypeName(ObjectType::Conversion)),
+						ErrorCode::AsgFunctionInvalidReturnType,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	setCodeInvalidated(conversion_func != conv_func);
 	this->conversion_func=conv_func;
@@ -94,8 +94,8 @@ void Conversion::setDefault(bool value)
 
 EncodingType Conversion::getEncoding(unsigned encoding_idx)
 {
-	if(encoding_idx > DST_ENCODING)
-		throw Exception(ERR_REF_TYPE_INV_INDEX,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+	if(encoding_idx > DstEncoding)
+		throw Exception(ErrorCode::RefTypeInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	return(this->encodings[encoding_idx]);
 }
@@ -115,16 +115,16 @@ QString Conversion::getCodeDefinition(unsigned def_type)
 	QString code_def=getCachedCode(def_type, false);
 	if(!code_def.isEmpty()) return(code_def);
 
-	attributes[ParsersAttributes::DEFAULT]=(is_default ? ParsersAttributes::_TRUE_ : QString());
-	attributes[ParsersAttributes::SRC_ENCODING]=(~encodings[SRC_ENCODING]);
-	attributes[ParsersAttributes::DST_ENCODING]=(~encodings[DST_ENCODING]);
+	attributes[Attributes::Default]=(is_default ? Attributes::True : QString());
+	attributes[Attributes::SrcEncoding]=(~encodings[SrcEncoding]);
+	attributes[Attributes::DstEncoding]=(~encodings[DstEncoding]);
 
 	if(conversion_func)
 	{
-		if(def_type==SchemaParser::SQL_DEFINITION)
-			attributes[ParsersAttributes::FUNCTION]=conversion_func->getName(true);
+		if(def_type==SchemaParser::SqlDefinition)
+			attributes[Attributes::Function]=conversion_func->getName(true);
 		else
-			attributes[ParsersAttributes::FUNCTION]=conversion_func->getCodeDefinition(def_type, true);
+			attributes[Attributes::Function]=conversion_func->getCodeDefinition(def_type, true);
 	}
 
 	return(BaseObject::__getCodeDefinition(def_type));
