@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 */
 
 #include "copyoptions.h"
+#include "baseobject.h"
 
 CopyOptions::CopyOptions(void)
 {
@@ -25,8 +26,8 @@ CopyOptions::CopyOptions(void)
 
 CopyOptions::CopyOptions(unsigned copy_mode, unsigned copy_op_ids)
 {
-	if((copy_mode!=0 && copy_mode!=INCLUDING && copy_mode!=EXCLUDING) || copy_op_ids > ALL)
-		throw Exception(ERR_REF_INV_LIKE_OP_TYPE,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+	if((copy_mode!=0 && copy_mode!=Including && copy_mode!=Excluding) || copy_op_ids > All)
+		throw Exception(ErrorCode::RefInvalidLikeOptionType,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	this->copy_mode = copy_mode;
 	this->copy_op_ids = copy_op_ids;
@@ -39,20 +40,20 @@ unsigned CopyOptions::getCopyMode(void)
 
 bool CopyOptions::isOptionSet(unsigned op)
 {
-	if(op > ALL)
-		throw Exception(ERR_REF_INV_LIKE_OP_TYPE,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+	if(op > All)
+		throw Exception(ErrorCode::RefInvalidLikeOptionType,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	return((copy_op_ids & op) == op);
 }
 
 bool CopyOptions::isIncluding(void)
 {
-	return(copy_mode & INCLUDING);
+	return(copy_mode & Including);
 }
 
 bool CopyOptions::isExcluding(void)
 {
-	return(copy_mode & EXCLUDING);
+	return(copy_mode & Excluding);
 }
 
 unsigned CopyOptions::getCopyOptionsIds(void)
@@ -64,11 +65,11 @@ QString CopyOptions::getSQLDefinition(void)
 {
 	QString def, mode, op_name;
 	unsigned op_id,
-			ids[]={ALL, DEFAULTS, CONSTRAINTS,
-				   INDEXES, STORAGE, COMMENTS },
+			ids[]={All, Defaults, Constraints, Indexes,
+						 Storage, Comments, Identity, Statistics },
 			cnt = sizeof(ids) / sizeof(unsigned);
 
-	mode = (copy_mode == INCLUDING ? QString(" INCLUDING") : QString(" EXCLUDING"));
+	mode = (copy_mode == Including ? QString(" INCLUDING") : QString(" EXCLUDING"));
 	if(copy_mode!=0 && copy_op_ids!=0)
 	{
 		for(unsigned i=0; i < cnt; i++)
@@ -77,12 +78,14 @@ QString CopyOptions::getSQLDefinition(void)
 
 			switch(op_id)
 			{
-				case ALL: op_name=QString(" ALL"); break;
-				case DEFAULTS: op_name=QString(" DEFAULTS"); break;
-				case CONSTRAINTS: op_name=QString(" CONSTRAINTS"); break;
-				case INDEXES: op_name=QString(" INDEXES"); break;
-				case STORAGE: op_name=QString(" STORAGE"); break;
-				case COMMENTS: op_name=QString(" COMMENTS"); break;
+				case All: op_name=QString(" ALL"); break;
+				case Defaults: op_name=QString(" DEFAULTS"); break;
+				case Constraints: op_name=QString(" CONSTRAINTS"); break;
+				case Indexes: op_name=QString(" INDEXES"); break;
+				case Storage: op_name=QString(" STORAGE"); break;
+				case Comments: op_name=QString(" COMMENTS"); break;
+				case Identity: op_name=(BaseObject::getPgSQLVersion().toFloat() > PgSqlVersions::PgSqlVersion96.toFloat() ? QString(" IDENTITY") : QString()); break;
+				case Statistics: op_name=(BaseObject::getPgSQLVersion().toFloat() > PgSqlVersions::PgSqlVersion96.toFloat() ? QString(" STATISTICS") : QString()); break;
 			}
 
 			if(!op_name.isEmpty())
@@ -91,7 +94,7 @@ QString CopyOptions::getSQLDefinition(void)
 				op_name.clear();
 			}
 
-			if(op_id==ALL) break;
+			if(op_id==All) break;
 		}
 	}
 
