@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,31 +20,31 @@
 
 Domain::Domain(void)
 {
-	obj_type=OBJ_DOMAIN;
+	obj_type=ObjectType::Domain;
 	not_null=false;
-	attributes[ParsersAttributes::DEFAULT_VALUE]=QString();
-	attributes[ParsersAttributes::NOT_NULL]=QString();
-	attributes[ParsersAttributes::TYPE]=QString();
-	attributes[ParsersAttributes::CONSTRAINTS]=QString();
+	attributes[Attributes::DefaultValue]=QString();
+	attributes[Attributes::NotNull]=QString();
+	attributes[Attributes::Type]=QString();
+	attributes[Attributes::Constraints]=QString();
 }
 
 void Domain::addCheckConstraint(const QString &name, const QString &expr)
 {
 	//Raises an error if the constraint name is invalid
 	if(!name.isEmpty() && !BaseObject::isValidName(name))
-		throw Exception(ERR_ASG_INV_NAME_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgInvalidNameObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	if(expr.isEmpty())
-		throw Exception(ERR_ASG_INV_EXPR_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgInvalidExpressionObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	if(chk_constrs.count(name))
 	{
-		throw Exception(QString(Exception::getErrorMessage(ERR_ASG_DUPLIC_OBJECT))
+		throw Exception(Exception::getErrorMessage(ErrorCode::AsgDuplicatedObject)
 						.arg(name)
-						.arg(BaseObject::getTypeName(OBJ_CONSTRAINT))
+						.arg(BaseObject::getTypeName(ObjectType::Constraint))
 						.arg(this->getName(true))
 						.arg(this->getTypeName()),
-						ERR_ASG_DUPLIC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+						ErrorCode::AsgDuplicatedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 	}
 
 	chk_constrs[name] = expr;
@@ -70,7 +70,7 @@ void Domain::setName(const QString &name)
 	new_name=this->getName(true);
 
 	//Renames the PostgreSQL type represented by the domain
-	PgSQLType::renameUserType(prev_name, this, new_name);
+	PgSqlType::renameUserType(prev_name, this, new_name);
 }
 
 void Domain::setSchema(BaseObject *schema)
@@ -81,7 +81,7 @@ void Domain::setSchema(BaseObject *schema)
 	BaseObject::setSchema(schema);
 
 	//Renames the PostgreSQL type represented by the domain
-	PgSQLType::renameUserType(prev_name, this, this->getName(true));
+	PgSqlType::renameUserType(prev_name, this, this->getName(true));
 }
 
 void Domain::setDefaultValue(const QString &default_val)
@@ -98,7 +98,7 @@ void Domain::setNotNull(bool value)
 	not_null=value;
 }
 
-void Domain::setType(PgSQLType type)
+void Domain::setType(PgSqlType type)
 {
 	setCodeInvalidated(this->type != type);
 	this->type=type;
@@ -114,7 +114,7 @@ bool Domain::isNotNull(void)
 	return(not_null);
 }
 
-PgSQLType Domain::getType(void)
+PgSqlType Domain::getType(void)
 {
 	return(type);
 }
@@ -126,20 +126,20 @@ QString Domain::getCodeDefinition(unsigned def_type)
 
 	attribs_map aux_attribs;
 
-	attributes[ParsersAttributes::NOT_NULL]=(not_null ? ParsersAttributes::_TRUE_ : QString());
-	attributes[ParsersAttributes::DEFAULT_VALUE]=default_value;
+	attributes[Attributes::NotNull]=(not_null ? Attributes::True : QString());
+	attributes[Attributes::DefaultValue]=default_value;
 
 	for(auto itr : chk_constrs)
 	{
-		aux_attribs[ParsersAttributes::NAME] = itr.first;
-		aux_attribs[ParsersAttributes::EXPRESSION] = itr.second;
-		attributes[ParsersAttributes::CONSTRAINTS]+=schparser.getCodeDefinition(ParsersAttributes::DOM_CONSTRAINT, aux_attribs, def_type);
+		aux_attribs[Attributes::Name] = itr.first;
+		aux_attribs[Attributes::Expression] = itr.second;
+		attributes[Attributes::Constraints]+=schparser.getCodeDefinition(Attributes::DomConstraint, aux_attribs, def_type);
 	}
 
-	if(def_type==SchemaParser::SQL_DEFINITION)
-		attributes[ParsersAttributes::TYPE]=(*type);
+	if(def_type==SchemaParser::SqlDefinition)
+		attributes[Attributes::Type]=(*type);
 	else
-		attributes[ParsersAttributes::TYPE]=type.getCodeDefinition(def_type);
+		attributes[Attributes::Type]=type.getCodeDefinition(def_type);
 
 	return(BaseObject::__getCodeDefinition(def_type));
 }
@@ -153,7 +153,7 @@ void Domain::operator = (Domain &domain)
 	this->default_value=domain.default_value;
 	this->type=domain.type;
 	this->chk_constrs=domain.chk_constrs;
-	PgSQLType::renameUserType(prev_name, this, this->getName(true));
+	PgSqlType::renameUserType(prev_name, this, this->getName(true));
 }
 
 QString Domain::getAlterDefinition(BaseObject *object)
@@ -161,7 +161,7 @@ QString Domain::getAlterDefinition(BaseObject *object)
 	Domain *domain=dynamic_cast<Domain *>(object);
 
 	if(!domain)
-		throw Exception(ERR_OPR_NOT_ALOC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::OprNotAllocatedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	try
 	{
@@ -169,23 +169,23 @@ QString Domain::getAlterDefinition(BaseObject *object)
 		attribs_map orig_constrs, aux_constrs, aux_attribs;
 		QString orig_expr, aux_expr;
 
-		attributes[ParsersAttributes::DEFAULT_VALUE]=QString();
-		attributes[ParsersAttributes::NOT_NULL]=QString();
-		attributes[ParsersAttributes::CONSTRAINTS]=QString();
-		attributes[ParsersAttributes::EXPRESSION]=QString();
-		attributes[ParsersAttributes::OLD_NAME]=QString();
-		attributes[ParsersAttributes::NEW_NAME]=QString();
+		attributes[Attributes::DefaultValue]=QString();
+		attributes[Attributes::NotNull]=QString();
+		attributes[Attributes::Constraints]=QString();
+		attributes[Attributes::Expression]=QString();
+		attributes[Attributes::OldName]=QString();
+		attributes[Attributes::NewName]=QString();
 
 		if(this->default_value!=domain->default_value)
-			attributes[ParsersAttributes::DEFAULT_VALUE]=(!domain->default_value.isEmpty() ? domain->default_value : ParsersAttributes::UNSET);
+			attributes[Attributes::DefaultValue]=(!domain->default_value.isEmpty() ? domain->default_value : Attributes::Unset);
 
 		if(this->not_null!=domain->not_null)
-			attributes[ParsersAttributes::NOT_NULL]=(domain->not_null ? ParsersAttributes::_TRUE_ : ParsersAttributes::UNSET);
+			attributes[Attributes::NotNull]=(domain->not_null ? Attributes::True : Attributes::Unset);
 
 		orig_constrs = this->chk_constrs;
 		aux_constrs = domain->chk_constrs;
-		aux_attribs[ParsersAttributes::SQL_OBJECT] = this->getSQLName();
-		aux_attribs[ParsersAttributes::SIGNATURE] = this->getSignature();
+		aux_attribs[Attributes::SqlObject] = this->getSQLName();
+		aux_attribs[Attributes::Signature] = this->getSignature();
 
 		//Generating the DROP for check constraints that does not exists anymore
 		for(auto constr : orig_constrs)
@@ -197,17 +197,17 @@ QString Domain::getAlterDefinition(BaseObject *object)
 			if(aux_constrs.count(constr.first) == 0 ||
 				 (aux_constrs.count(constr.first) && orig_expr != aux_expr))
 			{
-				aux_attribs[ParsersAttributes::NAME]=constr.first;
-				aux_attribs[ParsersAttributes::EXPRESSION]=ParsersAttributes::UNSET;
-				attributes[ParsersAttributes::CONSTRAINTS]+=BaseObject::getAlterDefinition(ParsersAttributes::DOM_CONSTRAINT, aux_attribs, false, true);
+				aux_attribs[Attributes::Name]=constr.first;
+				aux_attribs[Attributes::Expression]=Attributes::Unset;
+				attributes[Attributes::Constraints]+=BaseObject::getAlterDefinition(Attributes::DomConstraint, aux_attribs, false, true);
 			}
 
 			//We should include a command to recreate the check constraint with the new expression
 			if(aux_constrs.count(constr.first) && orig_expr != aux_expr)
 			{
-				aux_attribs[ParsersAttributes::NAME]=constr.first;
-				aux_attribs[ParsersAttributes::EXPRESSION]=aux_constrs[constr.first];
-				attributes[ParsersAttributes::CONSTRAINTS]+=BaseObject::getAlterDefinition(ParsersAttributes::DOM_CONSTRAINT, aux_attribs, false, true);
+				aux_attribs[Attributes::Name]=constr.first;
+				aux_attribs[Attributes::Expression]=aux_constrs[constr.first];
+				attributes[Attributes::Constraints]+=BaseObject::getAlterDefinition(Attributes::DomConstraint, aux_attribs, false, true);
 			}
 		}
 
@@ -216,9 +216,9 @@ QString Domain::getAlterDefinition(BaseObject *object)
 		{
 			if(orig_constrs.count(constr.first) == 0)
 			{
-				aux_attribs[ParsersAttributes::NAME]=constr.first;
-				aux_attribs[ParsersAttributes::EXPRESSION]=constr.second;
-				attributes[ParsersAttributes::CONSTRAINTS]+=BaseObject::getAlterDefinition(ParsersAttributes::DOM_CONSTRAINT, aux_attribs, false, true);
+				aux_attribs[Attributes::Name]=constr.first;
+				aux_attribs[Attributes::Expression]=constr.second;
+				attributes[Attributes::Constraints]+=BaseObject::getAlterDefinition(Attributes::DomConstraint, aux_attribs, false, true);
 			}
 		}
 
@@ -227,6 +227,6 @@ QString Domain::getAlterDefinition(BaseObject *object)
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__,&e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__,&e);
 	}
 }
