@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,11 +20,11 @@
 
 EventTrigger::EventTrigger(void)
 {
-	obj_type=OBJ_EVENT_TRIGGER;
+	obj_type=ObjectType::EventTrigger;
 	function=nullptr;
-	attributes[ParsersAttributes::EVENT]=QString();
-	attributes[ParsersAttributes::FILTER]=QString();
-	attributes[ParsersAttributes::FUNCTION]=QString();
+	attributes[Attributes::Event]=QString();
+	attributes[Attributes::Filter]=QString();
+	attributes[Attributes::Function]=QString();
 }
 
 void EventTrigger::setEvent(EventTriggerType evnt_type)
@@ -36,22 +36,22 @@ void EventTrigger::setEvent(EventTriggerType evnt_type)
 void EventTrigger::setFunction(Function *func)
 {
 	if(!func)
-		throw Exception(Exception::getErrorMessage(ERR_ASG_NOT_ALOC_FUNCTION)
+		throw Exception(Exception::getErrorMessage(ErrorCode::AsgNotAllocatedFunction)
 						.arg(this->getName())
-						.arg(BaseObject::getTypeName(OBJ_EVENT_TRIGGER)),
-						ERR_ASG_NOT_ALOC_FUNCTION,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+						.arg(BaseObject::getTypeName(ObjectType::EventTrigger)),
+						ErrorCode::AsgNotAllocatedFunction,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 	//Functions with return type other that event_trigger are not accepted
 	else if(func->getReturnType()!=QString("event_trigger"))
-		throw Exception(Exception::getErrorMessage(ERR_ASG_INV_TRIGGER_FUNCTION).arg(QString("event_trigger")),__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(Exception::getErrorMessage(ErrorCode::AsgInvalidTriggerFunction).arg(QString("event_trigger")),__PRETTY_FUNCTION__,__FILE__,__LINE__);
 	//Functions with one or more parameters are not accepted
 	else if(func->getParameterCount()!=0)
-		throw Exception(Exception::getErrorMessage(ERR_ASG_FUNC_INV_PARAM_COUNT)
+		throw Exception(Exception::getErrorMessage(ErrorCode::AsgFunctionInvalidParamCount)
 						.arg(this->getName())
-						.arg(BaseObject::getTypeName(OBJ_EVENT_TRIGGER)),
-						ERR_ASG_FUNC_INV_PARAM_COUNT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+						.arg(BaseObject::getTypeName(ObjectType::EventTrigger)),
+						ErrorCode::AsgFunctionInvalidParamCount,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 	//Functions coded in SQL lang. is not accepted by event triggers
-	else if(func->getLanguage()->getName()==~LanguageType(LanguageType::sql))
-		throw Exception(ERR_ASG_EVNT_TRIG_FUNC_INV_LANG,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+	else if(func->getLanguage()->getName()==~LanguageType(LanguageType::Sql))
+		throw Exception(ErrorCode::AsgEventTriggerFuncInvalidLang,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	setCodeInvalidated(function != func);
 	function=func;
@@ -59,8 +59,8 @@ void EventTrigger::setFunction(Function *func)
 
 void EventTrigger::setFilter(const QString &variable, const QStringList &values)
 {
-	if(variable.toLower()!=ParsersAttributes::TAG)
-		throw Exception(Exception::getErrorMessage(ERR_ASG_INV_EVENT_TRIGGER_VARIABLE).arg(variable),__PRETTY_FUNCTION__,__FILE__,__LINE__);
+	if(variable.toLower()!=Attributes::Tag)
+		throw Exception(Exception::getErrorMessage(ErrorCode::AsgInvalidEventTriggerVariable).arg(variable),__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	if(!values.isEmpty())
 	{
@@ -109,31 +109,31 @@ QString EventTrigger::getCodeDefinition(unsigned def_type)
 	QString code_def=getCachedCode(def_type, false);
 	if(!code_def.isEmpty()) return(code_def);
 
-	attributes[ParsersAttributes::EVENT]=~event;
+	attributes[Attributes::Event]=~event;
 
-	if(def_type==SchemaParser::SQL_DEFINITION)
+	if(def_type==SchemaParser::SqlDefinition)
 	{
 		QStringList str_list;
 
 		if(function)
-			attributes[ParsersAttributes::FUNCTION]=function->getSignature();
+			attributes[Attributes::Function]=function->getSignature();
 
 		for(auto &flt : filter)
 			str_list.push_back(QString("%1 IN ('%2')").arg(flt.first).arg(flt.second.join(QString("','"))));
 
-		attributes[ParsersAttributes::FILTER]=str_list.join(QString("\n\t AND "));
+		attributes[Attributes::Filter]=str_list.join(QString("\n\t AND "));
 	}
 	else
 	{
 		if(function)
-			attributes[ParsersAttributes::FUNCTION]=function->getCodeDefinition(def_type, true);
+			attributes[Attributes::Function]=function->getCodeDefinition(def_type, true);
 
 		for(auto &flt : filter)
 			//Creating an element <filter variable="" values=""/>
-			attributes[ParsersAttributes::FILTER]+=QString("\t<%1 %2=\"%3\" %4=\"%5\"/>\n")
-												   .arg(ParsersAttributes::FILTER)
-												   .arg(ParsersAttributes::VARIABLE).arg(flt.first)
-												   .arg(ParsersAttributes::VALUES).arg(flt.second.join(','));
+			attributes[Attributes::Filter]+=QString("\t<%1 %2=\"%3\" %4=\"%5\"/>\n")
+												   .arg(Attributes::Filter)
+												   .arg(Attributes::Variable).arg(flt.first)
+												   .arg(Attributes::Values).arg(flt.second.join(','));
 	}
 
 	return(BaseObject::__getCodeDefinition(def_type));
@@ -143,11 +143,11 @@ QString EventTrigger::getAlterDefinition(BaseObject *object)
 {
 	try
 	{
-		attributes[ParsersAttributes::ALTER_CMDS]=BaseObject::getAlterDefinition(object);
+		attributes[Attributes::AlterCmds]=BaseObject::getAlterDefinition(object);
 		return(BaseObject::getAlterDefinition(this->getSchemaName(), attributes, false, false));
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__,&e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__,&e);
 	}
 }
