@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -54,10 +54,10 @@ class Index: public TableObject{
 		void validateElements(void);
 
 	public:
-		static const  unsigned UNIQUE=0,
-		CONCURRENT=1,
-		FAST_UPDATE=2,
-		BUFFERING=3;
+		static constexpr  unsigned Unique=0,
+		Concurrent=1,
+		FastUpdate=2,
+		Buffering=3;
 
 		Index(void);
 
