@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,13 +25,14 @@ OperationList::OperationList(DatabaseModel *model)
 	/* Raises an error if the user tries to allocate an operation list linked to
 		to an unallocated model */
 	if(!model)
-		throw Exception(ERR_ASG_NOT_ALOC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgNotAllocattedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	this->model=model;
 	xmlparser=model->getXMLParser();
 	current_index=0;
-	next_op_chain=Operation::NO_CHAIN;
+	next_op_chain=Operation::NoChain;
 	ignore_chain=false;
+	operations.reserve(max_size);
 }
 
 OperationList::~OperationList(void)
@@ -58,12 +59,12 @@ void OperationList::startOperationChain(void)
 {
 	/* If the chaining is started and the user try it initializes
 		again, the earlier chaining is finished */
-	if(next_op_chain!=Operation::NO_CHAIN)
+	if(next_op_chain!=Operation::NoChain)
 		finishOperationChain();
 
 	/* The next operation inserted on the list will be the start
 		of the chaining */
-	next_op_chain=Operation::CHAIN_START;
+	next_op_chain=Operation::ChainStart;
 }
 
 void OperationList::finishOperationChain(void)
@@ -71,11 +72,11 @@ void OperationList::finishOperationChain(void)
 	/* If the chain is not ignored indicates that the next
 		element of the list no longer will be part of chaining */
 	if(!ignore_chain)
-		next_op_chain=Operation::NO_CHAIN;
+		next_op_chain=Operation::NoChain;
 	else if(ignore_chain)
 		/* If the chain is canceled indicates that the next element
 		 of the list still part of the chaining */
-		next_op_chain=Operation::CHAIN_MIDDLE;
+		next_op_chain=Operation::ChainMiddle;
 
 	if(operations.size() > 0 && !ignore_chain)
 	{
@@ -83,15 +84,15 @@ void OperationList::finishOperationChain(void)
 
 		/* Marks the last operatin as being the end of chaining in case it is
 		 on the middle of chain */
-		if(operations[idx]->getChainType()==Operation::CHAIN_MIDDLE)
-			operations[idx]->setChainType(Operation::CHAIN_END);
+		if(operations[idx]->getChainType()==Operation::ChainMiddle)
+			operations[idx]->setChainType(Operation::ChainEnd);
 
 		/* If the last operation is marked as CHAIN_START indicates that
 		 the chaining was open but only one operation is recorded
 		 and thus the operation is marked as NO_CHAIN because as it is
 		 only one operation there is no need to treat it as chaining */
-		else if(operations[idx]->getChainType()==Operation::CHAIN_START)
-			operations[idx]->setChainType(Operation::NO_CHAIN);
+		else if(operations[idx]->getChainType()==Operation::ChainStart)
+			operations[idx]->setChainType(Operation::NoChain);
 	}
 }
 
@@ -102,8 +103,8 @@ void OperationList::ignoreOperationChain(bool value)
 
 bool OperationList::isOperationChainStarted(void)
 {
-	return(next_op_chain==Operation::CHAIN_START ||
-		   next_op_chain==Operation::CHAIN_MIDDLE);
+	return(next_op_chain==Operation::ChainStart ||
+		   next_op_chain==Operation::ChainMiddle);
 }
 
 bool OperationList::isObjectRegistered(BaseObject *object, unsigned op_type)
@@ -139,7 +140,7 @@ void OperationList::setMaximumSize(unsigned max)
 {
 	//Raises an error if a zero max size is assigned to the list
 	if(max==0)
-		throw Exception(ERR_ASG_INV_MAX_SIZE_OP_LIST,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgInvalidMaxSizeOpList,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	max_size=max;
 }
@@ -153,24 +154,24 @@ void OperationList::addToPool(BaseObject *object, unsigned op_type)
 
 		//Raises an error if the object to be added is not allocated
 		if(!object)
-			throw Exception(ERR_ASG_NOT_ALOC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+			throw Exception(ErrorCode::AsgNotAllocattedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 		obj_type=object->getObjectType();
 
 		//Stores a copy of the object if its about to be moved or modified
-		if(op_type==Operation::OBJECT_MODIFIED ||
-				op_type==Operation::OBJECT_MOVED)
+		if(op_type==Operation::ObjectModified ||
+				op_type==Operation::ObjectMoved)
 		{
 			BaseObject *copy_obj=nullptr;
 
-			if(obj_type!=BASE_OBJECT && obj_type!=OBJ_DATABASE)
-				PgModelerNS::copyObject(&copy_obj, object, obj_type);
+			if(obj_type!=ObjectType::BaseObject && obj_type!=ObjectType::Database)
+				PgModelerNs::copyObject(&copy_obj, object, obj_type);
 			else
-				throw Exception(ERR_ASG_OBJECT_INV_TYPE,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+				throw Exception(ErrorCode::AsgObjectInvalidType,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 			//Raises an error if the copy fails (returning a null object)
 			if(!copy_obj)
-				throw Exception(ERR_ASG_NOT_ALOC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+				throw Exception(ErrorCode::AsgNotAllocattedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 			else
 				//Inserts the copy on the pool
 				object_pool.push_back(copy_obj);
@@ -181,7 +182,7 @@ void OperationList::addToPool(BaseObject *object, unsigned op_type)
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__,&e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__,&e);
 	}
 }
 
@@ -227,7 +228,7 @@ void OperationList::removeOperations(void)
 			if(unallocated_objs.count(object)==0 &&
 					(!tab_obj && model->getObjectIndex(object) < 0))
 			{
-				if(object->getObjectType()==OBJ_TABLE)
+				if(object->getObjectType()==ObjectType::Table)
 				{
 					vector<BaseObject *> list=dynamic_cast<Table *>(object)->getObjects();
 
@@ -296,7 +297,7 @@ bool OperationList::isObjectOnPool(BaseObject *object)
 	vector<BaseObject *>::iterator itr, itr_end;
 
 	if(!object)
-		throw Exception(ERR_OPR_NOT_ALOC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::OprNotAllocatedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	itr=object_pool.begin();
 	itr_end=object_pool.end();
@@ -314,9 +315,9 @@ void OperationList::removeFromPool(unsigned obj_idx)
 	BaseObject *object=nullptr;
 	vector<BaseObject *>::iterator itr;
 
-	//Raises an error if the object index is invalid (out of bound)
+	//Avoiding the removal of an object in invalid index (out of bound)
 	if(obj_idx >= object_pool.size())
-		throw Exception(ERR_REF_OBJ_INV_INDEX,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		return;
 
 	//Gets the element to bo removed through its index
 	itr=object_pool.begin() + obj_idx;
@@ -347,18 +348,18 @@ int OperationList::registerObject(BaseObject *object, unsigned op_type, int obje
 	{
 		//Raises an error if the user tries to register an operation with null object
 		if(!object)
-			throw Exception(ERR_ASG_NOT_ALOC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+			throw Exception(ErrorCode::AsgNotAllocattedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 		obj_type=object->getObjectType();
 		if(tab_obj && !parent_obj)
-			throw Exception(ERR_OPR_NOT_ALOC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+			throw Exception(ErrorCode::OprNotAllocatedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 		else if(parent_obj &&
-				(((obj_type==OBJ_COLUMN || obj_type==OBJ_CONSTRAINT) &&
-				  (parent_obj->getObjectType()!=OBJ_RELATIONSHIP && parent_obj->getObjectType()!=OBJ_TABLE)) ||
+				(((obj_type==ObjectType::Column || obj_type==ObjectType::Constraint) &&
+					(parent_obj->getObjectType()!=ObjectType::Relationship && !PhysicalTable::isPhysicalTable(parent_obj->getObjectType()))) ||
 
-				 ((obj_type==OBJ_TRIGGER || obj_type==OBJ_RULE || obj_type==OBJ_INDEX) && !dynamic_cast<BaseTable *>(parent_obj))))
-			throw Exception(ERR_OPR_OBJ_INV_TYPE,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+				 ((obj_type==ObjectType::Trigger || obj_type==ObjectType::Rule || obj_type==ObjectType::Index) && !dynamic_cast<BaseTable *>(parent_obj))))
+			throw Exception(ErrorCode::OprObjectInvalidType,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 		//If the operations list is full makes the automatic cleaning before inserting a new operation
 		if(current_index == static_cast<int>(max_size-1))
@@ -397,15 +398,15 @@ int OperationList::registerObject(BaseObject *object, unsigned op_type, int obje
 		operation->setPoolObject(object_pool.back());
 
 		//Stores the object's permission befor its removal
-		if(op_type==Operation::OBJECT_REMOVED)
+		if(op_type==Operation::ObjectRemoved)
 		{
 			vector<Permission *> perms;
 			model->getPermissions(object, perms);
 			operation->setPermissions(perms);
 		}
 
-		if(next_op_chain==Operation::CHAIN_START)
-			next_op_chain=Operation::CHAIN_MIDDLE;
+		if(next_op_chain==Operation::ChainStart)
+			next_op_chain=Operation::ChainMiddle;
 
 		/*  Performing specific operations according to the type of object.
 		 If the object has a parent object, it must be discovered
@@ -413,29 +414,29 @@ int OperationList::registerObject(BaseObject *object, unsigned op_type, int obje
 		 in the list on the parent object */
 		if(tab_obj)
 		{
-			if(parent_obj->getObjectType()==OBJ_RELATIONSHIP)
+			if(parent_obj->getObjectType()==ObjectType::Relationship)
 				parent_rel=dynamic_cast<Relationship *>(parent_obj);
 			else
 				parent_tab=dynamic_cast<BaseTable *>(parent_obj);
 
-			if(((obj_type==OBJ_TRIGGER && dynamic_cast<Trigger *>(tab_obj)->isReferRelationshipAddedColumn()) ||
-				(obj_type==OBJ_INDEX && dynamic_cast<Index *>(tab_obj)->isReferRelationshipAddedColumn()) ||
-				(obj_type==OBJ_CONSTRAINT && dynamic_cast<Constraint *>(tab_obj)->isReferRelationshipAddedColumn())))
+			if(((obj_type==ObjectType::Trigger && dynamic_cast<Trigger *>(tab_obj)->isReferRelationshipAddedColumn()) ||
+				(obj_type==ObjectType::Index && dynamic_cast<Index *>(tab_obj)->isReferRelationshipAddedColumn()) ||
+				(obj_type==ObjectType::Constraint && dynamic_cast<Constraint *>(tab_obj)->isReferRelationshipAddedColumn())))
 			{
-				if(op_type==Operation::OBJECT_REMOVED)
+				if(op_type==Operation::ObjectRemoved)
 					tab_obj->setParentTable(parent_tab);
 
-				if(tab_obj->getObjectType()==OBJ_CONSTRAINT)
-					operation->setXMLDefinition(dynamic_cast<Constraint *>(tab_obj)->getCodeDefinition(SchemaParser::XML_DEFINITION, true));
+				if(tab_obj->getObjectType()==ObjectType::Constraint)
+					operation->setXMLDefinition(dynamic_cast<Constraint *>(tab_obj)->getCodeDefinition(SchemaParser::XmlDefinition, true));
 				else
-					operation->setXMLDefinition(tab_obj->getCodeDefinition(SchemaParser::XML_DEFINITION));
+					operation->setXMLDefinition(tab_obj->getCodeDefinition(SchemaParser::XmlDefinition));
 			}
 
 			operation->setParentObject(parent_obj);
 
 			/* If there is a parent relationship will get the index of the object.
 			Only columns and constraints are handled case the parent is a relationship */
-			if(parent_rel && (obj_type==OBJ_COLUMN || obj_type==OBJ_CONSTRAINT))
+			if(parent_rel && (obj_type==ObjectType::Column || obj_type==ObjectType::Constraint))
 			{
 				//Case a specific index wasn't specified
 				if(object_idx < 0)
@@ -456,13 +457,14 @@ int OperationList::registerObject(BaseObject *object, unsigned op_type, int obje
 			}
 			//Raises an error if both parent table / relationship isn't allocated
 			else
-				throw Exception(ERR_OPR_NOT_ALOC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+				throw Exception(ErrorCode::OprNotAllocatedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 		}
 		else
 		{
-			if((obj_type==OBJ_SEQUENCE && dynamic_cast<Sequence *>(object)->isReferRelationshipAddedColumn()) ||
-					(obj_type==OBJ_VIEW && dynamic_cast<View *>(object)->isReferRelationshipAddedColumn()))
-				operation->setXMLDefinition(object->getCodeDefinition(SchemaParser::XML_DEFINITION));
+			if((obj_type==ObjectType::Sequence && dynamic_cast<Sequence *>(object)->isReferRelationshipAddedColumn()) ||
+					(obj_type==ObjectType::View && dynamic_cast<View *>(object)->isReferRelationshipAddedColumn()) ||
+					(obj_type==ObjectType::GenericSql && dynamic_cast<GenericSQL *>(object)->isReferRelationshipAddedObject()))
+				operation->setXMLDefinition(object->getCodeDefinition(SchemaParser::XmlDefinition));
 
 			//Case a specific index wasn't specified
 			if(object_idx < 0)
@@ -473,8 +475,8 @@ int OperationList::registerObject(BaseObject *object, unsigned op_type, int obje
 				obj_idx=object_idx;
 		}
 
-		if(obj_type==OBJ_COLUMN && dynamic_cast<Column *>(object)->getType().isUserType())
-			operation->setXMLDefinition(object->getCodeDefinition(SchemaParser::XML_DEFINITION));
+		if(obj_type==ObjectType::Column && dynamic_cast<Column *>(object)->getType().isUserType())
+			operation->setXMLDefinition(object->getCodeDefinition(SchemaParser::XmlDefinition));
 
 		operation->setObjectIndex(obj_idx);
 		operations.push_back(operation);
@@ -490,7 +492,7 @@ int OperationList::registerObject(BaseObject *object, unsigned op_type, int obje
 			removeFromPool(object_pool.size()-1);
 			delete(operation);
 		}
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__,&e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__,&e);
 	}
 }
 
@@ -500,7 +502,7 @@ void OperationList::getOperationData(unsigned oper_idx, unsigned &oper_type, QSt
 	BaseObject *pool_obj=nullptr;
 
 	if(oper_idx >= operations.size())
-		throw Exception(ERR_REF_OBJ_INV_INDEX,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::RefObjectInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	operation=operations[oper_idx];
 	oper_type=operation->getOperationType();
@@ -516,7 +518,7 @@ void OperationList::getOperationData(unsigned oper_idx, unsigned &oper_type, QSt
 	}
 	else
 	{
-		obj_type=BASE_OBJECT;
+		obj_type=ObjectType::BaseObject;
 		obj_name=trUtf8("(invalid object)");
 	}
 }
@@ -531,21 +533,21 @@ unsigned OperationList::getChainSize(void)
 
 	//Checks if the current operations is chained
 	if(!operations.empty() &&
-			operations[i]->getChainType()!=Operation::NO_CHAIN)
+			operations[i]->getChainType()!=Operation::NoChain)
 	{
-		unsigned chain_type=Operation::NO_CHAIN;
+		unsigned chain_type=Operation::NoChain;
 		int inc=0;
 
 		//Case the operation is the end of a chain  runs the list in reverse order (from end to start)
-		if(operations[i]->getChainType()==Operation::CHAIN_END)
+		if(operations[i]->getChainType()==Operation::ChainEnd)
 		{
-			chain_type=Operation::CHAIN_START;
+			chain_type=Operation::ChainStart;
 			inc=-1;
 		}
 		//Case the operation is the start of a chain  runs the list in normal order (from start to end)
-		else if(operations[i]->getChainType()==Operation::CHAIN_START)
+		else if(operations[i]->getChainType()==Operation::ChainStart)
 		{
-			chain_type=Operation::CHAIN_END;
+			chain_type=Operation::ChainEnd;
 			inc=1;
 		}
 
@@ -585,14 +587,14 @@ void OperationList::undoOperation(void)
 			and active chaining flag is cleared marks the flag to start
 			the execution several operations at once */
 			if(!ignore_chain && !chain_active &&
-					operation->getChainType()!=Operation::NO_CHAIN)
+					operation->getChainType()!=Operation::NoChain)
 				chain_active=true;
 
 			/* If the chaining is active and the current operation is not part of
 			chain, aborts execution of the operation */
 			else if(chain_active &&
-					(operation->getChainType()==Operation::CHAIN_END ||
-					 operation->getChainType()==Operation::NO_CHAIN))
+					(operation->getChainType()==Operation::ChainEnd ||
+					 operation->getChainType()==Operation::NoChain))
 				break;
 
 			try
@@ -614,10 +616,10 @@ void OperationList::undoOperation(void)
 		/* Performs the operations while the current operation is part of chain
 		 or the undo option is available */
 		while(!ignore_chain && isUndoAvailable() &&
-			  operation->getChainType()!=Operation::NO_CHAIN);
+			  operation->getChainType()!=Operation::NoChain);
 
-		if(error.getErrorType()!=ERR_CUSTOM)
-			throw Exception(ERR_UNDO_REDO_OPR_INV_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__, &error);
+		if(error.getErrorCode()!=ErrorCode::Custom)
+			throw Exception(ErrorCode::UndoRedoOperationInvalidObject,__PRETTY_FUNCTION__,__FILE__,__LINE__, &error);
 	}
 }
 
@@ -641,14 +643,14 @@ void OperationList::redoOperation(void)
 			and active chaining flag is cleared marks the flag to start
 			the execution several operations at once */
 			if(!ignore_chain && !chain_active &&
-					operation->getChainType()!=Operation::NO_CHAIN)
+					operation->getChainType()!=Operation::NoChain)
 				chain_active=true;
 
 			/* If the chaining is active and the current operation is not part of
 			chain or it is at the start of chain, aborts execution of the operation */
 			else if(chain_active &&
-					(operation->getChainType()==Operation::CHAIN_START ||
-					 operation->getChainType()==Operation::NO_CHAIN))
+					(operation->getChainType()==Operation::ChainStart ||
+					 operation->getChainType()==Operation::NoChain))
 				break;
 
 			try
@@ -669,10 +671,10 @@ void OperationList::redoOperation(void)
 		/* Performs the operations while the current operation is part of chain
 		 or the redo option is available */
 		while(!ignore_chain && isRedoAvailable() &&
-			  operation->getChainType()!=Operation::NO_CHAIN);
+			  operation->getChainType()!=Operation::NoChain);
 
-		if(error.getErrorType()!=ERR_CUSTOM)
-			throw Exception(ERR_UNDO_REDO_OPR_INV_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__, &error);
+		if(error.getErrorCode()!=ErrorCode::Custom)
+			throw Exception(ErrorCode::UndoRedoOperationInvalidObject,__PRETTY_FUNCTION__,__FILE__,__LINE__, &error);
 	}
 }
 
@@ -686,7 +688,7 @@ void OperationList::executeOperation(Operation *oper, bool redo)
 		BaseTable *parent_tab=nullptr;
 		Relationship *parent_rel=nullptr;
 		QString xml_def;
-		unsigned op_type=Operation::NO_OPERATION;
+		unsigned op_type=Operation::NoOperation;
 		int obj_idx=-1;
 
 		object=oper->getPoolObject();
@@ -697,13 +699,13 @@ void OperationList::executeOperation(Operation *oper, bool redo)
 		obj_idx=oper->getObjectIndex();
 
 		/* Converting the parent object, if any, to the correct class according
-			to the type of the parent object. If OBJ_TABLE|OBJ_VIEW, the pointer
+			to the type of the parent object. If ObjectType::Table|ObjectType::View, the pointer
 			'parent_tab' get the reference to table/view and will be used as referential
 			in the operations below. If the parent object is a relationship, the pointer
 					'parent_rel' get the reference to the relationship */
 		if(parent_obj)
 		{
-			if(parent_obj->getObjectType()==OBJ_RELATIONSHIP)
+			if(parent_obj->getObjectType()==ObjectType::Relationship)
 				parent_rel=dynamic_cast<Relationship *>(parent_obj);
 			else
 				parent_tab=dynamic_cast<BaseTable *>(parent_obj);
@@ -712,35 +714,36 @@ void OperationList::executeOperation(Operation *oper, bool redo)
 		/* If the XML definition of object is set indicates that it is referencing a column
 			included by relationship (special object) */
 		if(!xml_def.isEmpty() &&
-				((op_type==Operation::OBJECT_REMOVED && !redo) ||
-				 (op_type==Operation::OBJECT_CREATED && redo) ||
-				 (op_type==Operation::OBJECT_MODIFIED ||
-				  op_type==Operation::OBJECT_MOVED)))
+				((op_type==Operation::ObjectRemoved && !redo) ||
+				 (op_type==Operation::ObjectCreated && redo) ||
+				 (op_type==Operation::ObjectModified ||
+				  op_type==Operation::ObjectMoved)))
 		{
 			//Resets the XML parser and loads the buffer xml from the operation
 			xmlparser->restartParser();
 			xmlparser->loadXMLBuffer(xml_def);
 
-			if(obj_type==OBJ_TRIGGER)
+			if(obj_type==ObjectType::Trigger)
 				aux_obj=model->createTrigger();
-			else if(obj_type==OBJ_INDEX)
+			else if(obj_type==ObjectType::Index)
 				aux_obj=model->createIndex();
-			else if(obj_type==OBJ_CONSTRAINT)
+			else if(obj_type==ObjectType::Constraint)
 				aux_obj=model->createConstraint(parent_obj);
-			else if(obj_type==OBJ_SEQUENCE)
+			else if(obj_type==ObjectType::Sequence)
 				aux_obj=model->createSequence();
-			else if(obj_type==OBJ_VIEW)
+			else if(obj_type==ObjectType::View)
 				aux_obj=model->createView();
-			else if(obj_type==OBJ_COLUMN)
+			else if(obj_type==ObjectType::Column)
 				aux_obj=model->createColumn();
+			else if(obj_type==ObjectType::GenericSql)
+				aux_obj=model->createGenericSQL();
 		}
 
 		/* If the operation is a modified/moved object, the object copy
 			stored in the pool will be restored */
-		if(op_type==Operation::OBJECT_MODIFIED ||
-				op_type==Operation::OBJECT_MOVED)
+		if(op_type==Operation::ObjectModified || op_type==Operation::ObjectMoved)
 		{
-			if(obj_type==OBJ_RELATIONSHIP)
+			if(obj_type==ObjectType::Relationship)
 			{
 				/* Due to the complexity of the class Relationship and the strong link between all
 				relationships of the model it is necessary to store XML for special objects and
@@ -759,27 +762,27 @@ void OperationList::executeOperation(Operation *oper, bool redo)
 				orig_obj=model->getObject(obj_idx, obj_type);
 
 			if(aux_obj)
-				oper->setXMLDefinition(orig_obj->getCodeDefinition(SchemaParser::XML_DEFINITION));
+				oper->setXMLDefinition(orig_obj->getCodeDefinition(SchemaParser::XmlDefinition));
 
 
 			//For pk constraint, before restore the previous configuration, uncheck the not-null flag of the source columns
-			if(obj_type==OBJ_CONSTRAINT)
+			if(obj_type==ObjectType::Constraint)
 				dynamic_cast<Constraint *>(orig_obj)->setColumnsNotNull(false);
 
 			/* The original object (obtained from the table, relationship or model) will have its
 		previous values restored with the existing copy on the pool. After restoring the object
 		on the pool will have the same attributes as the object before being restored
 		to enable redo operations */
-			PgModelerNS::copyObject(reinterpret_cast<BaseObject **>(&bkp_obj), orig_obj, obj_type);
-			PgModelerNS::copyObject(reinterpret_cast<BaseObject **>(&orig_obj), object, obj_type);
-			PgModelerNS::copyObject(reinterpret_cast<BaseObject **>(&object), bkp_obj, obj_type);
+			PgModelerNs::copyObject(reinterpret_cast<BaseObject **>(&bkp_obj), orig_obj, obj_type);
+			PgModelerNs::copyObject(reinterpret_cast<BaseObject **>(&orig_obj), object, obj_type);
+			PgModelerNs::copyObject(reinterpret_cast<BaseObject **>(&object), bkp_obj, obj_type);
 			object=orig_obj;
 
 			if(aux_obj)
-				PgModelerNS::copyObject(reinterpret_cast<BaseObject **>(&object), aux_obj, obj_type);
+				PgModelerNs::copyObject(reinterpret_cast<BaseObject **>(&object), aux_obj, obj_type);
 
 			//For pk constraint, after restore the previous configuration, check the not-null flag of the new source columns
-			if(obj_type==OBJ_CONSTRAINT)
+			if(obj_type==ObjectType::Constraint)
 				dynamic_cast<Constraint *>(orig_obj)->setColumnsNotNull(true);
 		}
 
@@ -787,35 +790,35 @@ void OperationList::executeOperation(Operation *oper, bool redo)
 			if the object was previously created and wants to redo the operation
 			the existing pool object will be inserted into table or in your relationship
 			on its original index */
-		else if((op_type==Operation::OBJECT_REMOVED && !redo) ||
-				(op_type==Operation::OBJECT_CREATED && redo))
+		else if((op_type==Operation::ObjectRemoved && !redo) ||
+				(op_type==Operation::ObjectCreated && redo))
 		{
 			if(aux_obj)
-				PgModelerNS::copyObject(reinterpret_cast<BaseObject **>(&object), aux_obj, obj_type);
+				PgModelerNs::copyObject(reinterpret_cast<BaseObject **>(&object), aux_obj, obj_type);
 
 			if(parent_tab)
 			{
 				parent_tab->addObject(dynamic_cast<TableObject *>(object), obj_idx);
 
-				if(object->getObjectType()==OBJ_CONSTRAINT &&
-						dynamic_cast<Constraint *>(object)->getConstraintType()==ConstraintType::foreign_key)
+				if(object->getObjectType()==ObjectType::Constraint &&
+						dynamic_cast<Constraint *>(object)->getConstraintType()==ConstraintType::ForeignKey)
 					model->updateTableFKRelationships(dynamic_cast<Table *>(parent_tab));
 			}
 			else if(parent_rel)
 				parent_rel->addObject(dynamic_cast<TableObject *>(object), obj_idx);
-			else if(object->getObjectType()==OBJ_TABLE)
-				dynamic_cast<Table *>(object)->getCodeDefinition(SchemaParser::SQL_DEFINITION);
+			else if(object->getObjectType()==ObjectType::Table)
+				dynamic_cast<Table *>(object)->getCodeDefinition(SchemaParser::SqlDefinition);
 
 			model->addObject(object, obj_idx);
 
-			if(op_type==Operation::OBJECT_REMOVED)
+			if(op_type==Operation::ObjectRemoved)
 				model->addPermissions(oper->getPermissions());
 		}
 		/* If the operation is a previously created object or if the object
 			was removed and wants to redo the operation it'll be
 			excluded from the table or relationship */
-		else if((op_type==Operation::OBJECT_CREATED && !redo) ||
-				(op_type==Operation::OBJECT_REMOVED && redo))
+		else if((op_type==Operation::ObjectCreated && !redo) ||
+				(op_type==Operation::ObjectRemoved && redo))
 		{
 			if(parent_tab)
 				parent_tab->removeObject(object);
@@ -837,14 +840,16 @@ void OperationList::executeOperation(Operation *oper, bool redo)
 				if(parent_tab->getSchema())
 					dynamic_cast<Schema *>(parent_tab->getSchema())->setModified(true);
 
-				if(object->getObjectType()==OBJ_COLUMN ||
-						object->getObjectType()==OBJ_CONSTRAINT)
+				if(object->getObjectType()==ObjectType::Column ||
+						object->getObjectType()==ObjectType::Constraint)
 				{
 					model->validateRelationships(dynamic_cast<TableObject *>(object), dynamic_cast<Table *>(parent_tab));
 
-					if(object->getObjectType()==OBJ_CONSTRAINT &&
-							dynamic_cast<Constraint *>(object)->getConstraintType()==ConstraintType::foreign_key)
+					if(object->getObjectType()==ObjectType::Constraint &&
+						 dynamic_cast<Constraint *>(object)->getConstraintType()==ConstraintType::ForeignKey)
 						model->updateTableFKRelationships(dynamic_cast<Table *>(parent_tab));
+					else if(object->getObjectType() == ObjectType::Column)
+						model->updateViewsReferencingTable(dynamic_cast<Table *>(parent_tab));
 				}
 			}
 			else if(parent_rel)
@@ -857,43 +862,41 @@ void OperationList::executeOperation(Operation *oper, bool redo)
 
 		/* If the object in question is graphical it has the modified flag
 			marked to force the redraw at the time of its restoration */
-		else if(obj_type==OBJ_TABLE || obj_type==OBJ_VIEW ||
-				obj_type==BASE_RELATIONSHIP || obj_type==OBJ_RELATIONSHIP ||
-				obj_type==OBJ_TEXTBOX || obj_type==OBJ_SCHEMA)
+		else if(BaseGraphicObject::isGraphicObject(obj_type))
 		{
 			BaseGraphicObject *graph_obj=dynamic_cast<BaseGraphicObject *>(object);
 
-			if(op_type==Operation::OBJECT_MODIFIED ||
-					op_type==Operation::OBJECT_MOVED)
+			if(op_type==Operation::ObjectModified ||
+					op_type==Operation::ObjectMoved)
 				graph_obj->setModified(true);
 
 			//Case the object is a view is necessary to update the table-view relationships on the model
-			if(obj_type==OBJ_VIEW && op_type==Operation::OBJECT_MODIFIED)
+			if(obj_type==ObjectType::View && op_type==Operation::ObjectModified)
 				model->updateViewRelationships(dynamic_cast<View *>(graph_obj));
-			else if((obj_type==OBJ_RELATIONSHIP ||
-					 (obj_type==OBJ_TABLE && model->getRelationship(dynamic_cast<BaseTable *>(object), nullptr))) &&
-					op_type==Operation::OBJECT_MODIFIED)
+			else if((obj_type==ObjectType::Relationship ||
+							(PhysicalTable::isPhysicalTable(obj_type) && model->getRelationship(dynamic_cast<BaseTable *>(object), nullptr))) &&
+							op_type==Operation::ObjectModified)
 				model->validateRelationships();
 
 			//If a object had its schema restored is necessary to update the envolved schemas
-			if((obj_type==OBJ_TABLE || obj_type==OBJ_VIEW) &&
-					((bkp_obj && graph_obj->getSchema()!=bkp_obj->getSchema() && op_type==Operation::OBJECT_MODIFIED) ||
-					 op_type==Operation::OBJECT_MOVED))
+			if(BaseTable::isBaseTable(obj_type) &&
+				 ((bkp_obj && graph_obj->getSchema()!=bkp_obj->getSchema() && op_type==Operation::ObjectModified) ||
+					op_type==Operation::ObjectMoved))
 			{
 				dynamic_cast<BaseGraphicObject *>(graph_obj->getSchema())->setModified(true);
 
 				if(bkp_obj)
-					dynamic_cast<BaseGraphicObject *>(bkp_obj->getSchema())->setModified(op_type==Operation::OBJECT_MODIFIED);
+					dynamic_cast<BaseGraphicObject *>(bkp_obj->getSchema())->setModified(op_type==Operation::ObjectModified);
 			}
 		}
-		else if(op_type==Operation::OBJECT_MODIFIED)
+		else if(op_type==Operation::ObjectModified)
 		{
-			if(obj_type==OBJ_SCHEMA)
+			if(obj_type==ObjectType::Schema)
 			{
 				model->validateSchemaRenaming(dynamic_cast<Schema *>(object), bkp_obj->getName());
 				dynamic_cast<Schema *>(object)->setModified(true);
 			}
-			else if(obj_type==OBJ_TAG)
+			else if(obj_type==ObjectType::Tag)
 			{
 				vector<BaseObject *> refs;
 				model->getObjectReferences(object, refs);
@@ -907,17 +910,17 @@ void OperationList::executeOperation(Operation *oper, bool redo)
 		}
 
 		//Case the object is a type update the tables that are referencing it
-		if(op_type==Operation::OBJECT_MODIFIED &&
-				(object->getObjectType()==OBJ_TYPE || object->getObjectType()==OBJ_DOMAIN ||
-				 object->getObjectType()==OBJ_TABLE || object->getObjectType()==OBJ_VIEW ||
-				 object->getObjectType()==OBJ_EXTENSION))
+		if(op_type==Operation::ObjectModified &&
+				(object->getObjectType()==ObjectType::Type || object->getObjectType()==ObjectType::Domain ||
+				 object->getObjectType()==ObjectType::Table || object->getObjectType()==ObjectType::ForeignTable ||
+				 object->getObjectType()==ObjectType::View || object->getObjectType()==ObjectType::Extension))
 		{
 			vector<BaseObject *> ref_objs;
 			model->getObjectReferences(object, ref_objs);
 
 			for(auto &obj : ref_objs)
 			{
-				if(obj->getObjectType()==OBJ_COLUMN)
+				if(obj->getObjectType()==ObjectType::Column)
 					dynamic_cast<Column *>(obj)->getParentTable()->setModified(true);
 			}
 		}
@@ -951,8 +954,8 @@ void OperationList::removeLastOperation(void)
 					is removed the iteration is stopped.*/
 			end=(ignore_chain ||
 				 (!ignore_chain &&
-				  (oper->getChainType()==Operation::NO_CHAIN ||
-				   oper->getChainType()==Operation::CHAIN_START)));
+				  (oper->getChainType()==Operation::NoChain ||
+				   oper->getChainType()==Operation::ChainStart)));
 
 			itr++; oper_idx--;
 		}
@@ -960,8 +963,8 @@ void OperationList::removeLastOperation(void)
 		/* If the head of chaining is removed (CHAIN_START)
 		 marks that the next element in the list is the new
 		 start of chain */
-		if(oper && oper->getChainType()==Operation::CHAIN_START)
-			next_op_chain=Operation::CHAIN_START;
+		if(oper && oper->getChainType()==Operation::ChainStart)
+			next_op_chain=Operation::ChainStart;
 
 		//Erasing the excluded operations
 		for(int i=operations.size()-1; i > oper_idx ; i--)
@@ -983,7 +986,7 @@ void OperationList::updateObjectIndex(BaseObject *object, unsigned new_idx)
 	Operation *oper=nullptr;
 
 	if(!object)
-		throw Exception(ERR_OPR_NOT_ALOC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::OprNotAllocatedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	itr=operations.begin();
 	itr_end=operations.end();
