@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,29 +22,29 @@ Operator::Operator(void)
 {
 	unsigned i;
 
-	obj_type=OBJ_OPERATOR;
+	obj_type=ObjectType::Operator;
 
-	for(i=FUNC_OPERATOR; i <= FUNC_RESTRICT; i++)
+	for(i=FuncOperator; i <= FuncRestrict; i++)
 		functions[i]=nullptr;
 
-	for(i=Operator::OPER_COMMUTATOR; i <= OPER_NEGATOR; i++)
+	for(i=Operator::OperCommutator; i <= OperNegator; i++)
 		operators[i]=nullptr;
 
 	hashes=merges=false;
-	argument_types[LEFT_ARG]=PgSQLType(QString("\"any\""));
-	argument_types[RIGHT_ARG]=PgSQLType(QString("\"any\""));
+	argument_types[LeftArg]=PgSqlType(QString("\"any\""));
+	argument_types[RightArg]=PgSqlType(QString("\"any\""));
 
-	attributes[ParsersAttributes::LEFT_TYPE]=QString();
-	attributes[ParsersAttributes::RIGHT_TYPE]=QString();
-	attributes[ParsersAttributes::COMMUTATOR_OP]=QString();
-	attributes[ParsersAttributes::NEGATOR_OP]=QString();
-	attributes[ParsersAttributes::RESTRICTION_FUNC]=QString();
-	attributes[ParsersAttributes::JOIN_FUNC]=QString();
-	attributes[ParsersAttributes::OPERATOR_FUNC]=QString();
-	attributes[ParsersAttributes::HASHES]=QString();
-	attributes[ParsersAttributes::MERGES]=QString();
-	attributes[ParsersAttributes::SIGNATURE]=QString();
-	attributes[ParsersAttributes::REF_TYPE]=QString();
+	attributes[Attributes::LeftType]=QString();
+	attributes[Attributes::RightType]=QString();
+	attributes[Attributes::CommutatorOp]=QString();
+	attributes[Attributes::NegatorOp]=QString();
+	attributes[Attributes::RestrictionFunc]=QString();
+	attributes[Attributes::JoinFunc]=QString();
+	attributes[Attributes::OperatorFunc]=QString();
+	attributes[Attributes::Hashes]=QString();
+	attributes[Attributes::Merges]=QString();
+	attributes[Attributes::Signature]=QString();
+	attributes[Attributes::RefType]=QString();
 }
 
 bool Operator::isValidName(const QString &name)
@@ -55,7 +55,7 @@ bool Operator::isValidName(const QString &name)
 	bool valid=true;
 
 	//Checks if the size of the name is valid
-	valid=(name.size() <= static_cast<int>(OBJECT_NAME_MAX_LENGTH));
+	valid=(name.size() <= static_cast<int>(ObjectNameMaxLength));
 
 	/* Checking if the name is valid according the conditions:
 		 1) The name has only the chars defined in 'valid_chars' */
@@ -82,9 +82,9 @@ bool Operator::isValidName(const QString &name)
 void Operator::setName(const QString &name)
 {
 	if(name.isEmpty())
-		throw Exception(ERR_ASG_EMPTY_NAME_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgEmptyNameObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 	else	if(!isValidName(name))
-		throw Exception(ERR_ASG_INV_NAME_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgInvalidNameObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	this->obj_name=name;
 }
@@ -92,27 +92,27 @@ void Operator::setName(const QString &name)
 void Operator::setFunction(Function *func, unsigned func_type)
 {
 	//Raises an error if the function type is invalid
-	if(func_type > FUNC_RESTRICT)
-		throw Exception(ERR_REF_FUNCTION_INV_TYPE,__PRETTY_FUNCTION__,__FILE__,__LINE__);
-	else if(func_type==FUNC_OPERATOR)
+	if(func_type > FuncRestrict)
+		throw Exception(ErrorCode::RefFunctionInvalidType,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+	else if(func_type==FuncOperator)
 	{
 		//Raises an error if the function is not allocated
 		if(!func)
-			throw Exception(Exception::getErrorMessage(ERR_ASG_NOT_ALOC_FUNCTION)
+			throw Exception(Exception::getErrorMessage(ErrorCode::AsgNotAllocatedFunction)
 							.arg(this->getName(true))
-							.arg(BaseObject::getTypeName(OBJ_OPERATOR)),
-							ERR_ASG_NOT_ALOC_FUNCTION,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+							.arg(BaseObject::getTypeName(ObjectType::Operator)),
+							ErrorCode::AsgNotAllocatedFunction,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 		/* Raises an error if the parameter count is invalid. To be used by the operator
 		 the function must own 1 or 2 parameters */
 		else if(func->getParameterCount()==0 || func->getParameterCount() > 2)
-			throw Exception(Exception::getErrorMessage(ERR_ASG_FUNC_INV_PARAM_COUNT)
+			throw Exception(Exception::getErrorMessage(ErrorCode::AsgFunctionInvalidParamCount)
 							.arg(this->getName())
-							.arg(BaseObject::getTypeName(OBJ_OPERATOR)),
-							ERR_ASG_FUNC_INV_PARAM_COUNT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+							.arg(BaseObject::getTypeName(ObjectType::Operator)),
+							ErrorCode::AsgFunctionInvalidParamCount,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 		else
 		{
 			unsigned param_count=func->getParameterCount();
-			PgSQLType param_type1=PgSQLType(QString("\"any\"")), param_type2=PgSQLType(QString("\"any\""));
+			PgSqlType param_type1=PgSqlType(QString("\"any\"")), param_type2=PgSqlType(QString("\"any\""));
 
 			//Get the function parameter to make validations
 			param_type1=func->getParameter(0).getType();
@@ -140,10 +140,10 @@ void Operator::setFunction(Function *func, unsigned func_type)
 					(param_count==1 &&
 					 ((argument_types[0]!=QString("\"any\"") && argument_types[0]!=param_type1) ||
 						(argument_types[1]!=QString("\"any\"") && argument_types[1]!=param_type1))))
-				throw Exception(Exception::getErrorMessage(ERR_ASG_FUNCTION_INV_PARAMS)
+				throw Exception(Exception::getErrorMessage(ErrorCode::AsgFunctionInvalidParameters)
 								.arg(this->getName())
-								.arg(BaseObject::getTypeName(OBJ_OPERATOR)),
-								ERR_ASG_FUNCTION_INV_PARAMS,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+								.arg(BaseObject::getTypeName(ObjectType::Operator)),
+								ErrorCode::AsgFunctionInvalidParameters,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 		}
 	}
 
@@ -151,11 +151,11 @@ void Operator::setFunction(Function *func, unsigned func_type)
 	functions[func_type]=func;
 }
 
-void Operator::setArgumentType(PgSQLType arg_type, unsigned arg_id)
+void Operator::setArgumentType(PgSqlType arg_type, unsigned arg_id)
 {
 	//Raises an error if the argument id is invalid
-	if(arg_id > RIGHT_ARG)
-		throw Exception( ERR_REF_OPER_ARG_INV_TYPE,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+	if(arg_id > RightArg)
+		throw Exception(ErrorCode::RefOperatorArgumentInvalidType,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	setCodeInvalidated(argument_types[arg_id] != arg_type);
 	argument_types[arg_id]=arg_type;
@@ -164,8 +164,8 @@ void Operator::setArgumentType(PgSQLType arg_type, unsigned arg_id)
 void Operator::setOperator(Operator *oper, unsigned op_type)
 {
 	//Raises an error if the operator type is invalid
-	if(op_type > OPER_NEGATOR)
-		throw Exception(ERR_REF_OPER_INV_TYPE,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+	if(op_type > OperNegator)
+		throw Exception(ErrorCode::RefOperatorInvalidType,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 	else
 	{
 		/* Validating the Commutator OP: According to the PostgreSQL documentation
@@ -174,26 +174,26 @@ void Operator::setOperator(Operator *oper, unsigned op_type)
 		 is being defined and its commutator operator is +*+ then the signature
 		 of the latter should be +*+ (typeB, typeA). Raises an error when this condition
 		 is not satisfied. */
-		if(oper && op_type==OPER_COMMUTATOR && argument_types[LEFT_ARG]!=oper->argument_types[RIGHT_ARG])
+		if(oper && op_type==OperCommutator && argument_types[LeftArg]!=oper->argument_types[RightArg])
 		{
-			throw Exception(Exception::getErrorMessage(ERR_ASG_INV_COM_OPEERATOR)
+			throw Exception(Exception::getErrorMessage(ErrorCode::AsgInvalidCommutatorOperator)
 							.arg(oper->getSignature(true))
 							.arg(this->getSignature(true)),
-							ERR_ASG_FUNC_INV_PARAM_COUNT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+							ErrorCode::AsgFunctionInvalidParamCount,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 		}
 		/* Validating Negator OP: According to the PostgreSQL documentation the negator
 		 operator must have its arguments as the same type of arguments from the
 		 operator to be defined. That is, if the operator !!(typeA) is being
 		 set and its negator is !*! then the signature of the latter should be !*! (typeA).
 		 Raises an error when this condition is not satisfied. */
-		else if(oper && op_type==OPER_NEGATOR &&
-				(argument_types[LEFT_ARG]!=oper->argument_types[LEFT_ARG] &&
-				 argument_types[RIGHT_ARG]!=oper->argument_types[RIGHT_ARG]))
+		else if(oper && op_type==OperNegator &&
+				(argument_types[LeftArg]!=oper->argument_types[LeftArg] &&
+				 argument_types[RightArg]!=oper->argument_types[RightArg]))
 		{
-			throw Exception(Exception::getErrorMessage(ERR_ASG_INV_NEG_OPERATOR)
+			throw Exception(Exception::getErrorMessage(ErrorCode::AsgInvalidNegatorOperator)
 							.arg(oper->getSignature(true))
 							.arg(this->getSignature(true)),
-							ERR_ASG_FUNC_INV_PARAM_COUNT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+							ErrorCode::AsgFunctionInvalidParamCount,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 		}
 
 		setCodeInvalidated(operators[op_type] != oper);
@@ -216,25 +216,25 @@ void Operator::setMerges(bool value)
 Function *Operator::getFunction(unsigned func_type)
 {
 	//Raises an error if the function type is invalid
-	if(func_type > FUNC_RESTRICT)
-		throw Exception(ERR_REF_OPER_INV_TYPE,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+	if(func_type > FuncRestrict)
+		throw Exception(ErrorCode::RefOperatorInvalidType,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	return(functions[func_type]);
 }
 
-PgSQLType Operator::getArgumentType(unsigned arg_id)
+PgSqlType Operator::getArgumentType(unsigned arg_id)
 {
 	//Raises an error if the argument id is invalid
-	if(arg_id > RIGHT_ARG)
-		throw Exception( ERR_REF_OPER_ARG_INV_TYPE,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+	if(arg_id > RightArg)
+		throw Exception(ErrorCode::RefOperatorArgumentInvalidType,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 	return(argument_types[arg_id]);
 }
 
 Operator *Operator::getOperator(unsigned op_type)
 {
 	//Raises an error if the operator type is invalid
-	if(op_type > OPER_NEGATOR)
-		throw Exception(ERR_REF_FUNCTION_INV_TYPE,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+	if(op_type > OperNegator)
+		throw Exception(ErrorCode::RefFunctionInvalidType,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	return(operators[op_type]);
 }
@@ -280,17 +280,17 @@ QString Operator::getCodeDefinition(unsigned def_type, bool reduced_form)
 	if(!code_def.isEmpty()) return(code_def);
 
 	unsigned i;
-	QString type_attribs[]={ParsersAttributes::LEFT_TYPE, ParsersAttributes::RIGHT_TYPE},
-			op_attribs[]={ ParsersAttributes::COMMUTATOR_OP,
-						   ParsersAttributes::NEGATOR_OP },
+	QString type_attribs[]={Attributes::LeftType, Attributes::RightType},
+			op_attribs[]={ Attributes::CommutatorOp,
+						   Attributes::NegatorOp },
 
-			func_attribs[]={ParsersAttributes::OPERATOR_FUNC,
-							ParsersAttributes::JOIN_FUNC,
-							ParsersAttributes::RESTRICTION_FUNC};
+			func_attribs[]={Attributes::OperatorFunc,
+							Attributes::JoinFunc,
+							Attributes::RestrictionFunc};
 
-	for(i=Operator::LEFT_ARG; i <= Operator::RIGHT_ARG; i++)
+	for(i=Operator::LeftArg; i <= Operator::RightArg; i++)
 	{
-		if(def_type==SchemaParser::SQL_DEFINITION)
+		if(def_type==SchemaParser::SqlDefinition)
 		{
 			if(argument_types[i]!=QString("\"any\""))
 				attributes[type_attribs[i]]=~argument_types[i];
@@ -298,42 +298,52 @@ QString Operator::getCodeDefinition(unsigned def_type, bool reduced_form)
 		else
 		{
 			attributes[type_attribs[i]]=argument_types[i].
-																	getCodeDefinition(SchemaParser::XML_DEFINITION,type_attribs[i]);
+																	getCodeDefinition(SchemaParser::XmlDefinition,type_attribs[i]);
 		}
 	}
 
-	for(i=Operator::OPER_COMMUTATOR; i <= Operator::OPER_NEGATOR; i++)
+	for(i=Operator::OperCommutator; i <= Operator::OperNegator; i++)
 	{
 		if(operators[i])
 		{
-			if(def_type==SchemaParser::SQL_DEFINITION)
+			if(def_type==SchemaParser::SqlDefinition)
 				attributes[op_attribs[i]]=operators[i]->getName(true);
 			else
 			{
-				operators[i]->attributes[ParsersAttributes::REF_TYPE]=op_attribs[i];
+				operators[i]->attributes[Attributes::RefType]=op_attribs[i];
 				attributes[op_attribs[i]]=operators[i]->getCodeDefinition(def_type, true);
 			}
 		}
 	}
 
-	for(i=Operator::FUNC_OPERATOR; i <= Operator::FUNC_RESTRICT; i++)
+	for(i=Operator::FuncOperator; i <= Operator::FuncRestrict; i++)
 	{
 		if(functions[i])
 		{
-			if(def_type==SchemaParser::SQL_DEFINITION)
+			if(def_type==SchemaParser::SqlDefinition)
 				attributes[func_attribs[i]]=functions[i]->getName(true);
 			else
 			{
-				functions[i]->setAttribute(ParsersAttributes::REF_TYPE, func_attribs[i]);
+				functions[i]->setAttribute(Attributes::RefType, func_attribs[i]);
 				attributes[func_attribs[i]]=functions[i]->getCodeDefinition(def_type, true);
 			}
 		}
 	}
 
-	attributes[ParsersAttributes::HASHES]=(hashes ? ParsersAttributes::_TRUE_ : QString());
-	attributes[ParsersAttributes::MERGES]=(merges ? ParsersAttributes::_TRUE_ : QString());
-	attributes[ParsersAttributes::SIGNATURE]=getSignature();
+	attributes[Attributes::Hashes]=(hashes ? Attributes::True : QString());
+	attributes[Attributes::Merges]=(merges ? Attributes::True : QString());
+	attributes[Attributes::Signature]=getSignature();
 
 	return(BaseObject::getCodeDefinition(def_type, reduced_form));
 }
 
+void Operator::configureSearchAttributes(void)
+{
+	QStringList arg_types;
+
+	BaseObject::configureSearchAttributes();
+
+	arg_types += *argument_types[0];
+	arg_types += *argument_types[1];
+	search_attribs[Attributes::Type] = arg_types.join("; ");
+}
