@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 
 OperatorClassElement::OperatorClassElement(void)
 {
-	element_type=OPERATOR_ELEM;
+	element_type=OperatorElem;
 	function=nullptr;
 	_operator=nullptr;
 	strategy_number=0;
@@ -31,11 +31,11 @@ void OperatorClassElement::setFunction(Function *func, unsigned stg_number)
 {
 	//Raises an exception case the function is not allocated
 	if(!func)
-		throw Exception(ERR_ASG_NOT_ALOC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgNotAllocattedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	//Raises an error case the stratagy number is zero (invalid)
 	else if(stg_number==0)
-		throw Exception(ERR_ASG_INV_SUPSTG_NUMBER,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgInvalidSupportStrategyNumber,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	//Clear the attributes not related to the FUNCTION element type
 	this->_operator=nullptr;
@@ -44,18 +44,18 @@ void OperatorClassElement::setFunction(Function *func, unsigned stg_number)
 	//Configure the attributes that belongs to the element type
 	this->function=func;
 	this->strategy_number=stg_number;
-	this->element_type=FUNCTION_ELEM;
+	this->element_type=FunctionElem;
 }
 
 void OperatorClassElement::setOperator(Operator *oper, unsigned stg_number)
 {
 	//Raises an error in case the operator is not allocated
 	if(!oper)
-		throw Exception(ERR_ASG_NOT_ALOC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgNotAllocattedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	//Raises an error case the stratagy number is zero (invalid)
 	else if(stg_number==0)
-		throw Exception(ERR_ASG_INV_SUPSTG_NUMBER,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgInvalidSupportStrategyNumber,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	//Clear the attributes not related to the OPERATOR element type
 	this->function=nullptr;
@@ -63,21 +63,21 @@ void OperatorClassElement::setOperator(Operator *oper, unsigned stg_number)
 	//Configure the attributes that belongs to the element type
 	this->_operator=oper;
 	this->strategy_number=stg_number;
-	this->element_type=OPERATOR_ELEM;
+	this->element_type=OperatorElem;
 }
 
 void OperatorClassElement::setOperatorFamily(OperatorFamily *op_family)
 {
-	if(this->element_type==OPERATOR_ELEM)
+	if(this->element_type==OperatorElem)
 	{
-		if(op_family && op_family->getIndexingType()!=IndexingType::btree)
-			throw Exception(ERR_ASG_INV_OPFAM_OPCLSELEM,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		if(op_family && op_family->getIndexingType()!=IndexingType::Btree)
+			throw Exception(ErrorCode::AsgInvalidOpFamilyOpClassElem,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 		this->op_family=op_family;
 	}
 }
 
-void OperatorClassElement::setStorage(PgSQLType storage)
+void OperatorClassElement::setStorage(PgSqlType storage)
 {
 	//Clear the attributes not related to the STORAGE element type
 	this->function=nullptr;
@@ -87,7 +87,7 @@ void OperatorClassElement::setStorage(PgSQLType storage)
 
 	//Configure the attributes that belongs to the element type
 	this->storage=storage;
-	this->element_type=STORAGE_ELEM;
+	this->element_type=StorageElem;
 }
 
 unsigned OperatorClassElement::getElementType(void)
@@ -110,7 +110,7 @@ OperatorFamily *OperatorClassElement::getOperatorFamily(void)
 	return(op_family);
 }
 
-PgSQLType OperatorClassElement::getStorage(void)
+PgSqlType OperatorClassElement::getStorage(void)
 {
 	return(storage);
 }
@@ -125,57 +125,57 @@ QString OperatorClassElement::getCodeDefinition(unsigned def_type)
 	SchemaParser schparser;
 	attribs_map attributes;
 
-	attributes[ParsersAttributes::TYPE]=QString();
-	attributes[ParsersAttributes::STRATEGY_NUM]=QString();
-	attributes[ParsersAttributes::SIGNATURE]=QString();
-	attributes[ParsersAttributes::FUNCTION]=QString();
-	attributes[ParsersAttributes::OPERATOR]=QString();
-	attributes[ParsersAttributes::STORAGE]=QString();
-	attributes[ParsersAttributes::OP_FAMILY]=QString();
-	attributes[ParsersAttributes::DEFINITION]=QString();
+	attributes[Attributes::Type]=QString();
+	attributes[Attributes::StrategyNum]=QString();
+	attributes[Attributes::Signature]=QString();
+	attributes[Attributes::Function]=QString();
+	attributes[Attributes::Operator]=QString();
+	attributes[Attributes::Storage]=QString();
+	attributes[Attributes::OpFamily]=QString();
+	attributes[Attributes::Definition]=QString();
 
-	if(element_type==FUNCTION_ELEM && function && strategy_number > 0)
+	if(element_type==FunctionElem && function && strategy_number > 0)
 	{
 		//FUNCTION support_number [ ( op_type [ , op_type ] ) ] funcname ( argument_type [, ...] )
-		attributes[ParsersAttributes::FUNCTION]=ParsersAttributes::_TRUE_;
-		attributes[ParsersAttributes::STRATEGY_NUM]=QString("%1").arg(strategy_number);
+		attributes[Attributes::Function]=Attributes::True;
+		attributes[Attributes::StrategyNum]=QString("%1").arg(strategy_number);
 
-		if(def_type==SchemaParser::SQL_DEFINITION)
-			attributes[ParsersAttributes::SIGNATURE]=function->getSignature();
+		if(def_type==SchemaParser::SqlDefinition)
+			attributes[Attributes::Signature]=function->getSignature();
 		else
-			attributes[ParsersAttributes::DEFINITION]=function->getCodeDefinition(def_type,true);
+			attributes[Attributes::Definition]=function->getCodeDefinition(def_type,true);
 	}
-	else if(element_type==OPERATOR_ELEM && _operator && strategy_number > 0)
+	else if(element_type==OperatorElem && _operator && strategy_number > 0)
 	{
 		//OPERATOR strategy_number operator_name [ ( op_type, op_type ) ] [ FOR SEARCH | FOR ORDER BY sort_family_name ]
-		attributes[ParsersAttributes::OPERATOR]=ParsersAttributes::_TRUE_;
-		attributes[ParsersAttributes::STRATEGY_NUM]=QString("%1").arg(strategy_number);
+		attributes[Attributes::Operator]=Attributes::True;
+		attributes[Attributes::StrategyNum]=QString("%1").arg(strategy_number);
 
-		if(def_type==SchemaParser::SQL_DEFINITION)
-			attributes[ParsersAttributes::SIGNATURE]=_operator->getSignature();
+		if(def_type==SchemaParser::SqlDefinition)
+			attributes[Attributes::Signature]=_operator->getSignature();
 		else
-			attributes[ParsersAttributes::DEFINITION]=_operator->getCodeDefinition(def_type,true);
+			attributes[Attributes::Definition]=_operator->getCodeDefinition(def_type,true);
 
 		if(op_family)
 		{
-			if(def_type==SchemaParser::SQL_DEFINITION)
-				attributes[ParsersAttributes::OP_FAMILY]=op_family->getName(true);
+			if(def_type==SchemaParser::SqlDefinition)
+				attributes[Attributes::OpFamily]=op_family->getName(true);
 			else
-				attributes[ParsersAttributes::DEFINITION]+=op_family->getCodeDefinition(def_type,true);
+				attributes[Attributes::Definition]+=op_family->getCodeDefinition(def_type,true);
 		}
 	}
-	else if(element_type==STORAGE_ELEM && storage!=PgSQLType::null)
+	else if(element_type==StorageElem && storage!=PgSqlType::Null)
 	{
 		//STORAGE storage_type
-		attributes[ParsersAttributes::STORAGE]=ParsersAttributes::_TRUE_;
+		attributes[Attributes::Storage]=Attributes::True;
 
-		if(def_type==SchemaParser::SQL_DEFINITION)
-			attributes[ParsersAttributes::TYPE]=(*storage);
+		if(def_type==SchemaParser::SqlDefinition)
+			attributes[Attributes::Type]=(*storage);
 		else
-			attributes[ParsersAttributes::DEFINITION]=storage.getCodeDefinition(def_type);
+			attributes[Attributes::Definition]=storage.getCodeDefinition(def_type);
 	}
 
-	return(schparser.getCodeDefinition(ParsersAttributes::ELEMENT,attributes, def_type));
+	return(schparser.getCodeDefinition(Attributes::Element,attributes, def_type));
 }
 
 bool OperatorClassElement::operator == (OperatorClassElement &elem)
