@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,8 +20,8 @@
 
 OperatorFamily::OperatorFamily(void)
 {
-	obj_type=OBJ_OPFAMILY;
-	attributes[ParsersAttributes::INDEX_TYPE]=QString();
+	obj_type=ObjectType::OpFamily;
+	attributes[Attributes::IndexType]=QString();
 }
 
 void OperatorFamily::setIndexingType(IndexingType idx_type)
@@ -45,8 +45,8 @@ QString OperatorFamily::getCodeDefinition(unsigned def_type, bool reduced_form)
 	QString code_def=getCachedCode(def_type, reduced_form);
 	if(!code_def.isEmpty()) return(code_def);
 
-	attributes[ParsersAttributes::SIGNATURE]=getSignature();
-	attributes[ParsersAttributes::INDEX_TYPE]=(~indexing_type);
+	attributes[Attributes::Signature]=getSignature();
+	attributes[Attributes::IndexType]=(~indexing_type);
 	return(BaseObject::getCodeDefinition(def_type,reduced_form));
 }
 
