@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,20 +25,20 @@ Reference::Reference(void)
 	this->is_def_expr=false;
 }
 
-Reference::Reference(Table *table, Column *column, const QString &tab_alias, const QString &col_alias)
+Reference::Reference(PhysicalTable *table, Column *column, const QString &tab_alias, const QString &col_alias)
 {
 	//Raises an error if the table is not allocated
 	if(!table)
-		throw Exception(ERR_ASG_NOT_ALOC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgNotAllocattedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	//Raises an error if the table/column alias has an invalid name
 	else if((!tab_alias.isEmpty() && !BaseObject::isValidName(tab_alias)) ||
-			(!col_alias.isEmpty() && !BaseObject::isValidName(col_alias)))
-		throw Exception(ERR_ASG_INV_NAME_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+					(!col_alias.isEmpty() && !BaseObject::isValidName(col_alias)))
+		throw Exception(ErrorCode::AsgInvalidNameObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	//Raises an error if the column parent table differs from the passed table
 	else if(column && column->getParentTable()!=table)
-		throw Exception(ERR_ASG_OBJ_BELONGS_OTHER_TABLE ,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgObjectBelongsAnotherTable ,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	this->table=table;
 	this->column=column;
@@ -51,10 +51,10 @@ Reference::Reference(const QString &expression, const QString &expr_alias)
 {
 	//Raises an error if the user try to create an reference using an empty expression
 	if(expression.isEmpty())
-		throw Exception(ERR_ASG_INV_EXPR_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgInvalidExpressionObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 	//Raises an error if the expression alias has an invalid name
 	else if(!expr_alias.isEmpty() && !BaseObject::isValidName(expr_alias))
-		throw Exception(ERR_ASG_INV_NAME_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgInvalidNameObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	table=nullptr;
 	column=nullptr;
@@ -65,7 +65,38 @@ Reference::Reference(const QString &expression, const QString &expr_alias)
 
 void Reference::setDefinitionExpression(bool value)
 {
-	is_def_expr=value;
+	is_def_expr = value;
+	if(!value) clearReferencedTables();
+}
+
+void Reference::addReferencedTable(PhysicalTable *ref_table)
+{
+	if(!ref_table)
+		return;
+
+	if(std::find(ref_tables.begin(), ref_tables.end(), ref_table) == ref_tables.end())
+		ref_tables.push_back(ref_table);
+}
+
+int Reference::getReferencedTableIndex(PhysicalTable *ref_table)
+{
+	int idx = -1;
+	vector<PhysicalTable *>::iterator itr = std::find(ref_tables.begin(), ref_tables.end(), ref_table);
+
+	if(itr != ref_tables.end())
+		idx = itr - ref_tables.begin();
+
+	return(idx);
+}
+
+void Reference::clearReferencedTables(void)
+{
+	ref_tables.clear();
+}
+
+vector<PhysicalTable *> Reference::getReferencedTables(void)
+{
+	return(ref_tables);
 }
 
 bool Reference::isDefinitionExpression(void)
@@ -73,7 +104,57 @@ bool Reference::isDefinitionExpression(void)
 	return(is_def_expr);
 }
 
-Table *Reference::getTable(void)
+void Reference::addColumn(const QString &name, PgSqlType type, const QString &alias)
+{
+	QString aux_name = name;
+
+	if(aux_name.startsWith(QChar('\"')) &&
+		 aux_name.endsWith(QChar('\"')))
+	{
+		aux_name.remove(0, 1);
+		aux_name.remove(aux_name.length(), 1);
+	}
+
+	// Validating the column name
+	if(!BaseObject::isValidName(name))
+	{
+		if(aux_name.isEmpty())
+			throw Exception(ErrorCode::AsgEmptyNameObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		else if(aux_name.size() > BaseObject::ObjectNameMaxLength)
+			throw Exception(ErrorCode::AsgLongNameObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		else
+			throw Exception(ErrorCode::AsgInvalidNameObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+	}
+
+	// Checking if the column already exists
+	for(auto &col : columns)
+	{
+		if(col.name == name)
+			throw Exception(ErrorCode::InsDuplicatedElement,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+	}
+
+	columns.push_back(SimpleColumn(name, *type, alias));
+}
+
+void Reference::addColumn(Column *col)
+{
+	if(!col)
+		throw Exception(ErrorCode::OprNotAllocatedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+
+	addColumn(col->getName(), col->getType(), col->getAlias());
+}
+
+void Reference::removeColumns(void)
+{
+	columns.clear();
+}
+
+vector<SimpleColumn> Reference::getColumns(void)
+{
+	return(columns);
+}
+
+PhysicalTable *Reference::getTable(void)
 {
 	return(table);
 }
@@ -101,9 +182,22 @@ QString Reference::getExpression(void)
 unsigned Reference::getReferenceType(void)
 {
 	if(expression.isEmpty())
-		return(REFER_COLUMN);
+		return(ReferColumn);
 	else
-		return(REFER_EXPRESSION);
+		return(ReferExpression);
+}
+
+void Reference::setReferenceAlias(const QString &alias)
+{
+	if(alias.size() > BaseObject::ObjectNameMaxLength)
+		throw Exception(ErrorCode::AsgLongNameObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+
+	ref_alias = alias;
+}
+
+QString Reference::getReferenceAlias(void)
+{
+	return(ref_alias);
 }
 
 QString Reference::getSQLDefinition(unsigned sql_type)
@@ -114,10 +208,10 @@ QString Reference::getSQLDefinition(unsigned sql_type)
 	refer_type=getReferenceType();
 
 	//Case the reference is between the SELECT-FROM keywords
-	if(sql_type==SQL_REFER_SELECT)
+	if(sql_type==SqlReferSelect)
 	{
 		//Case the reference is linked to a column
-		if(refer_type==REFER_COLUMN)
+		if(refer_type==ReferColumn)
 		{
 			/* Generated SQL definition:
 			[TABLE_ALIAS.]{COLUMN_NAME | *} [AS COLUMN_ALIAS] */
@@ -153,14 +247,14 @@ QString Reference::getSQLDefinition(unsigned sql_type)
 		sql_def+=QString(",\n");
 	}
 	//Case the reference is between the FROM-[JOIN | WHERE] keywords
-	else if(sql_type==SQL_REFER_FROM)
+	else if(sql_type==SqlReferFrom)
 	{
 		/* Case the reference is linked to a column only the table name is used.
 		 For expression the complete code is used thus the generated code is:
 
 		 ... FROM {TABLE_NAME} [AS ALIAS] or
 		 ... FROM {EXPRESSION} */
-		if(refer_type==REFER_COLUMN)
+		if(refer_type==ReferColumn)
 		{
 			sql_def+=table->getName(true);
 
@@ -176,7 +270,7 @@ QString Reference::getSQLDefinition(unsigned sql_type)
 	else
 	{
 		//Case the column is allocated
-		if(refer_type==REFER_COLUMN && column)
+		if(refer_type==ReferColumn && column)
 		{
 			/* Generated SQL definition:
 			... WHERE {TABLE_NAME | ALIAS}.{COLUMN_NAME} */
@@ -191,7 +285,7 @@ QString Reference::getSQLDefinition(unsigned sql_type)
 			if(column)
 				sql_def+=column->getName(true);
 		}
-		else if(refer_type==REFER_EXPRESSION)
+		else if(refer_type==ReferExpression)
 			sql_def=expression;
 	}
 
@@ -201,23 +295,45 @@ QString Reference::getSQLDefinition(unsigned sql_type)
 
 QString Reference::getXMLDefinition(void)
 {
-	attribs_map attribs;
+	attribs_map attribs, aux_attribs;
 	SchemaParser schparser;
+	Column col_aux;
+	QStringList ref_tab_names;
 
-	attribs[ParsersAttributes::TABLE]=QString();
-	attribs[ParsersAttributes::COLUMN]=QString();
+	attribs[Attributes::Table]=QString();
+	attribs[Attributes::Column]=QString();
 
 	if(table)
-		attribs[ParsersAttributes::TABLE]=table->getName(true);
+		attribs[Attributes::Table]=table->getName(true);
 
 	if(column)
-		attribs[ParsersAttributes::COLUMN]=column->getName();
+		attribs[Attributes::Column]=column->getName();
 
-	attribs[ParsersAttributes::EXPRESSION]=expression;
-	attribs[ParsersAttributes::ALIAS]=alias;
-	attribs[ParsersAttributes::COLUMN_ALIAS]=column_alias;
+	attribs[Attributes::RefAlias]=ref_alias;
+	attribs[Attributes::Expression]=expression;
+	attribs[Attributes::Alias]=alias;
+	attribs[Attributes::ColumnAlias]=column_alias;
+	attribs[Attributes::Columns]=QString();
+	attribs[Attributes::RefTables]=QString();
 
-	return(schparser.getCodeDefinition(ParsersAttributes::REFERENCE, attribs, SchemaParser::XML_DEFINITION));
+	for(auto &col : columns)
+	{
+		col_aux.setName(col.name);
+		col_aux.setType(PgSqlType::parseString(col.type));
+		col_aux.setAlias(col.alias);
+		attribs[Attributes::Columns]+=col_aux.getCodeDefinition(SchemaParser::XmlDefinition);
+	}
+
+	if(is_def_expr)
+	{
+		for(auto &tab : ref_tables)
+		{
+			aux_attribs[Attributes::Name] = tab->getSignature();
+			attribs[Attributes::RefTables] += schparser.getCodeDefinition(Attributes::RefTableTag, aux_attribs, SchemaParser::XmlDefinition);
+		}
+	}
+
+	return(schparser.getCodeDefinition(Attributes::Reference, attribs, SchemaParser::XmlDefinition));
 }
 
 bool Reference::operator == (Reference &refer)
@@ -228,7 +344,7 @@ bool Reference::operator == (Reference &refer)
 
 	if(ref_type==refer.getReferenceType())
 	{
-		if(ref_type==REFER_COLUMN)
+		if(ref_type==ReferColumn)
 		{
 			return(this->table==refer.table &&
 				   this->column==refer.column &&
