@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -42,9 +42,9 @@ class Textbox: public BaseGraphicObject{
 
 	public:
 		//! \brief Constants used to configure the text attributes
-		static const unsigned ITALIC_TXT=0,
-		BOLD_TXT=1,
-		UNDERLINE_TXT=2;
+		static constexpr unsigned ItalicText=0,
+		BoldText=1,
+		UnderlineText=2;
 
 		/*! \brief To define the content of the textboxes
 		 the method setComment() must be used and the getComment()
