@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,15 +29,15 @@
 
 class TypeAttribute: public BaseObject {
 	private:
-		PgSQLType type;
+		PgSqlType type;
 
 		QString getCodeDefinition(unsigned, bool){ return(""); }
 
 	public:
 		TypeAttribute(void);
 
-		void setType(PgSQLType type);
-		PgSQLType getType(void);
+		void setType(PgSqlType type);
+		PgSqlType getType(void);
 
 		//! \brief Returns the SQL / XML code definition for the parameter
 		virtual QString getCodeDefinition(unsigned def_type) final;
