@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ class AboutWidget: public QWidget, public Ui::AboutWidget {
 		Q_OBJECT
 		
 	public:
-		AboutWidget(QWidget *parent = 0);
+		AboutWidget(QWidget *parent = nullptr);
 		
 	signals:
 		void s_visibilityChanged(bool value);
