@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -73,7 +73,7 @@ class AppearanceConfigWidget: public BaseConfigWidget, public Ui::AppearanceConf
 		void updatePlaceholderItem(void);
 		
 	public:
-		AppearanceConfigWidget(QWidget * parent=0);
+		AppearanceConfigWidget(QWidget * parent = nullptr);
 		~AppearanceConfigWidget(void);
 		
 		void saveConfiguration(void);
