@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -50,18 +50,18 @@ void BaseConfigWidget::saveConfiguration(const QString &conf_id, map<QString, at
 	QByteArray buf;
 
 	//Configures the schema filename for the configuration
-	QString	sch_filename=GlobalAttributes::TMPL_CONFIGURATIONS_DIR +
-						 GlobalAttributes::DIR_SEPARATOR +
-						 GlobalAttributes::SCHEMAS_DIR +
-						 GlobalAttributes::DIR_SEPARATOR +
+	QString	sch_filename=GlobalAttributes::TmplConfigurationDir +
+						 GlobalAttributes::DirSeparator +
+						 GlobalAttributes::SchemasDir +
+						 GlobalAttributes::DirSeparator +
 						 conf_id +
-						 GlobalAttributes::SCHEMA_EXT,
+						 GlobalAttributes::SchemaExt,
 
 			//Cofnigures the filename for the configuration file
-			cfg_filename=GlobalAttributes::CONFIGURATIONS_DIR +
-						 GlobalAttributes::DIR_SEPARATOR +
+			cfg_filename=GlobalAttributes::ConfigurationsDir +
+						 GlobalAttributes::DirSeparator +
 						 conf_id +
-						 GlobalAttributes::CONFIGURATION_EXT;
+						 GlobalAttributes::ConfigurationExt;
 	QFile output(cfg_filename);
 	attribs_map attribs;
 	map<QString, attribs_map >::iterator itr, itr_end;
@@ -83,8 +83,8 @@ void BaseConfigWidget::saveConfiguration(const QString &conf_id, map<QString, at
 		output.open(QFile::WriteOnly);
 
 		if(!output.isOpen())
-			throw Exception(Exception::getErrorMessage(ERR_FILE_DIR_NOT_WRITTEN).arg(cfg_filename),
-							ERR_FILE_DIR_NOT_WRITTEN,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+			throw Exception(Exception::getErrorMessage(ErrorCode::FileDirectoryNotWritten).arg(cfg_filename),
+											ErrorCode::FileDirectoryNotWritten,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 		//Writes the generated configuration to the output file
 		output.write(buf.data(), buf.size());
@@ -94,8 +94,8 @@ void BaseConfigWidget::saveConfiguration(const QString &conf_id, map<QString, at
 	catch(Exception &e)
 	{
 		if(output.isOpen()) output.close();
-		throw Exception(Exception::getErrorMessage(ERR_FILE_NOT_WRITTER_INV_DEF).arg(cfg_filename),
-						ERR_FILE_NOT_WRITTER_INV_DEF,__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(Exception::getErrorMessage(ErrorCode::FileNotWrittenInvalidDefinition).arg(cfg_filename),
+										ErrorCode::FileNotWrittenInvalidDefinition,__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
@@ -104,30 +104,30 @@ void BaseConfigWidget::restoreDefaults(const QString &conf_id, bool silent)
 	QString current_file, default_file;
 
 	//Build the path to the current configuration (conf/[conf_id].conf
-	current_file=GlobalAttributes::CONFIGURATIONS_DIR +
-				 GlobalAttributes::DIR_SEPARATOR +
+	current_file=GlobalAttributes::ConfigurationsDir +
+				 GlobalAttributes::DirSeparator +
 				 conf_id +
-				 GlobalAttributes::CONFIGURATION_EXT;
+				 GlobalAttributes::ConfigurationExt;
 
 	//Build the path to the default configuration file (conf/defaults/[conf_id].conf
-	default_file=GlobalAttributes::TMPL_CONFIGURATIONS_DIR +
-				 GlobalAttributes::DIR_SEPARATOR +
-				 GlobalAttributes::DEFAULT_CONFS_DIR+
-				 GlobalAttributes::DIR_SEPARATOR +
+	default_file=GlobalAttributes::TmplConfigurationDir +
+				 GlobalAttributes::DirSeparator +
+				 GlobalAttributes::DefaultConfsDir+
+				 GlobalAttributes::DirSeparator +
 				 conf_id +
-				 GlobalAttributes::CONFIGURATION_EXT;
+				 GlobalAttributes::ConfigurationExt;
 
 	//Raises an error if the default file doesn't exists
 	if(!QFile::exists(default_file))
-		throw Exception(Exception::getErrorMessage(ERR_DEFAULT_CONFIG_NOT_REST).arg(default_file),
-						ERR_DEFAULT_CONFIG_NOT_REST,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(Exception::getErrorMessage(ErrorCode::DefaultConfigNotRestored).arg(default_file),
+										ErrorCode::DefaultConfigNotRestored,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 	else
 	{
 		bool bkp_saved = false;
 		QFileInfo fi(current_file);
 		QDir dir;
-		QString bkp_dir = fi.absolutePath() + GlobalAttributes::DIR_SEPARATOR + GlobalAttributes::CONFS_BACKUPS_DIR,
-				bkp_filename = bkp_dir + GlobalAttributes::DIR_SEPARATOR +
+		QString bkp_dir = fi.absolutePath() + GlobalAttributes::DirSeparator + GlobalAttributes::ConfsBackupsDir,
+				bkp_filename = bkp_dir + GlobalAttributes::DirSeparator +
 											 QString("%1.bkp_%2").arg(fi.fileName()).arg(QDateTime::currentDateTime().toString("yyyyMMd_hhmmss"));
 
 		dir.mkpath(bkp_dir);
@@ -137,7 +137,7 @@ void BaseConfigWidget::restoreDefaults(const QString &conf_id, bool silent)
 		if(bkp_saved && !silent)
 		{
 			Messagebox msg_box;
-			msg_box.show(trUtf8("A backup of the previous settings was saved into <strong>%1</strong>!").arg(bkp_filename), Messagebox::INFO_ICON);
+			msg_box.show(trUtf8("A backup of the previous settings was saved into <strong>%1</strong>!").arg(bkp_filename), Messagebox::InfoIcon);
 		}
 	}
 }
@@ -148,24 +148,24 @@ void BaseConfigWidget::loadConfiguration(const QString &conf_id, map<QString, at
 
 	try
 	{
-		filename = GlobalAttributes::CONFIGURATIONS_DIR +
-							 GlobalAttributes::DIR_SEPARATOR +
+		filename = GlobalAttributes::ConfigurationsDir +
+							 GlobalAttributes::DirSeparator +
 							 conf_id +
-							 GlobalAttributes::CONFIGURATION_EXT;
+							 GlobalAttributes::ConfigurationExt;
 
 		config_params.clear();
 		xmlparser.restartParser();
-		xmlparser.setDTDFile(GlobalAttributes::TMPL_CONFIGURATIONS_DIR +
-							 GlobalAttributes::DIR_SEPARATOR +
-							 GlobalAttributes::OBJECT_DTD_DIR +
-							 GlobalAttributes::DIR_SEPARATOR +
+		xmlparser.setDTDFile(GlobalAttributes::TmplConfigurationDir +
+							 GlobalAttributes::DirSeparator +
+							 GlobalAttributes::ObjectDTDDir +
+							 GlobalAttributes::DirSeparator +
 							 conf_id +
-							 GlobalAttributes::OBJECT_DTD_EXT,
+							 GlobalAttributes::ObjectDTDExt,
 							 conf_id);
 
 		xmlparser.loadXMLFile(filename);
 
-		if(xmlparser.accessElement(XMLParser::CHILD_ELEMENT))
+		if(xmlparser.accessElement(XmlParser::ChildElement))
 		{
 			do
 			{
@@ -173,10 +173,10 @@ void BaseConfigWidget::loadConfiguration(const QString &conf_id, map<QString, at
 				{
 					this->getConfigurationParams(config_params, key_attribs);
 
-					if(xmlparser.hasElement(XMLParser::CHILD_ELEMENT, XML_ELEMENT_NODE))
+					if(xmlparser.hasElement(XmlParser::ChildElement, XML_ELEMENT_NODE))
 					{
 						xmlparser.savePosition();
-						xmlparser.accessElement(XMLParser::CHILD_ELEMENT);
+						xmlparser.accessElement(XmlParser::ChildElement);
 
 						if(xmlparser.getElementType()!=XML_TEXT_NODE)
 						{
@@ -184,19 +184,19 @@ void BaseConfigWidget::loadConfiguration(const QString &conf_id, map<QString, at
 							{
 								this->getConfigurationParams(config_params, key_attribs);
 							}
-							while(xmlparser.accessElement(XMLParser::NEXT_ELEMENT));
+							while(xmlparser.accessElement(XmlParser::NextElement));
 						}
 
 						xmlparser.restorePosition();
 					}
 				}
 			}
-			while(xmlparser.accessElement(XMLParser::NEXT_ELEMENT));
+			while(xmlparser.accessElement(XmlParser::NextElement));
 		}
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e, filename);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e, filename);
 	}
 }
 
@@ -223,11 +223,11 @@ void BaseConfigWidget::getConfigurationParams(map<QString, attribs_map> &config_
 		key=xmlparser.getElementName();
 
 	//Extract the contents of the child element and create a special element on map called "_contents_"
-	if(xmlparser.hasElement(XMLParser::CHILD_ELEMENT, XML_TEXT_NODE))
+	if(xmlparser.hasElement(XmlParser::ChildElement, XML_TEXT_NODE))
 	{
 		xmlparser.savePosition();
-		xmlparser.accessElement(XMLParser::CHILD_ELEMENT);
-		aux_attribs[ParsersAttributes::CONTENTS]=xmlparser.getElementContent();
+		xmlparser.accessElement(XmlParser::ChildElement);
+		aux_attribs[Attributes::Contents]=xmlparser.getElementContent();
 		xmlparser.restorePosition();
 	}
 
