@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ BaseForm::BaseForm(QWidget *parent, Qt::WindowFlags f) : QDialog(parent, f)
 
 void BaseForm::setButtonConfiguration(unsigned button_conf)
 {
-	if(button_conf==Messagebox::OK_CANCEL_BUTTONS)
+	if(button_conf==Messagebox::OkCancelButtons)
 	{
 		apply_ok_btn->setText(trUtf8("&Apply"));
 		cancel_btn->setVisible(true);
@@ -45,16 +45,16 @@ void BaseForm::resizeForm(QWidget *widget)
 	int max_h = 0, max_w = 0, curr_w =0, curr_h = 0,
 			screen_id = qApp->desktop()->screenNumber(qApp->activeWindow());
 	QScreen *screen=qApp->screens().at(screen_id);
-	float dpi_factor = 0;
-  float pixel_ratio = 0;
+	double dpi_factor = 0;
+  double pixel_ratio = 0;
 
 	max_w = screen->size().width() * 0.70;
 	max_h = screen->size().height() * 0.70;
-	dpi_factor = screen->logicalDotsPerInch() / 96.0f;
+	dpi_factor = screen->logicalDotsPerInch() / 96.0;
   pixel_ratio = screen->devicePixelRatio();
 
-	if(dpi_factor <= 1.01f)
-		dpi_factor = 1.0f;
+	if(dpi_factor <= 1.01)
+		dpi_factor = 1.0;
 
 	vbox->setContentsMargins(2,2,2,2);
 
@@ -87,7 +87,7 @@ void BaseForm::resizeForm(QWidget *widget)
 	main_frm->setLayout(vbox);
 	this->adjustSize();
 
-	curr_h=this->height(),
+	curr_h=this->height();
 	curr_w=min_size.width();
 
 	// If the current height is greater than the widget's minimum height we will use a medium value
@@ -115,6 +115,7 @@ void BaseForm::resizeForm(QWidget *widget)
 
 	this->setMinimumSize(min_size);
 	this->resize(curr_w, curr_h);
+	this->adjustSize();
 }
 
 void BaseForm::closeEvent(QCloseEvent *)
@@ -126,17 +127,17 @@ void BaseForm::setMainWidget(BaseObjectWidget *widget)
 {
 	if(!widget)	return;
 
-	if(widget->getHandledObjectType()!=BASE_OBJECT && widget->windowTitle().isEmpty())
+	if(widget->getHandledObjectType()!=ObjectType::BaseObject && widget->windowTitle().isEmpty())
 		setWindowTitle(trUtf8("%1 properties").arg(BaseObject::getTypeName(widget->getHandledObjectType())));
 	else
 		setWindowTitle(widget->windowTitle());
 
 	apply_ok_btn->setDisabled(widget->isHandledObjectProtected());
 	resizeForm(widget);
-	setButtonConfiguration(Messagebox::OK_CANCEL_BUTTONS);
+	setButtonConfiguration(Messagebox::OkCancelButtons);
 
+	connect(cancel_btn, SIGNAL(clicked(bool)), widget, SLOT(cancelConfiguration()));
 	connect(cancel_btn, SIGNAL(clicked(bool)), this, SLOT(reject()));
-	//connect(this, SIGNAL(rejected()), widget, SLOT(cancelConfiguration()));
 	connect(apply_ok_btn, SIGNAL(clicked(bool)), widget, SLOT(applyConfiguration()));
 	connect(widget, SIGNAL(s_closeRequested()), this, SLOT(accept()));
 }
@@ -147,7 +148,7 @@ void BaseForm::setMainWidget(QWidget *widget)
 
 	setWindowTitle(widget->windowTitle());
 	resizeForm(widget);
-	setButtonConfiguration(Messagebox::OK_BUTTON);
+	setButtonConfiguration(Messagebox::OkButton);
 
 	connect(cancel_btn, SIGNAL(clicked(bool)), this, SLOT(reject()));
 	connect(apply_ok_btn, SIGNAL(clicked(bool)), this, SLOT(accept()));
