@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -45,9 +45,9 @@ class BaseForm: public QDialog, public Ui::BaseForm {
 		void closeEvent(QCloseEvent *);
 
 	public:
-		BaseForm(QWidget * parent = 0, Qt::WindowFlags f = 0);
+		BaseForm(QWidget * parent = nullptr, Qt::WindowFlags f = Qt::Widget);
 
-		void setButtonConfiguration(unsigned button_conf=Messagebox::OK_CANCEL_BUTTONS);
+		void setButtonConfiguration(unsigned button_conf=Messagebox::OkCancelButtons);
 
 		/*! \brief Injects the specified object into the form and turns it the main widget.
 				The widget is reparented to the stack widget within the form */
