@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,27 +33,31 @@
 #include "ui_baseobjectwidget.h"
 #include "pgsqltypewidget.h"
 #include "pgmodeleruins.h"
+#include "hinttextwidget.h"
 
 /* Declaring the PgSQLType class as a Qt metatype in order to permit
 	 that instances of the class be used as data of QVariant and QMetaType */
 #include <QMetaType>
-Q_DECLARE_METATYPE(PgSQLType)
+Q_DECLARE_METATYPE(PgSqlType)
 
 class BaseObjectWidget: public QWidget, public Ui::BaseObjectWidget {
 	private:
 		Q_OBJECT
 		
 	protected:
-		static const int MAX_OBJECT_SIZE=16777215;
-		static const QColor PROT_LINE_BGCOLOR,
-		PROT_LINE_FGCOLOR,
-		RELINC_LINE_BGCOLOR,
-		RELINC_LINE_FGCOLOR;
+		static constexpr int MaxObjectSize=16777215;
+
+		static const QColor ProtRowBgColor,
+		ProtRowFgColor,
+		RelAddedRowBgColor,
+		RelAddedRowFgColor;
 
 		bool object_protected;
 
 		QHBoxLayout *misc_btns_lt;
 
+		HintTextWidget *alias_ht;
+
 		//! \brief Store the kind of object being handled by the widget (configured in the constructor)
 		ObjectType handled_obj_type;
 		
@@ -102,7 +106,7 @@ class BaseObjectWidget: public QWidget, public Ui::BaseObjectWidget {
 		
 		/*! \brief Merges the specified grid layout with the 'baseobject_grid' creating a single form.
 			The obj_type parameter must be specified to show the object type icon */
-		void configureFormLayout(QGridLayout *grid=nullptr, ObjectType obj_type=BASE_OBJECT);
+		void configureFormLayout(QGridLayout *grid=nullptr, ObjectType obj_type=ObjectType::BaseObject);
 		
 		/*! \brief Starts a object configuration, alocating a new one if necessary, registering
 			the object on the operation list. This method doens't applies to database model edition */
@@ -120,25 +124,27 @@ class BaseObjectWidget: public QWidget, public Ui::BaseObjectWidget {
 		
 		void setAttributes(DatabaseModel *model, OperationList *op_list,
 						   BaseObject *object, BaseObject *parent_obj=nullptr,
-						   double obj_px=NAN, double obj_py=NAN, bool uses_op_list=true);
+						   double obj_px=DNaN, double obj_py=DNaN, bool uses_op_list=true);
 		
 		/*! \brief This method is a simplification of the original setAttributes. This method must be used
 		only on forms that does not make use of operaton list and not treat graphical objects, since it calls
-		this original one whit the op_list=nullptr and obj_px=NAN, obj_py=NAN */
+		this original one whit the op_list=nullptr and obj_px=DoubleNaN, obj_py=DoubleNaN */
 		void setAttributes(DatabaseModel *model, BaseObject *object, BaseObject *parent_obj);
 		
 		//! \brief Disable the object's refereces SQL code
 		void disableReferencesSQL(BaseObject *object);
 		
 		void configureTabOrder(vector<QWidget *> widgets={});
+
+		BaseObject *getHandledObject(void);
 			
 	public:
 		//! \brief Constants used to generate version intervals for version alert frame
-		static const unsigned UNTIL_VERSION=0,
-		VERSIONS_INTERVAL=1,
-		AFTER_VERSION=2;
+		static constexpr unsigned UntilVersion=0,
+		VersionsInterval=1,
+		AfterVersion=2;
 		
-		BaseObjectWidget(QWidget * parent = 0, ObjectType obj_type=BASE_OBJECT);
+		BaseObjectWidget(QWidget * parent = nullptr, ObjectType obj_type=ObjectType::BaseObject);
 		
 		virtual ~BaseObjectWidget(void);
 		
@@ -189,6 +195,7 @@ class BaseObjectWidget: public QWidget, public Ui::BaseObjectWidget {
 		void s_closeRequested(void);
 
 	friend class BaseForm;
+	friend class ModelWidget;
 };
 
 template<class Class>
@@ -200,12 +207,12 @@ void BaseObjectWidget::startConfiguration(void)
 		
 		//! \brief If the object is already allocated
 		if(this->object && op_list &&
-				this->object->getObjectType()!=OBJ_DATABASE)
+				this->object->getObjectType()!=ObjectType::Database)
 		{
 			if(this->table)
-				op_list->registerObject(this->object, Operation::OBJECT_MODIFIED, -1, this->table);
+				op_list->registerObject(this->object, Operation::ObjectModified, -1, this->table);
 			else
-				op_list->registerObject(this->object, Operation::OBJECT_MODIFIED, -1, this->relationship);
+				op_list->registerObject(this->object, Operation::ObjectModified, -1, this->relationship);
 			new_object=false;
 		}
 		//! \brief If there is need to allocate the object
@@ -218,7 +225,7 @@ void BaseObjectWidget::startConfiguration(void)
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
