@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ class BulkDataEditWidget: public QWidget, public Ui::BulkDataEditWidget {
 		void showEvent(QShowEvent *);
 
 	public:
-		BulkDataEditWidget(QWidget *parent = 0);
+		BulkDataEditWidget(QWidget *parent = nullptr);
 };
 
 #endif
