@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,11 +18,10 @@
 
 #include "castwidget.h"
 
-CastWidget::CastWidget(QWidget *parent): BaseObjectWidget(parent, OBJ_CAST)
+CastWidget::CastWidget(QWidget *parent): BaseObjectWidget(parent, ObjectType::Cast)
 {
 	try
 	{
-		QFont font;
 		QFrame *frame=nullptr;
 		QSpacerItem *spacer=new QSpacerItem(10,1,QSizePolicy::Fixed,QSizePolicy::Expanding);
 
@@ -30,18 +29,13 @@ CastWidget::CastWidget(QWidget *parent): BaseObjectWidget(parent, OBJ_CAST)
 
 		src_datatype=new PgSQLTypeWidget(this, trUtf8("Source data type"));
 		trg_datatype=new PgSQLTypeWidget(this, trUtf8("Target data type"));
-		conv_func_sel=new ObjectSelectorWidget(OBJ_FUNCTION, true, this);
+		conv_func_sel=new ObjectSelectorWidget(ObjectType::Function, true, this);
 
 		cast_grid->addWidget(conv_func_sel,1,1,1,4);
 		cast_grid->addWidget(src_datatype,2,0,1,5);
 		cast_grid->addWidget(trg_datatype,3,0,1,5);
 
-		configureFormLayout(cast_grid, OBJ_CAST);
-
-		name_edt->setReadOnly(true);
-		font=name_edt->font();
-		font.setItalic(true);
-		name_edt->setFont(font);
+		configureFormLayout(cast_grid, ObjectType::Cast);
 
 		frame=generateInformationFrame(trUtf8("The function to be assigned to a cast from <em><strong>typeA</strong></em> to <em><strong>typeB</strong></em> must have the following signature: <em><strong>typeB</strong> function(<strong>typeA</strong>, integer, boolean)</em>."));
 		cast_grid->addItem(spacer, cast_grid->count()+1, 0, 1, 0);
@@ -58,27 +52,27 @@ CastWidget::CastWidget(QWidget *parent): BaseObjectWidget(parent, OBJ_CAST)
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
 void CastWidget::setAttributes(DatabaseModel *model, OperationList *op_list, Cast *cast)
 {
-	PgSQLType src_type, trg_type;
+	PgSqlType src_type, trg_type;
 
 	BaseObjectWidget::setAttributes(model, op_list, cast);
 	conv_func_sel->setModel(model);
 
 	if(cast)
 	{
-		src_type=cast->getDataType(Cast::SRC_TYPE);
-		trg_type=cast->getDataType(Cast::DST_TYPE);
+		src_type=cast->getDataType(Cast::SrcType);
+		trg_type=cast->getDataType(Cast::DstType);
 
 		conv_func_sel->setSelectedObject(cast->getCastFunction());
 		input_output_chk->setChecked(cast->isInOut());
-		explicit_rb->setChecked(cast->getCastType()==Cast::EXPLICIT);
-		implicit_rb->setChecked(cast->getCastType()==Cast::IMPLICIT);
-		assignment_rb->setChecked(cast->getCastType()==Cast::ASSIGNMENT);
+		explicit_rb->setChecked(cast->getCastType()==Cast::Explicit);
+		implicit_rb->setChecked(cast->getCastType()==Cast::Implicit);
+		assignment_rb->setChecked(cast->getCastType()==Cast::Assignment);
 	}
 
 	src_datatype->setAttributes(src_type,model);
@@ -94,16 +88,16 @@ void CastWidget::applyConfiguration(void)
 		startConfiguration<Cast>();
 
 		cast=dynamic_cast<Cast *>(this->object);
-		cast->setDataType(Cast::SRC_TYPE, src_datatype->getPgSQLType());
-		cast->setDataType(Cast::DST_TYPE, trg_datatype->getPgSQLType());
+		cast->setDataType(Cast::SrcType, src_datatype->getPgSQLType());
+		cast->setDataType(Cast::DstType, trg_datatype->getPgSQLType());
 		cast->setInOut(input_output_chk->isChecked());
 
 		if(implicit_rb->isChecked())
-			cast->setCastType(Cast::IMPLICIT);
+			cast->setCastType(Cast::Implicit);
 		else if(assignment_rb->isChecked())
-			cast->setCastType(Cast::ASSIGNMENT);
+			cast->setCastType(Cast::Assignment);
 		else
-			cast->setCastType(Cast::EXPLICIT);
+			cast->setCastType(Cast::Explicit);
 
 		cast->setCastFunction(dynamic_cast<Function*>(conv_func_sel->getSelectedObject()));
 
@@ -113,7 +107,7 @@ void CastWidget::applyConfiguration(void)
 	catch(Exception &e)
 	{
 		cancelConfiguration();
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
