@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
 #include "collationwidget.h"
 
-CollationWidget::CollationWidget(QWidget *parent): BaseObjectWidget(parent, OBJ_COLLATION)
+CollationWidget::CollationWidget(QWidget *parent): BaseObjectWidget(parent, ObjectType::Collation)
 {
 	try
 	{
@@ -32,7 +32,7 @@ CollationWidget::CollationWidget(QWidget *parent): BaseObjectWidget(parent, OBJ_
 		collation_grid->addItem(new QSpacerItem(10,10, QSizePolicy::Minimum,QSizePolicy::Expanding), collation_grid->count()+1, 0, 1, 0);
 		collation_grid->addWidget(frame, collation_grid->count()+1, 0, 1, 0);
 		frame->setParent(this);
-		configureFormLayout(collation_grid, OBJ_COLLATION);
+		configureFormLayout(collation_grid, ObjectType::Collation);
 
 		//Configures the encoding combobox
 		EncodingType::getTypes(encodings);
@@ -66,7 +66,7 @@ CollationWidget::CollationWidget(QWidget *parent): BaseObjectWidget(parent, OBJ_
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
@@ -88,10 +88,10 @@ void CollationWidget::setAttributes(DatabaseModel *model, OperationList *op_list
 
 			if(locale_cmb->currentIndex()==0)
 			{
-				idx=lcctype_cmb->findText(collation->getLocalization(Collation::_LC_CTYPE));
+				idx=lcctype_cmb->findText(collation->getLocalization(Collation::LcCtype));
 				lcctype_cmb->setCurrentIndex(idx < 0 ? 0 : idx);
 
-				idx=lccollate_cmb->findText(collation->getLocalization(Collation::_LC_COLLATE));
+				idx=lccollate_cmb->findText(collation->getLocalization(Collation::LcCollate));
 				lccollate_cmb->setCurrentIndex(idx < 0 ? 0 : idx);
 			}
 		}
@@ -160,16 +160,16 @@ void CollationWidget::applyConfiguration(void)
 			collation->setLocale(locale_cmb->currentText());
 
 		if(lccollate_cmb->currentIndex() > 0)
-			collation->setLocalization(Collation::_LC_COLLATE, lccollate_cmb->currentText());
+			collation->setLocalization(Collation::LcCollate, lccollate_cmb->currentText());
 
 		if(lcctype_cmb->currentIndex() > 0)
-			collation->setLocalization(Collation::_LC_CTYPE, lcctype_cmb->currentText());
+			collation->setLocalization(Collation::LcCtype, lcctype_cmb->currentText());
 
 		finishConfiguration();
 	}
 	catch(Exception &e)
 	{
 		cancelConfiguration();
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
