@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -53,9 +53,9 @@ class ColorPickerWidget: public QWidget, public Ui::ColorPickerWidget {
 		bool eventFilter(QObject *object, QEvent *event);
 		
 	public:
-		static const int MAX_COLOR_BUTTONS=20;
+		static constexpr int MaxColorButtons=20;
 		
-		explicit ColorPickerWidget(int color_count, QWidget * parent = 0);
+		explicit ColorPickerWidget(int color_count, QWidget * parent = nullptr);
 		
 		void setColor(int color_idx, const QColor &color);
 		QColor getColor(int color_idx);
