@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,12 +36,14 @@ class ColumnWidget: public BaseObjectWidget, public Ui::ColumnWidget {
 		SyntaxHighlighter *hl_default_value;
 		PgSQLTypeWidget *data_type;
 		ObjectSelectorWidget *sequence_sel;
+		Sequence ident_col_seq;
 
 	public:
-		ColumnWidget(QWidget * parent = 0);
+		ColumnWidget(QWidget * parent = nullptr);
 		void setAttributes(DatabaseModel *model, OperationList *op_list, BaseObject *parent_obj, Column *column);
 		
 	private slots:
+		void editSequenceAttributes(void);
 		
 	public slots:
 		void applyConfiguration(void);
