@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,10 +30,10 @@ ConfigurationForm::ConfigurationForm(QWidget *parent, Qt::WindowFlags f) : QDial
 	plugins_conf=new PluginsConfigWidget(this);
 
 	QWidgetList wgt_list={ general_conf, relationships_conf,
-						   appearance_conf, connections_conf,
-						   snippets_conf, plugins_conf};
+												 appearance_conf, connections_conf,
+												 snippets_conf, plugins_conf};
 
-	for(int i=GENERAL_CONF_WGT; i <= PLUGINS_CONF_WGT; i++)
+	for(int i=GeneralConfWgt; i <= PluginsConfWgt; i++)
 		confs_stw->addWidget(wgt_list[i]);
 
 	connect(icons_lst, SIGNAL(currentRowChanged(int)), confs_stw, SLOT(setCurrentIndex(int)));
@@ -41,7 +41,8 @@ ConfigurationForm::ConfigurationForm(QWidget *parent, Qt::WindowFlags f) : QDial
 	connect(apply_btn, SIGNAL(clicked(void)), this, SLOT(applyConfiguration(void)));
 	connect(defaults_btn, SIGNAL(clicked(void)), this, SLOT(restoreDefaults(void)));
 
-	icons_lst->setCurrentRow(GENERAL_CONF_WGT);
+	icons_lst->setCurrentRow(GeneralConfWgt);
+	setMinimumSize(890, 740);
 }
 
 ConfigurationForm::~ConfigurationForm(void)
@@ -51,7 +52,7 @@ ConfigurationForm::~ConfigurationForm(void)
 
 void ConfigurationForm::hideEvent(QHideEvent *)
 {
-	icons_lst->setCurrentRow(GENERAL_CONF_WGT);
+	icons_lst->setCurrentRow(GeneralConfWgt);
 }
 
 void ConfigurationForm::showEvent(QShowEvent *)
@@ -86,8 +87,9 @@ void ConfigurationForm::reject(void)
 void ConfigurationForm::applyConfiguration(void)
 {
 	BaseConfigWidget *conf_wgt=nullptr;
+	bool curr_escape_comments = BaseObject::isEscapeComments();
 
-	for(int i=GENERAL_CONF_WGT; i <= SNIPPETS_CONF_WGT; i++)
+	for(int i=GeneralConfWgt; i <= SnippetsConfWgt; i++)
 	{
 		conf_wgt=qobject_cast<BaseConfigWidget *>(confs_stw->widget(i));
 
@@ -98,6 +100,9 @@ void ConfigurationForm::applyConfiguration(void)
 	general_conf->applyConfiguration();
 	relationships_conf->applyConfiguration();
 
+	if(curr_escape_comments != BaseObject::isEscapeComments())
+		emit s_invalidateModelsRequested();
+
 	QDialog::accept();
 }
 
@@ -105,7 +110,7 @@ void ConfigurationForm::loadConfiguration(void)
 {
 	BaseConfigWidget *config_wgt = nullptr;
 
-	for(int i=GENERAL_CONF_WGT; i <= PLUGINS_CONF_WGT; i++)
+	for(int i=GeneralConfWgt; i <= PluginsConfWgt; i++)
 	{
 		try
 		{
@@ -116,15 +121,15 @@ void ConfigurationForm::loadConfiguration(void)
 		{
 			Messagebox msg_box;
 
-			if(e.getErrorType()==ERR_PLUGINS_NOT_LOADED)
+			if(e.getErrorCode()==ErrorCode::PluginsNotLoaded)
 			{
 				msg_box.show(e);
 			}
 			else
 			{
-				Exception ex = Exception(Exception::getErrorMessage(ERR_CONFIG_NOT_LOADED).arg(e.getExtraInfo()),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+				Exception ex = Exception(Exception::getErrorMessage(ErrorCode::ConfigurationNotLoaded).arg(e.getExtraInfo()),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 				msg_box.show(ex, QString("%1 %2").arg(ex.getErrorMessage()).arg(trUtf8("In some cases restore the default settings related to it may solve the problem. Would like to do that?")),
-										 Messagebox::ALERT_ICON, Messagebox::YES_NO_BUTTONS, trUtf8("Restore"), QString(), QString(), PgModelerUiNS::getIconPath("atualizar"));
+										 Messagebox::AlertIcon, Messagebox::YesNoButtons, trUtf8("Restore"), QString(), QString(), PgModelerUiNs::getIconPath("atualizar"));
 
 				if(msg_box.result() == QDialog::Accepted)
 					config_wgt->restoreDefaults();
@@ -137,8 +142,8 @@ void ConfigurationForm::restoreDefaults(void)
 {
 	Messagebox msg_box;
 	msg_box.show(trUtf8("Any modification made until now in the current section will be lost! Do you really want to restore default settings?"),
-				 Messagebox::CONFIRM_ICON,
-				 Messagebox::YES_NO_BUTTONS);
+				 Messagebox::ConfirmIcon,
+				 Messagebox::YesNoButtons);
 
 	if(msg_box.result()==QDialog::Accepted)
 		qobject_cast<BaseConfigWidget *>(confs_stw->currentWidget())->restoreDefaults();
