@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
 #include "constraintwidget.h"
 
-ConstraintWidget::ConstraintWidget(QWidget *parent): BaseObjectWidget(parent, OBJ_CONSTRAINT)
+ConstraintWidget::ConstraintWidget(QWidget *parent): BaseObjectWidget(parent, ObjectType::Constraint)
 {
 	try
 	{
@@ -29,45 +29,45 @@ ConstraintWidget::ConstraintWidget(QWidget *parent): BaseObjectWidget(parent, OB
 
 		Ui_ConstraintWidget::setupUi(this);
 
-		excl_elems_wgt=new ElementsWidget(this);
+		excl_elems_tab=new ElementsTableWidget(this);
 		grid=new QGridLayout;
 		grid->setContentsMargins(4,4,4,4);
-		grid->addWidget(excl_elems_wgt,0,0);
+		grid->addWidget(excl_elems_tab,0,0);
 		excl_elems_grp->setLayout(grid);
 
 		expression_hl=new SyntaxHighlighter(expression_txt, false, true);
-		expression_hl->loadConfiguration(GlobalAttributes::SQL_HIGHLIGHT_CONF_PATH);
+		expression_hl->loadConfiguration(GlobalAttributes::SQLHighlightConfPath);
 
-		columns_tab=new ObjectsTableWidget(ObjectsTableWidget::ALL_BUTTONS ^
-										  (ObjectsTableWidget::EDIT_BUTTON |
-											 ObjectsTableWidget::UPDATE_BUTTON |
-											 ObjectsTableWidget::DUPLICATE_BUTTON), true, this);
+		columns_tab=new ObjectsTableWidget(ObjectsTableWidget::AllButtons ^
+										  (ObjectsTableWidget::EditButton |
+											 ObjectsTableWidget::UpdateButton |
+											 ObjectsTableWidget::DuplicateButton), true, this);
 
-		ref_columns_tab=new ObjectsTableWidget(ObjectsTableWidget::ALL_BUTTONS ^
-											  (ObjectsTableWidget::EDIT_BUTTON |
-												 ObjectsTableWidget::UPDATE_BUTTON |
-												ObjectsTableWidget::DUPLICATE_BUTTON), true, this);
+		ref_columns_tab=new ObjectsTableWidget(ObjectsTableWidget::AllButtons ^
+											  (ObjectsTableWidget::EditButton |
+												 ObjectsTableWidget::UpdateButton |
+												ObjectsTableWidget::DuplicateButton), true, this);
 
-		ref_table_sel=new ObjectSelectorWidget(OBJ_TABLE, true, this);
+		ref_table_sel=new ObjectSelectorWidget(ObjectType::Table, true, this);
 
 		columns_tab->setColumnCount(2);
 		columns_tab->setHeaderLabel(trUtf8("Column"), 0);
-		columns_tab->setHeaderIcon(QPixmap(PgModelerUiNS::getIconPath("column")),0);
+		columns_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("column")),0);
 		columns_tab->setHeaderLabel(trUtf8("Type"), 1);
-		columns_tab->setHeaderIcon(QPixmap(PgModelerUiNS::getIconPath("usertype")),1);
+		columns_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("usertype")),1);
 
 		ref_columns_tab->setEnabled(false);
 		ref_columns_tab->setColumnCount(2);
 		ref_columns_tab->setHeaderLabel(trUtf8("Column"), 0);
-		ref_columns_tab->setHeaderIcon(QPixmap(PgModelerUiNS::getIconPath("column")),0);
+		ref_columns_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("column")),0);
 		ref_columns_tab->setHeaderLabel(trUtf8("Type"), 1);
-		ref_columns_tab->setHeaderIcon(QPixmap(PgModelerUiNS::getIconPath("usertype")),1);
+		ref_columns_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("usertype")),1);
 
 		dynamic_cast<QGridLayout *>(columns_tbw->widget(0)->layout())->addWidget(columns_tab, 1,0,1,3);
 		dynamic_cast<QGridLayout *>(columns_tbw->widget(1)->layout())->addWidget(ref_table_sel, 0,1,1,2);
 		dynamic_cast<QGridLayout *>(columns_tbw->widget(1)->layout())->addWidget(ref_columns_tab, 3,0,1,3);
 
-		configureFormLayout(constraint_grid, OBJ_CONSTRAINT);
+		configureFormLayout(constraint_grid, ObjectType::Constraint);
 
 		ConstraintType::getTypes(list);
 		constr_type_cmb->addItems(list);
@@ -89,9 +89,9 @@ ConstraintWidget::ConstraintWidget(QWidget *parent): BaseObjectWidget(parent, OB
 		constraint_grid->addWidget(info_frm, constraint_grid->count()+1, 0, 1, 0);
 		info_frm->setParent(this);
 
-		fields_map[generateVersionsInterval(AFTER_VERSION, PgSQLVersions::PGSQL_VERSION_92)].push_back(no_inherit_lbl);
-		fields_map[generateVersionsInterval(AFTER_VERSION, PgSQLVersions::PGSQL_VERSION_95)].push_back(indexing_chk);
-		values_map[indexing_chk].push_back(~IndexingType(IndexingType::brin));
+		fields_map[generateVersionsInterval(AfterVersion, PgSqlVersions::PgSqlVersion92)].push_back(no_inherit_lbl);
+		fields_map[generateVersionsInterval(AfterVersion, PgSqlVersions::PgSqlVersion95)].push_back(indexing_chk);
+		values_map[indexing_chk].push_back(~IndexingType(IndexingType::Brin));
 
 		warn_frm=generateVersionWarningFrame(fields_map, &values_map);
 		constraint_grid->addWidget(warn_frm, constraint_grid->count()+1, 0, 1, 0);
@@ -119,7 +119,7 @@ ConstraintWidget::ConstraintWidget(QWidget *parent): BaseObjectWidget(parent, OB
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
@@ -137,13 +137,13 @@ void ConstraintWidget::addColumn(int row)
 		{
 			aux_col_tab=columns_tab;
 			combo=column_cmb;
-			col_id=Constraint::SOURCE_COLS;
+			col_id=Constraint::SourceCols;
 		}
 		else
 		{
 			aux_col_tab=ref_columns_tab;
 			combo=ref_column_cmb;
-			col_id=Constraint::REFERENCED_COLS;
+			col_id=Constraint::ReferencedCols;
 		}
 
 		//Gets the reference to the selected column
@@ -156,29 +156,29 @@ void ConstraintWidget::addColumn(int row)
 		addColumn(column, col_id, row);
 
 		//When there is no items con the combo the insert button of the table is disabled
-		aux_col_tab->setButtonsEnabled(ObjectsTableWidget::ADD_BUTTON, (combo->count()!=0));
+		aux_col_tab->setButtonsEnabled(ObjectsTableWidget::AddButton, (combo->count()!=0));
 	}
 	catch(Exception &e)
 	{
 		aux_col_tab->removeRow(row);
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
 void ConstraintWidget::removeColumn(int)
 {
 	if(sender()==columns_tab)
-		updateColumnsCombo(Constraint::SOURCE_COLS);
+		updateColumnsCombo(Constraint::SourceCols);
 	else
-		updateColumnsCombo(Constraint::REFERENCED_COLS);
+		updateColumnsCombo(Constraint::ReferencedCols);
 }
 
 void ConstraintWidget::removeColumns(void)
 {
 	if(sender()==columns_tab)
-		updateColumnsCombo(Constraint::SOURCE_COLS);
+		updateColumnsCombo(Constraint::SourceCols);
 	else
-		updateColumnsCombo(Constraint::REFERENCED_COLS);
+		updateColumnsCombo(Constraint::ReferencedCols);
 }
 
 void ConstraintWidget::addColumn(Column *column, unsigned col_id, int row)
@@ -187,7 +187,7 @@ void ConstraintWidget::addColumn(Column *column, unsigned col_id, int row)
 
 	if(column && row >= 0)
 	{
-		if(col_id==Constraint::SOURCE_COLS)
+		if(col_id==Constraint::SourceCols)
 			table_wgt=columns_tab;
 		else
 			table_wgt=ref_columns_tab;
@@ -204,9 +204,9 @@ void ConstraintWidget::addColumn(Column *column, unsigned col_id, int row)
 			fonte.setItalic(true);
 
 			if(column->isProtected())
-				table_wgt->setRowFont(row, fonte, PROT_LINE_FGCOLOR, PROT_LINE_BGCOLOR);
+				table_wgt->setRowFont(row, fonte, ProtRowFgColor, ProtRowBgColor);
 			else
-				table_wgt->setRowFont(row, fonte, RELINC_LINE_FGCOLOR, RELINC_LINE_BGCOLOR);
+				table_wgt->setRowFont(row, fonte, RelAddedRowFgColor, RelAddedRowBgColor);
 		}
 	}
 }
@@ -215,14 +215,14 @@ void ConstraintWidget::updateColumnsCombo(unsigned col_id)
 {
 	ObjectsTableWidget *aux_col_tab=nullptr;
 	Column *column=nullptr;
-	Table *table=nullptr;
+	PhysicalTable *table=nullptr;
 	QComboBox *combo=nullptr;
 	Relationship *rel=nullptr;
 	unsigned i, count=0;
 
 	try
 	{
-		if(col_id==Constraint::SOURCE_COLS)
+		if(col_id==Constraint::SourceCols)
 		{
 			combo=column_cmb;
 			aux_col_tab=columns_tab;
@@ -231,7 +231,7 @@ void ConstraintWidget::updateColumnsCombo(unsigned col_id)
 			means that the column is from a table */
 			if(!this->relationship)
 			{
-				table=dynamic_cast<Table *>(this->table);
+				table=dynamic_cast<PhysicalTable *>(this->table);
 				count=table->getColumnCount();
 			}
 			else
@@ -244,7 +244,7 @@ void ConstraintWidget::updateColumnsCombo(unsigned col_id)
 		{
 			combo=ref_column_cmb;
 			aux_col_tab=ref_columns_tab;
-			table=dynamic_cast<Table *>(ref_table_sel->getSelectedObject());
+			table=dynamic_cast<PhysicalTable *>(ref_table_sel->getSelectedObject());
 
 			if(table)
 				count=table->getColumnCount();
@@ -267,11 +267,11 @@ void ConstraintWidget::updateColumnsCombo(unsigned col_id)
 							   QString(")"), QVariant::fromValue<void *>(column));
 		}
 
-		aux_col_tab->setButtonsEnabled(ObjectsTableWidget::ADD_BUTTON, (combo->count()!=0));
+		aux_col_tab->setButtonsEnabled(ObjectsTableWidget::AddButton, (combo->count()!=0));
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
@@ -279,18 +279,20 @@ void ConstraintWidget::selectReferencedTable(void)
 {
 	Table *table=dynamic_cast<Table *>(ref_table_sel->getSelectedObject());
 
-	if(!table)
+	if(!table || (this->object && dynamic_cast<Constraint *>(this->object)->getReferencedTable() != table))
 	{
-		ref_column_cmb->clear();
 		ref_columns_tab->blockSignals(true);
 		ref_columns_tab->removeRows();
 		ref_columns_tab->setEnabled(false);
 		ref_columns_tab->blockSignals(false);
 	}
+
+	if(!table)
+		ref_column_cmb->clear();
 	else
 	{
 		ref_columns_tab->setEnabled(true);
-		updateColumnsCombo(Constraint::REFERENCED_COLS);
+		updateColumnsCombo(Constraint::ReferencedCols);
 	}
 }
 
@@ -298,48 +300,45 @@ void ConstraintWidget::selectConstraintType(void)
 {
 	ConstraintType constr_type=ConstraintType(constr_type_cmb->currentText());
 
-	tablespace_lbl->setVisible(constr_type==ConstraintType::primary_key || constr_type==ConstraintType::unique);
-	tablespace_sel->setVisible(constr_type==ConstraintType::primary_key || constr_type==ConstraintType::unique);
+	tablespace_lbl->setVisible(constr_type==ConstraintType::PrimaryKey || constr_type==ConstraintType::Unique);
+	tablespace_sel->setVisible(constr_type==ConstraintType::PrimaryKey || constr_type==ConstraintType::Unique);
 
 	if(!tablespace_sel->isVisible()) tablespace_sel->clearSelector();
 
-	expression_lbl->setVisible(constr_type==ConstraintType::check || constr_type==ConstraintType::exclude);
-	expression_txt->setVisible(constr_type==ConstraintType::check || constr_type==ConstraintType::exclude);
-	no_inherit_chk->setVisible(constr_type==ConstraintType::check);
-	no_inherit_lbl->setVisible(constr_type==ConstraintType::check);
-	warn_frm->setVisible(constr_type==ConstraintType::check);
+	expression_lbl->setVisible(constr_type==ConstraintType::Check || constr_type==ConstraintType::Exclude);
+	expression_txt->setVisible(constr_type==ConstraintType::Check || constr_type==ConstraintType::Exclude);
+	no_inherit_chk->setVisible(constr_type==ConstraintType::Check);
+	no_inherit_lbl->setVisible(constr_type==ConstraintType::Check);
+	warn_frm->setVisible(constr_type==ConstraintType::Check);
 
-	/*fill_factor_lbl->setVisible(constr_type==ConstraintType::unique ||
-															constr_type==ConstraintType::primary_key ||
-															constr_type==ConstraintType::exclude); */
-	fill_factor_chk->setVisible(constr_type==ConstraintType::unique ||
-								constr_type==ConstraintType::primary_key ||
-								constr_type==ConstraintType::exclude);
-	fill_factor_sb->setVisible(constr_type==ConstraintType::unique ||
-							   constr_type==ConstraintType::primary_key ||
-							   constr_type==ConstraintType::exclude);
+	fill_factor_chk->setVisible(constr_type==ConstraintType::Unique ||
+								constr_type==ConstraintType::PrimaryKey ||
+								constr_type==ConstraintType::Exclude);
+	fill_factor_sb->setVisible(constr_type==ConstraintType::Unique ||
+							   constr_type==ConstraintType::PrimaryKey ||
+							   constr_type==ConstraintType::Exclude);
 
-	info_frm->setVisible(constr_type==ConstraintType::primary_key);
+	info_frm->setVisible(constr_type==ConstraintType::PrimaryKey);
 
-	deferrable_lbl->setVisible(constr_type!=ConstraintType::check);
-	deferrable_chk->setVisible(constr_type!=ConstraintType::check);
-	deferral_cmb->setVisible(constr_type!=ConstraintType::check);
-	deferral_lbl->setVisible(constr_type!=ConstraintType::check);
+	deferrable_lbl->setVisible(constr_type!=ConstraintType::Check);
+	deferrable_chk->setVisible(constr_type!=ConstraintType::Check);
+	deferral_cmb->setVisible(constr_type!=ConstraintType::Check);
+	deferral_lbl->setVisible(constr_type!=ConstraintType::Check);
 
-	match_lbl->setVisible(constr_type==ConstraintType::foreign_key);
-	match_cmb->setVisible(constr_type==ConstraintType::foreign_key);
-	on_delete_cmb->setVisible(constr_type==ConstraintType::foreign_key);
-	on_delete_lbl->setVisible(constr_type==ConstraintType::foreign_key);
-	on_update_cmb->setVisible(constr_type==ConstraintType::foreign_key);
-	on_update_lbl->setVisible(constr_type==ConstraintType::foreign_key);
+	match_lbl->setVisible(constr_type==ConstraintType::ForeignKey);
+	match_cmb->setVisible(constr_type==ConstraintType::ForeignKey);
+	on_delete_cmb->setVisible(constr_type==ConstraintType::ForeignKey);
+	on_delete_lbl->setVisible(constr_type==ConstraintType::ForeignKey);
+	on_update_cmb->setVisible(constr_type==ConstraintType::ForeignKey);
+	on_update_lbl->setVisible(constr_type==ConstraintType::ForeignKey);
 
-	columns_tbw->setVisible(constr_type!=ConstraintType::check &&
-										 constr_type!=ConstraintType::exclude);
+	columns_tbw->setVisible(constr_type!=ConstraintType::Check &&
+										 constr_type!=ConstraintType::Exclude);
 
-	indexing_chk->setVisible(constr_type==ConstraintType::exclude);
-	indexing_cmb->setVisible(constr_type==ConstraintType::exclude);
+	indexing_chk->setVisible(constr_type==ConstraintType::Exclude);
+	indexing_cmb->setVisible(constr_type==ConstraintType::Exclude);
 
-	if(constr_type!=ConstraintType::foreign_key)
+	if(constr_type!=ConstraintType::ForeignKey)
 	{
 		columns_tbw->setTabEnabled(1, false);
 		columns_tbw->setCurrentIndex(0);
@@ -348,59 +347,51 @@ void ConstraintWidget::selectConstraintType(void)
 	else
 		columns_tbw->setTabEnabled(1, true);
 
-	excl_elems_grp->setVisible(constr_type==ConstraintType::exclude);
+	excl_elems_grp->setVisible(constr_type==ConstraintType::Exclude);
 }
 
 void ConstraintWidget::setAttributes(DatabaseModel *model, OperationList *op_list,  BaseObject *parent_obj, Constraint *constr)
 {
 	ObjectType obj_type;
-	unsigned count, i, row;
-	Column *column=nullptr;
+	unsigned row = 0;
 	Table *ref_table=nullptr;
 	vector<ExcludeElement> excl_elems;
 
 	if(!parent_obj)
-		throw Exception(ERR_ASG_NOT_ALOC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgNotAllocattedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
-	obj_type=parent_obj->getObjectType();
-	if(obj_type!=OBJ_TABLE && obj_type!=OBJ_RELATIONSHIP)
-		throw Exception(ERR_OPR_OBJ_INV_TYPE,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+	obj_type = parent_obj->getObjectType();
+
+	if(!PhysicalTable::isPhysicalTable(obj_type) && obj_type!=ObjectType::Relationship)
+		throw Exception(ErrorCode::OprObjectInvalidType,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	BaseObjectWidget::setAttributes(model, op_list, constr, parent_obj);
 
 	info_frm->setVisible(this->table!=nullptr);
 	ref_table_sel->setModel(model);
 
-	if(this->table)
-		count=table->getObjectCount(OBJ_COLUMN);
-	else
-		count=relationship->getAttributeCount();
-
 	columns_tab->blockSignals(true);
-	for(i=0, row=0; i < count; i++)
-	{
-		if(this->table)
-			column=dynamic_cast<Column *>(table->getObject(i, OBJ_COLUMN));
-		else
-			column=relationship->getAttribute(i);
 
-		if(constr && constr->isColumnExists(column, Constraint::SOURCE_COLS))
+	if(constr)
+	{
+		row = 0;
+		for(auto column : constr->getColumns(Constraint::SourceCols))
 		{
 			columns_tab->addRow();
-			addColumn(column, Constraint::SOURCE_COLS, row);
+			addColumn(column, Constraint::SourceCols, row);
 			row++;
 		}
 	}
 
-	updateColumnsCombo(Constraint::SOURCE_COLS);
-	columns_tab->setButtonsEnabled(ObjectsTableWidget::ADD_BUTTON, (column_cmb->count()!=0));
+	updateColumnsCombo(Constraint::SourceCols);
+	columns_tab->setButtonsEnabled(ObjectsTableWidget::AddButton, (column_cmb->count()!=0));
 	columns_tab->blockSignals(false);
 
 	if(constr)
 	{
 		excl_elems = constr->getExcludeElements();
 
-		indexing_chk->setChecked(constr->getIndexType()!=BaseType::null);
+		indexing_chk->setChecked(constr->getIndexType()!=BaseType::Null);
 		indexing_cmb->setCurrentIndex(indexing_cmb->findText(~constr->getIndexType()));
 
 		constr_type_cmb->setCurrentIndex(constr_type_cmb->findText(~constr->getConstraintType()));
@@ -412,8 +403,8 @@ void ConstraintWidget::setAttributes(DatabaseModel *model, OperationList *op_lis
 		deferrable_chk->setChecked(constr->isDeferrable());
 		deferral_cmb->setCurrentIndex(deferral_cmb->findText(~constr->getDeferralType()));
 		match_cmb->setCurrentIndex(match_cmb->findText(~constr->getMatchType()));
-		on_delete_cmb->setCurrentIndex(on_delete_cmb->findText(~constr->getActionType(Constraint::DELETE_ACTION)));
-		on_update_cmb->setCurrentIndex(on_update_cmb->findText(~constr->getActionType(Constraint::UPDATE_ACTION)));
+		on_delete_cmb->setCurrentIndex(on_delete_cmb->findText(~constr->getActionType(Constraint::DeleteAction)));
+		on_update_cmb->setCurrentIndex(on_update_cmb->findText(~constr->getActionType(Constraint::UpdateAction)));
 
 		fill_factor_chk->setChecked(constr->getFillFactor()!=0);
 		if(fill_factor_chk->isChecked())
@@ -425,25 +416,22 @@ void ConstraintWidget::setAttributes(DatabaseModel *model, OperationList *op_lis
 			ref_columns_tab->blockSignals(true);
 			ref_table_sel->setSelectedObject(ref_table);
 
-			count=ref_table->getColumnCount();
-			for(i=0, row=0; i < count; i++)
+			row = 0;
+			for(auto column : constr->getColumns(Constraint::ReferencedCols))
 			{
-				column=ref_table->getColumn(i);
-				if(constr->isColumnExists(column, Constraint::REFERENCED_COLS))
-				{
-					ref_columns_tab->addRow();
-					addColumn(column, Constraint::REFERENCED_COLS, row);
-					row++;
-				}
+				ref_columns_tab->addRow();
+				addColumn(column, Constraint::ReferencedCols, row);
+				row++;
 			}
 
-			updateColumnsCombo(Constraint::REFERENCED_COLS);
-			ref_columns_tab->setButtonsEnabled(ObjectsTableWidget::ADD_BUTTON, (column_cmb->count()!=0));
+			updateColumnsCombo(Constraint::ReferencedCols);
+			ref_columns_tab->setButtonsEnabled(ObjectsTableWidget::AddButton, (column_cmb->count()!=0));
 			ref_columns_tab->blockSignals(false);
 		}
 	}
 
-	excl_elems_wgt->setAttributes(model, parent_obj, excl_elems);
+	excl_elems_tab->setAttributes<ExcludeElement>(model, parent_obj);
+	excl_elems_tab->setElements<ExcludeElement>(excl_elems);
 }
 
 void ConstraintWidget::applyConfiguration(void)
@@ -470,22 +458,22 @@ void ConstraintWidget::applyConfiguration(void)
 		constr->setMatchType(MatchType(match_cmb->currentText()));
 		constr->setDeferrable(deferrable_chk->isChecked());
 		constr->setDeferralType(DeferralType(deferral_cmb->currentText()));
-		constr->setActionType(ActionType(on_delete_cmb->currentText()),Constraint::DELETE_ACTION);
-		constr->setActionType(ActionType(on_update_cmb->currentText()),Constraint::UPDATE_ACTION);
+		constr->setActionType(ActionType(on_delete_cmb->currentText()),Constraint::DeleteAction);
+		constr->setActionType(ActionType(on_update_cmb->currentText()),Constraint::UpdateAction);
 		constr->setNoInherit(no_inherit_chk->isChecked());
 
 		if(indexing_chk->isChecked())
 			constr->setIndexType(IndexingType(indexing_cmb->currentText()));
 		else
-			constr->setIndexType(BaseType::null);
+			constr->setIndexType(BaseType::Null);
 
-		if(constr->getConstraintType()==ConstraintType::foreign_key)
+		if(constr->getConstraintType()==ConstraintType::ForeignKey)
 			constr->setReferencedTable(dynamic_cast<BaseTable *>(ref_table_sel->getSelectedObject()));
 
 		constr->removeColumns();
-		for(col_id=Constraint::SOURCE_COLS; col_id <= Constraint::REFERENCED_COLS; col_id++)
+		for(col_id=Constraint::SourceCols; col_id <= Constraint::ReferencedCols; col_id++)
 		{
-			aux_col_tab=(col_id==Constraint::SOURCE_COLS ? columns_tab : ref_columns_tab);
+			aux_col_tab=(col_id==Constraint::SourceCols ? columns_tab : ref_columns_tab);
 
 			count=aux_col_tab->getRowCount();
 			for(i=0; i < count; i++)
@@ -495,35 +483,34 @@ void ConstraintWidget::applyConfiguration(void)
 			}
 		}
 
-		excl_elems_wgt->getElements(excl_elems);
+		excl_elems_tab->getElements<ExcludeElement>(excl_elems);
 		constr->addExcludeElements(excl_elems);
 
 		//Raises an error if the user try to create a primary key that has columns added by relationship (not supported)
-		if(constr->getConstraintType()==ConstraintType::primary_key &&
+		if(constr->getConstraintType()==ConstraintType::PrimaryKey &&
 				constr->isReferRelationshipAddedColumn())
-			throw Exception(ERR_PK_USING_COLS_ADDED_BY_REL,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+			throw Exception(ErrorCode::UnsupportedPKColsAddedByRel,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 		BaseObjectWidget::applyConfiguration();
 
 		/* Raises an error if the constraint type requires at least one column to be assinged and
 		there is no columns configured on the form */
-		if(((constr->getConstraintType()==ConstraintType::foreign_key ||
-			 constr->getConstraintType()==ConstraintType::primary_key) &&
-			constr->getColumnCount(Constraint::SOURCE_COLS)==0) ||
-				(constr->getConstraintType()==ConstraintType::foreign_key &&
-				 constr->getColumnCount(Constraint::REFERENCED_COLS)==0))
-			throw Exception(ERR_CONSTR_NO_COLUMNS,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		if(((constr->getConstraintType()==ConstraintType::ForeignKey ||
+			 constr->getConstraintType()==ConstraintType::PrimaryKey) &&
+			constr->getColumnCount(Constraint::SourceCols)==0) ||
+				(constr->getConstraintType()==ConstraintType::ForeignKey &&
+				 constr->getColumnCount(Constraint::ReferencedCols)==0))
+			throw Exception(ErrorCode::InvConstratintNoColumns,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 		finishConfiguration();
 
 		//For the foreign keys, updates the fk relationships on the model
-		if(constr->getConstraintType()==ConstraintType::foreign_key)
+		if(constr->getConstraintType()==ConstraintType::ForeignKey)
 			this->model->updateTableFKRelationships(dynamic_cast<Table *>(this->table));
 	}
 	catch(Exception &e)
 	{
 		Messagebox msg_box;
-
 		cancelConfiguration();
 		msg_box.show(e);
 	}
