@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #include "ui_constraintwidget.h"
 #include "objectstablewidget.h"
 #include "messagebox.h"
-#include "elementswidget.h"
+#include "elementstablewidget.h"
 
 class ConstraintWidget: public BaseObjectWidget, public Ui::ConstraintWidget {
 	private:
@@ -39,7 +39,7 @@ class ConstraintWidget: public BaseObjectWidget, public Ui::ConstraintWidget {
 		
 		SyntaxHighlighter *expression_hl;
 		
-		ElementsWidget *excl_elems_wgt;
+		ElementsTableWidget *excl_elems_tab;
 		
 		/*! \brief Table widgets used to store the columns that forms the constraint as well the
 		referenced columns (only for foreign keys) */
@@ -56,7 +56,7 @@ class ConstraintWidget: public BaseObjectWidget, public Ui::ConstraintWidget {
 		void addColumn(Column *column, unsigned col_id, int row);
 		
 	public:
-		ConstraintWidget(QWidget * parent = 0);
+		ConstraintWidget(QWidget * parent = nullptr);
 		void setAttributes(DatabaseModel *model, OperationList *op_list, BaseObject *parent_obj, Constraint *constr);
 		
 	private slots:
