@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ class DonateWidget: public QWidget, public Ui::DonateWidget {
 		Q_OBJECT
 		
 	public:
-		DonateWidget(QWidget *parent = 0);
+		DonateWidget(QWidget *parent = nullptr);
 		
 	signals:
 		void s_visibilityChanged(bool value);
