@@ -1,9 +1,9 @@
 #include "extensionwidget.h"
 
-ExtensionWidget::ExtensionWidget(QWidget * parent) : BaseObjectWidget(parent, OBJ_EXTENSION)
+ExtensionWidget::ExtensionWidget(QWidget * parent) : BaseObjectWidget(parent, ObjectType::Extension)
 {
 	Ui_ExtensionWidget::setupUi(this);
-	configureFormLayout(extension_grid, OBJ_EXTENSION);
+	configureFormLayout(extension_grid, ObjectType::Extension);
 
 	extension_grid->addItem(new QSpacerItem(10,10,QSizePolicy::Minimum,QSizePolicy::Expanding), extension_grid->count()+1, 0, 1, 0);
 	configureTabOrder({ cur_ver_edt, old_ver_edt, handles_type_chk });
@@ -17,8 +17,8 @@ void ExtensionWidget::setAttributes(DatabaseModel *model, OperationList *op_list
 
 	if(ext)
 	{
-		cur_ver_edt->setText(ext->getVersion(Extension::CUR_VERSION));
-		old_ver_edt->setText(ext->getVersion(Extension::OLD_VERSION));
+		cur_ver_edt->setText(ext->getVersion(Extension::CurVersion));
+		old_ver_edt->setText(ext->getVersion(Extension::OldVersion));
 
 		handles_type_chk->setEnabled(false);
 		handles_type_chk->setChecked(ext->handlesType());
@@ -35,14 +35,14 @@ void ExtensionWidget::applyConfiguration(void)
 		extension=dynamic_cast<Extension *>(this->object);
 		BaseObjectWidget::applyConfiguration();
 		extension->setHandlesType(handles_type_chk->isChecked());
-		extension->setVersion(Extension::CUR_VERSION, cur_ver_edt->text());
-		extension->setVersion(Extension::OLD_VERSION, old_ver_edt->text());
+		extension->setVersion(Extension::CurVersion, cur_ver_edt->text());
+		extension->setVersion(Extension::OldVersion, old_ver_edt->text());
 
 		finishConfiguration();
 	}
 	catch(Exception &e)
 	{
 		cancelConfiguration();
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
