@@ -1,7 +1,7 @@
-/*
+﻿/*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,28 +36,44 @@ class GeneralConfigWidget: public BaseConfigWidget, public Ui::GeneralConfigWidg
 	private:
 		Q_OBJECT
 
+		/* This simple struct is used to store the widgets geometry and maximized state
+		 * in order to save this info to configuration file being possible to restore
+		 * it when reloading the application */
+		struct WidgetState
+		{
+		  QRect geometry;
+		  bool maximized;
+		  WidgetState() { maximized = false; }
+		};
+
 		QWidgetList child_wgts;
 
 		NumberedTextEditor *font_preview_txt;
 
+		static map<QString, WidgetState> widgets_geom;
+
 		static map<QString, attribs_map> config_params;
 
-		static const unsigned UNIT_MILIMETERS=0,
-		UNIT_POINT=1,
-		UNIT_INCHS=2,
-		UNIT_CENTIMETERS=3;
+		static constexpr unsigned UnitMilimeters=0,
+		UnitPoint=1,
+		UnitInches=2,
+		UnitCentimeters=3;
 
 		HintTextWidget *simp_obj_creation_ht, *confirm_validation_ht, *corner_move_ht,
 		*save_last_pos_ht, *invert_rangesel_ht, *disable_smooth_ht,
 		*hide_ext_attribs_ht, *hide_table_tags_ht, *hide_rel_name_ht,
 		*code_completion_ht, *use_placeholders_ht, *min_obj_opacity_ht,
 		*autosave_ht, *op_history_ht, *ui_language_ht, *grid_size_ht,
-		*use_curved_lines_ht, *max_result_rows_ht;
+		*use_curved_lines_ht, *max_result_rows_ht, *attribs_per_page_ht,
+		*reduce_verbosity_ht, *escape_comments_ht;
 
 		ColorPickerWidget *line_numbers_cp, *line_numbers_bg_cp, *line_highlight_cp;
 
 	public:
-		GeneralConfigWidget(QWidget * parent=0);
+		//! \brief Maximum number of files listed as recent models
+		static constexpr int MaxRecentModels=15;
+
+		GeneralConfigWidget(QWidget * parent = nullptr);
 
 		void saveConfiguration(void);
 		void loadConfiguration(void);
@@ -69,6 +85,9 @@ class GeneralConfigWidget: public BaseConfigWidget, public Ui::GeneralConfigWidg
 		Section id can be <configuration>, <dock-widget>, <file[n]> or <recent[n]> */
 		static QString getConfigurationParam(const QString &section_id, const QString &param_name);
 
+		static void saveWidgetGeometry(QWidget *widget, const QString &custom_wgt_name = QString());
+		static bool restoreWidgetGeometry(QWidget *widget, const QString &custom_wgt_name = QString());
+
 	public slots:
 		void applyConfiguration(void);
 		void restoreDefaults(void);
@@ -78,6 +97,7 @@ class GeneralConfigWidget: public BaseConfigWidget, public Ui::GeneralConfigWidg
 	private slots:
 		void convertMarginUnity(void);
 		void updateFontPreview(void);
+		void resetDialogsSizes(void);
 };
 
 #endif
