@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ class HtmlItemDelegate : public PlainTextItemDelegate {
 		Q_OBJECT
 
 	public:
-		HtmlItemDelegate(QObject * parent = 0);
+		HtmlItemDelegate(QObject * parent = nullptr);
 		~HtmlItemDelegate(void);
 
 	protected:
