@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,34 +36,34 @@ class Messagebox: public QDialog, public Ui::Messagebox {
 
 	public:
 		//! \brief Constants used to define the message icon
-		static const unsigned NO_ICON=10,
-		ERROR_ICON=11,
-		INFO_ICON=12,
-		ALERT_ICON=13,
-		CONFIRM_ICON=14;
+		static constexpr unsigned NoIcon=10,
+		ErrorIcon=11,
+		InfoIcon=12,
+		AlertIcon=13,
+		ConfirmIcon=14;
 
 		//! \brief Constants used to configure the visible buttons
-		static const unsigned YES_NO_BUTTONS=0,
-		OK_CANCEL_BUTTONS=1,
-		OK_BUTTON=2,
-		ALL_BUTTONS=3;
+		static constexpr unsigned YesNoButtons=0,
+		OkCancelButtons=1,
+		OkButton=2,
+		AllButtons=3;
 
-		Messagebox(QWidget * parent = 0, Qt::WindowFlags f = 0);
+		Messagebox(QWidget * parent = nullptr, Qt::WindowFlags f = Qt::Widget);
 
 		/*! \brief Shows the message box defining the icons and available buttons.
 	User can specify custom button labels as well custom icons. The icons can be a path to a local file
 	or a Qt  resource icon ':/path/icon' and will be enabled only specifing custom labels for the respective button. */
-		void show(const QString &title, const QString &msg, unsigned icon_type=NO_ICON, unsigned buttons=OK_BUTTON,
+		void show(const QString &title, const QString &msg, unsigned icon_type=NoIcon, unsigned buttons=OkButton,
 				  const QString &yes_lbl=QString(), const QString &no_lbl=QString(), const QString &cancel_lbl=QString(),
 				  const QString &yes_ico=QString(), const QString &no_ico=QString(), const QString &cancel_ico=QString());
 
 		//! \brief Shows the message box using an excpetion as message
-		void show(Exception e, const QString &msg=QString(), unsigned icon_type=ERROR_ICON, unsigned buttons=OK_BUTTON,
+		void show(Exception e, const QString &msg=QString(), unsigned icon_type=ErrorIcon, unsigned buttons=OkButton,
 				  const QString &yes_lbl=QString(), const QString &no_lbl=QString(), const QString &cancel_lbl=QString(),
 				  const QString &yes_ico=QString(), const QString &no_ico=QString(), const QString &cancel_ico=QString());
 
 		//! \brief Shows a simple message box with the title automatically defined by the icon type
-		void show(const QString &msg, unsigned icon_type=NO_ICON, unsigned buttons=OK_BUTTON);
+		void show(const QString &msg, unsigned icon_type=NoIcon, unsigned buttons=OkButton);
 
 		bool isCancelled(void);
 
