@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -41,21 +41,22 @@ class MetadataHandlingForm: public QDialog, public Ui::MetadataHandlingForm {
 
 		HintTextWidget *db_metadata_ht, *objs_positioning_ht, *objs_protection_ht,
 		*objs_sql_disabled_ht, *custom_sql_ht, *textbox_objs_ht, *tag_objs_ht,
-		*custom_colors_ht, *extract_restore_ht, *restore_ht, *objs_fadedout_ht, *objs_extattribs_ht,
-		*generic_sql_objs_ht, *extract_only_ht;
+		*custom_colors_ht, *extract_restore_ht, *restore_ht, *objs_fadedout_ht,
+		*objs_collapse_mode_ht, *generic_sql_objs_ht, *extract_only_ht, *objs_aliases_ht;
 
 		void showEvent(QShowEvent *);
 		void selectFile(bool is_output);
 
 	public:
-		MetadataHandlingForm(QWidget * parent = 0, Qt::WindowFlags f = 0);
+		MetadataHandlingForm(QWidget * parent = nullptr, Qt::WindowFlags f = Qt::Widget);
 		void setModelWidget(ModelWidget *model_wgt);
 		void setModelWidgets(QList<ModelWidget *> models);
 
 	private slots:
 		void updateProgress(int progress, QString msg, unsigned type_id);
-		void handleObjectsMetada(void);	
+		void handleObjectsMetada(void);
 		void enableMetadataHandling(void);
+		void selectAllOptions(void);
 
 	signals:
 		void s_metadataHandled(void);
