@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 #include "configurationform.h"
 #include "pgmodeleruins.h"
 
+bool ModelExportForm::low_verbosity = false;
+
 ModelExportForm::ModelExportForm(QWidget *parent, Qt::WindowFlags f) : QDialog(parent, f)
 {
 	model=nullptr;
@@ -48,13 +50,21 @@ ModelExportForm::ModelExportForm(QWidget *parent, Qt::WindowFlags f) : QDialog(p
 	ignore_error_codes_ht=new HintTextWidget(ignore_extra_errors_hint, this);
 	ignore_error_codes_ht->setText(ignore_error_codes_chk->statusTip());
 
+	mode_ht=new HintTextWidget(mode_hint, this);
+	mode_ht->setText(mode_hint->statusTip());
+
+	incl_index_ht=new HintTextWidget(incl_index_hint, this);
+	incl_index_ht->setText(incl_index_hint->statusTip());
+
 	connect(export_to_file_rb, SIGNAL(clicked()), this, SLOT(selectExportMode(void)));
 	connect(export_to_dbms_rb, SIGNAL(clicked()), this, SLOT(selectExportMode(void)));
 	connect(export_to_img_rb, SIGNAL(clicked()), this, SLOT(selectExportMode(void)));
+	connect(export_to_dict_rb, SIGNAL(clicked()), this, SLOT(selectExportMode(void)));
 	connect(pgsqlvers_chk, SIGNAL(toggled(bool)), pgsqlvers1_cmb, SLOT(setEnabled(bool)));
 	connect(close_btn, SIGNAL(clicked(bool)), this, SLOT(close(void)));
 	connect(select_file_tb, SIGNAL(clicked(void)), this, SLOT(selectOutputFile(void)));
 	connect(select_img_tb, SIGNAL(clicked(void)), this, SLOT(selectOutputFile(void)));
+	connect(select_dict_tb, SIGNAL(clicked(void)), this, SLOT(selectOutputFile(void)));
 	connect(export_btn, SIGNAL(clicked(void)), this, SLOT(exportModel(void)));
 	connect(drop_chk, SIGNAL(toggled(bool)), drop_db_rb, SLOT(setEnabled(bool)));
 	connect(drop_chk, SIGNAL(toggled(bool)), drop_objs_rb, SLOT(setEnabled(bool)));
@@ -73,6 +83,8 @@ ModelExportForm::ModelExportForm(QWidget *parent, Qt::WindowFlags f) : QDialog(p
 			else
 				export_hlp.exportToSVG();
 		}
+		else if(export_to_dict_rb->isChecked())
+			export_hlp.exportToDataDict();
 		else
 			export_hlp.exportToSQL();
 	});
@@ -93,11 +105,11 @@ ModelExportForm::ModelExportForm(QWidget *parent, Qt::WindowFlags f) : QDialog(p
 	connect(svg_rb, SIGNAL(toggled(bool)), page_by_page_chk, SLOT(setDisabled(bool)));
 	connect(ignore_error_codes_chk, SIGNAL(toggled(bool)), error_codes_edt, SLOT(setEnabled(bool)));
 
-	pgsqlvers_cmb->addItems(PgSQLVersions::ALL_VERSIONS);
-	pgsqlvers1_cmb->addItems(PgSQLVersions::ALL_VERSIONS);
+	pgsqlvers_cmb->addItems(PgSqlVersions::AllVersions);
+	pgsqlvers1_cmb->addItems(PgSqlVersions::AllVersions);
 
-	double values[]={ ModelWidget::MINIMUM_ZOOM, 0.10f, 0.25f, 0.5f, 0.75f, 1, 1.25f, 1.50f, 1.75f, 2,
-										2.25, 2.50, 2.75, 3, 3.25, 3.50, 3.75, ModelWidget::MAXIMUM_ZOOM };
+	double values[]={ ModelWidget::MinimumZoom, 0.10, 0.25, 0.5, 0.75, 1, 1.25, 1.50, 1.75, 2,
+										2.25, 2.50, 2.75, 3, 3.25, 3.50, 3.75, ModelWidget::MaximumZoom };
 	unsigned cnt=sizeof(values)/sizeof(double);
 
 	for(unsigned i=0; i < cnt; i++)
@@ -108,12 +120,17 @@ ModelExportForm::ModelExportForm(QWidget *parent, Qt::WindowFlags f) : QDialog(p
 	settings_tbw->setTabEnabled(1, false);
 }
 
+void ModelExportForm::setLowVerbosity(bool value)
+{
+	low_verbosity = value;
+}
+
 void ModelExportForm::exec(ModelWidget *model)
 {
 	if(model)
 	{
 		this->model=model;
-		ConnectionsConfigWidget::fillConnectionsComboBox(connections_cmb, true, Connection::OP_EXPORT);
+		ConnectionsConfigWidget::fillConnectionsComboBox(connections_cmb, true, Connection::OpExport);
 		selectExportMode();
 		QDialog::exec();
 	}
@@ -123,39 +140,40 @@ void ModelExportForm::handleErrorIgnored(QString err_code, QString err_msg, QStr
 {
 	QTreeWidgetItem *item=nullptr;
 
-	item=PgModelerUiNS::createOutputTreeItem(output_trw, trUtf8("Error code <strong>%1</strong> found and ignored. Proceeding with export.").arg(err_code),
-																					 QPixmap(PgModelerUiNS::getIconPath("msgbox_alerta")), nullptr, false);
+	item=PgModelerUiNs::createOutputTreeItem(output_trw, trUtf8("Error code <strong>%1</strong> found and ignored. Proceeding with export.").arg(err_code),
+																					 QPixmap(PgModelerUiNs::getIconPath("msgbox_alerta")), nullptr, false);
 
-	PgModelerUiNS::createOutputTreeItem(output_trw, PgModelerUiNS::formatMessage(err_msg),
-																			QPixmap(PgModelerUiNS::getIconPath("msgbox_alerta")),	item, false);
+	PgModelerUiNs::createOutputTreeItem(output_trw, PgModelerUiNs::formatMessage(err_msg),
+																			QPixmap(PgModelerUiNs::getIconPath("msgbox_alerta")),	item, false);
 
-	PgModelerUiNS::createOutputTreeItem(output_trw, cmd, QPixmap(), item, false);
+	PgModelerUiNs::createOutputTreeItem(output_trw, cmd, QPixmap(), item, false);
 }
 
 void ModelExportForm::updateProgress(int progress, QString msg, ObjectType obj_type, QString cmd, bool is_code_gen)
 {
 	QTreeWidgetItem *item=nullptr;
-	QString text=PgModelerUiNS::formatMessage(msg);
+	QString text=PgModelerUiNs::formatMessage(msg);
 	QPixmap ico;
 
 	progress_lbl->setText(text);
 	progress_pb->setValue(progress);
 
-	if(obj_type!=BASE_OBJECT)
-		ico=QPixmap(PgModelerUiNS::getIconPath(obj_type));
+	if(obj_type!=ObjectType::BaseObject)
+		ico=QPixmap(PgModelerUiNs::getIconPath(obj_type));
 	else if(!cmd.isEmpty())
-		ico=QPixmap(PgModelerUiNS::getIconPath("codigosql"));
+		ico=QPixmap(PgModelerUiNs::getIconPath("codigosql"));
 	else
-		ico=QPixmap(PgModelerUiNS::getIconPath("msgbox_info"));
+		ico=QPixmap(PgModelerUiNs::getIconPath("msgbox_info"));
 
 	ico_lbl->setPixmap(ico);
 
-	if(!is_code_gen)
+	// If low_verbosity is set only messages hinted by obj_type == BaseObject are show because they hold key info messages
+	if(!is_code_gen && (!low_verbosity || (low_verbosity && obj_type == ObjectType::BaseObject && cmd.isEmpty())))
 	{
-		item=PgModelerUiNS::createOutputTreeItem(output_trw, text, ico, nullptr, false);
+		item=PgModelerUiNs::createOutputTreeItem(output_trw, text, ico, nullptr, false);
 
 		if(!cmd.isEmpty())
-			PgModelerUiNS::createOutputTreeItem(output_trw, cmd, QPixmap(), item, false);
+			PgModelerUiNs::createOutputTreeItem(output_trw, cmd, QPixmap(), item, false);
 	}
 }
 
@@ -190,6 +208,10 @@ void ModelExportForm::exportModel(void)
 		{
 			progress_lbl->setText(trUtf8("Initializing model export..."));
 
+			if(low_verbosity)
+				PgModelerUiNs::createOutputTreeItem(output_trw, trUtf8("<strong>Low verbosity is set:</strong> only key informations and errors will be displayed."),
+																						QPixmap(PgModelerUiNs::getIconPath("msgbox_alerta")), nullptr, false);
+
 			//Exporting to sql file
 			if(export_to_file_rb->isChecked())
 			{
@@ -197,11 +219,16 @@ void ModelExportForm::exportModel(void)
 				export_hlp.setExportToSQLParams(model->db_model, file_edt->text(), pgsqlvers_cmb->currentText());
 				export_thread->start();
 			}
+			else if(export_to_dict_rb->isChecked())
+			{
+				export_hlp.setExportToDataDictParams(model->db_model, dict_edt->text(), incl_index_chk->isChecked(), splitted_rb->isChecked());
+				export_thread->start();
+			}
 			//Exporting directly to DBMS
 			else
 			{
 				QString version;
-				Connection *conn=reinterpret_cast<Connection *>(connections_cmb->itemData(connections_cmb->currentIndex()).value<void *>());
+				Connection *conn=reinterpret_cast<Connection *>(connections_cmb->itemData(connections_cmb->currentIndex()).value<void *>());			
 
 				//If the user chose a specific version
 				if(pgsqlvers1_cmb->isEnabled())
@@ -229,8 +256,8 @@ void ModelExportForm::exportModel(void)
 
 void ModelExportForm::selectExportMode(void)
 {
-	QList<QRadioButton *> radios={ export_to_dbms_rb, export_to_img_rb, export_to_file_rb};
-	QWidgetList wgts={ export_to_dbms_wgt, export_to_img_wgt, export_to_file_wgt };
+	QList<QRadioButton *> radios={ export_to_dbms_rb, export_to_img_rb, export_to_file_rb, export_to_dict_rb};
+	QWidgetList wgts={ export_to_dbms_wgt, export_to_img_wgt, export_to_file_wgt, export_to_dict_wgt };
 	int i=0;
 
 	for(QRadioButton *rb : radios)
@@ -243,8 +270,9 @@ void ModelExportForm::selectExportMode(void)
 
 	pgsqlvers1_cmb->setEnabled(export_to_dbms_rb->isChecked() && pgsqlvers_chk->isChecked());
 	export_btn->setEnabled((export_to_dbms_rb->isChecked() && connections_cmb->currentIndex() > 0 && connections_cmb->currentIndex()!=connections_cmb->count()-1) ||
-						   (export_to_file_rb->isChecked() && !file_edt->text().isEmpty()) ||
-						   (export_to_img_rb->isChecked() && !image_edt->text().isEmpty()));
+							(export_to_file_rb->isChecked() && !file_edt->text().isEmpty()) ||
+							(export_to_img_rb->isChecked() && !image_edt->text().isEmpty()) ||
+							(export_to_dict_rb->isChecked() && !dict_edt->text().isEmpty()));
 }
 
 void ModelExportForm::selectOutputFile(void)
@@ -262,6 +290,19 @@ void ModelExportForm::selectOutputFile(void)
 		file_dlg.setNameFilter(trUtf8("SQL script (*.sql);;All files (*.*)"));
 		file_dlg.selectFile(model->getDatabaseModel()->getName() + QString(".sql"));
 	}
+	else if(export_to_dict_rb->isChecked())
+	{
+		if(splitted_rb->isChecked())
+		{
+			file_dlg.setFileMode(QFileDialog::DirectoryOnly);
+			file_dlg.setNameFilter(QString());
+		}
+		else
+		{
+			file_dlg.setNameFilter(trUtf8("HTML file (*.html);;All files (*.*)"));
+			file_dlg.selectFile(model->getDatabaseModel()->getName() + QString(".html"));
+		}
+	}
 	else
 	{
 		if(png_rb->isChecked())
@@ -285,24 +326,28 @@ void ModelExportForm::selectOutputFile(void)
 
 		if(export_to_file_rb->isChecked())
 			file_edt->setText(file);
+		else if(export_to_dict_rb->isChecked())
+			dict_edt->setText(file);
 		else
 			image_edt->setText(file);
 	}
 
-	export_btn->setEnabled(!file_edt->text().isEmpty() || !image_edt->text().isEmpty());
+	export_btn->setEnabled(!file_edt->text().isEmpty() ||
+												 !dict_edt->text().isEmpty() ||
+												 !image_edt->text().isEmpty());
 }
 
 void ModelExportForm::captureThreadError(Exception e)
 {
-	QTreeWidgetItem *item=PgModelerUiNS::createOutputTreeItem(output_trw, PgModelerUiNS::formatMessage(e.getErrorMessage()),
-																														QPixmap(PgModelerUiNS::getIconPath("msgbox_erro")), nullptr, false, true);
+	QTreeWidgetItem *item=PgModelerUiNs::createOutputTreeItem(output_trw, PgModelerUiNs::formatMessage(e.getErrorMessage()),
+																														QPixmap(PgModelerUiNs::getIconPath("msgbox_erro")), nullptr, false, true);
 
-	PgModelerUiNS::createExceptionsTree(output_trw, e, item);
+	PgModelerUiNs::createExceptionsTree(output_trw, e, item);
 
-	ico_lbl->setPixmap(QPixmap(PgModelerUiNS::getIconPath("msgbox_erro")));
+	ico_lbl->setPixmap(QPixmap(PgModelerUiNs::getIconPath("msgbox_erro")));
 	finishExport(trUtf8("Exporting process aborted!"));
 
-	throw Exception(e.getErrorMessage(), e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+	throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 }
 
 void ModelExportForm::cancelExport(void)
@@ -313,22 +358,22 @@ void ModelExportForm::cancelExport(void)
 
 void ModelExportForm::handleExportCanceled(void)
 {
-	QPixmap ico=QPixmap(PgModelerUiNS::getIconPath("msgbox_alerta"));
+	QPixmap ico=QPixmap(PgModelerUiNs::getIconPath("msgbox_alerta"));
 	QString msg=trUtf8("Exporting process canceled by user!");
 
 	finishExport(msg);
 	ico_lbl->setPixmap(ico);
-	PgModelerUiNS::createOutputTreeItem(output_trw, msg, ico);
+	PgModelerUiNs::createOutputTreeItem(output_trw, msg, ico);
 }
 
 void ModelExportForm::handleExportFinished(void)
 {
-	QPixmap ico=QPixmap(PgModelerUiNS::getIconPath("msgbox_info"));
-	QString msg=trUtf8("Exporting process sucessfuly ended!");
+	QPixmap ico=QPixmap(PgModelerUiNs::getIconPath("msgbox_info"));
+	QString msg=trUtf8("Exporting process sucessfully ended!");
 
 	finishExport(msg);
 	ico_lbl->setPixmap(ico);
-	PgModelerUiNS::createOutputTreeItem(output_trw, msg, ico);
+	PgModelerUiNs::createOutputTreeItem(output_trw, msg, ico);
 }
 
 void ModelExportForm::finishExport(const QString &msg)
@@ -356,6 +401,7 @@ void ModelExportForm::enableExportModes(bool value)
 	export_to_dbms_rb->setEnabled(value);
 	export_to_file_rb->setEnabled(value);
 	export_to_img_rb->setEnabled(value);
+	export_to_dict_rb->setEnabled(value);
 	export_btn->setEnabled(value);
 	close_btn->setEnabled(value);
 }
@@ -372,9 +418,11 @@ void ModelExportForm::editConnections(void)
 {
 	try
 	{
-		if(connections_cmb->currentIndex()==connections_cmb->count()-1 &&
-				ConnectionsConfigWidget::openConnectionsConfiguration(connections_cmb, true))
+		if(connections_cmb->currentIndex()==connections_cmb->count()-1)
+		{
+			ConnectionsConfigWidget::openConnectionsConfiguration(connections_cmb, true);
 			emit s_connectionsUpdateRequest();
+		}
 	}
 	catch(Exception &e)
 	{
