@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -46,8 +46,8 @@ ModelValidationHelper::~ModelValidationHelper(void)
 void ModelValidationHelper::generateValidationInfo(unsigned val_type, BaseObject *object, vector<BaseObject *> refs)
 {
 	if(!refs.empty() ||
-		 val_type==ValidationInfo::MISSING_EXTENSION ||
-		 (val_type==ValidationInfo::BROKEN_REL_CONFIG &&
+		 val_type==ValidationInfo::MissingExtension ||
+		 (val_type==ValidationInfo::BrokenRelConfig &&
 			 std::find(inv_rels.begin(), inv_rels.end(), object)==inv_rels.end()))
 	{
 		//Configures a validation info
@@ -55,7 +55,7 @@ void ModelValidationHelper::generateValidationInfo(unsigned val_type, BaseObject
 		error_count++;
 		val_infos.push_back(info);
 
-		if(val_type==ValidationInfo::BROKEN_REL_CONFIG)
+		if(val_type==ValidationInfo::BrokenRelConfig)
 			inv_rels.push_back(object);
 
 		//Emit the signal containing the info
@@ -71,13 +71,13 @@ void  ModelValidationHelper::resolveConflict(ValidationInfo &info)
 		BaseObject *obj=nullptr;
 
 		//Resolving broken references by swaping the object ids
-		if(info.getValidationType()==ValidationInfo::BROKEN_REFERENCE ||
-			 info.getValidationType()==ValidationInfo::SP_OBJ_BROKEN_REFERENCE)
+		if(info.getValidationType()==ValidationInfo::BrokenReference ||
+			 info.getValidationType()==ValidationInfo::SpObjBrokenReference)
 		{
 			BaseObject *info_obj=info.getObject(), *aux_obj=nullptr;
 			unsigned obj_id=info_obj->getObjectId();
 
-			if(info.getValidationType()==ValidationInfo::BROKEN_REFERENCE)
+			if(info.getValidationType()==ValidationInfo::BrokenReference)
 			{
 				//Search for the object with the minor id
 				while(!refs.empty() && !valid_canceled)
@@ -106,7 +106,7 @@ void  ModelValidationHelper::resolveConflict(ValidationInfo &info)
 						}
 					}
 
-					if(aux_obj && (aux_obj->getObjectType()==OBJ_VIEW || aux_obj->getObjectType()==OBJ_TABLE))
+					if(aux_obj && BaseTable::isBaseTable(aux_obj->getObjectType()))
 					{
 						vector<BaseRelationship *> base_rels=db_model->getRelationships(dynamic_cast<BaseTable *>(aux_obj));
 						for(auto &rel : base_rels)
@@ -132,23 +132,22 @@ void  ModelValidationHelper::resolveConflict(ValidationInfo &info)
 			emit s_objectIdChanged(info_obj);
 		}
 		//Resolving no unique name by renaming the constraints/indexes
-		else if(info.getValidationType()==ValidationInfo::NO_UNIQUE_NAME)
+		else if(info.getValidationType()==ValidationInfo::NoUniqueName)
 		{
 			unsigned suffix=1;
 			QString new_name;
-			Table *table=nullptr;
+			BaseTable *table=nullptr;
 			ObjectType obj_type;
 			BaseObject *obj=info.getObject();
 			TableObject *tab_obj=nullptr;
 
 			/* If the last element of the referrer objects is a table or view the
 			info object itself need to be renamed since tables and views will not be renamed */
-			bool rename_obj=(refs.back()->getObjectType()==OBJ_TABLE ||
-							 refs.back()->getObjectType()==OBJ_VIEW);
+			bool rename_obj=BaseTable::isBaseTable(refs.back()->getObjectType());
 
 			if(rename_obj)
 			{
-				table=dynamic_cast<Table *>(dynamic_cast<TableObject *>(obj)->getParentTable());
+				table=dynamic_cast<BaseTable *>(dynamic_cast<TableObject *>(obj)->getParentTable());
 				obj_type=obj->getObjectType();
 
 				do
@@ -162,6 +161,7 @@ void  ModelValidationHelper::resolveConflict(ValidationInfo &info)
 
 				//Renames the object
 				obj->setName(new_name);
+				table->setModified(true);
 			}
 
 			//Renaming the referrer objects
@@ -173,26 +173,27 @@ void  ModelValidationHelper::resolveConflict(ValidationInfo &info)
 				//Tables and view aren't renamed only table child objects (constraints, indexes)
 				if(tab_obj && !tab_obj->isAddedByRelationship())
 				{
-					table=dynamic_cast<Table *>(tab_obj->getParentTable());
+					table=dynamic_cast<BaseTable *>(tab_obj->getParentTable());
 
 					do
 					{
 						//Configures a new name for the object [name]_[suffix]
-						new_name=QString("%1_%2").arg(refs.back()->getName()).arg(suffix);
+						new_name=QString("%1_%2").arg(tab_obj->getName()).arg(suffix);
 						suffix++;
 					}
 					//Generates a new name until no object is found on parent table
 					while(table->getObjectIndex(new_name, obj_type) >= 0);
 
 					//Renames the referrer object
-					refs.back()->setName(new_name);
+					tab_obj->setName(new_name);
+					table->setModified(true);
 				}
 
 				refs.pop_back();
 			}
 		}
 		//Resolving the absence of postgis extension
-		else if(info.getValidationType()==ValidationInfo::MISSING_EXTENSION && !db_model->getExtension(QString("postgis")))
+		else if(info.getValidationType()==ValidationInfo::MissingExtension && !db_model->getExtension(QString("postgis")))
 		{
 			Extension *extension = new Extension();
 			extension->setName(QString("postgis"));
@@ -201,7 +202,7 @@ void  ModelValidationHelper::resolveConflict(ValidationInfo &info)
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(), e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
@@ -233,7 +234,7 @@ void ModelValidationHelper::redirectExportProgress(int prog, QString msg, Object
 void ModelValidationHelper::setValidationParams(DatabaseModel *model, Connection *conn, const QString &pgsql_ver, bool use_tmp_names)
 {
 	if(!model)
-		throw Exception(ERR_ASG_NOT_ALOC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgNotAllocattedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	fix_mode=false;
 	valid_canceled=false;
@@ -259,30 +260,33 @@ bool ModelValidationHelper::isInFixMode()
 void ModelValidationHelper::validateModel(void)
 {
 	if(!db_model)
-		throw Exception(ERR_OPR_NOT_ALOC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::OprNotAllocatedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	try
 	{
-		ObjectType types[]={ OBJ_ROLE, OBJ_TABLESPACE, OBJ_SCHEMA, OBJ_LANGUAGE, OBJ_FUNCTION,
-							 OBJ_TYPE, OBJ_DOMAIN, OBJ_SEQUENCE, OBJ_OPERATOR, OBJ_OPFAMILY,
-							 OBJ_OPCLASS, OBJ_COLLATION, OBJ_TABLE, OBJ_EXTENSION, OBJ_VIEW, OBJ_RELATIONSHIP },
-				aux_types[]={ OBJ_TABLE, OBJ_VIEW },
-				tab_obj_types[]={ OBJ_CONSTRAINT, OBJ_INDEX },
+		ObjectType types[]={ ObjectType::Role, ObjectType::Tablespace, ObjectType::Schema, ObjectType::Language, ObjectType::Function,
+												 ObjectType::Type, ObjectType::Domain, ObjectType::Sequence, ObjectType::Operator, ObjectType::OpFamily,
+												 ObjectType::OpClass, ObjectType::Collation, ObjectType::Table, ObjectType::Extension, ObjectType::View,
+												 ObjectType::Relationship, ObjectType::ForeignDataWrapper, ObjectType::ForeignServer, ObjectType::GenericSql,
+												 ObjectType::ForeignTable },
+				aux_types[]={ ObjectType::Table, ObjectType::ForeignTable, ObjectType::View },
+				tab_obj_types[]={ ObjectType::Constraint, ObjectType::Index },
 				obj_type;
 		unsigned i, i1, cnt, aux_cnt=sizeof(aux_types)/sizeof(ObjectType),
 				count=sizeof(types)/sizeof(ObjectType), count1=sizeof(tab_obj_types)/sizeof(ObjectType);
 		BaseObject *object=nullptr, *refer_obj=nullptr;
-		vector<BaseObject *> refs, refs_aux, *obj_list=nullptr;
+		vector<BaseObject *> refs, refs_aux, *obj_list=nullptr, aux_tables;
 		vector<BaseObject *>::iterator itr;
 		TableObject *tab_obj=nullptr;
-		Table *table=nullptr, *ref_tab=nullptr, *recv_tab=nullptr;
+		PhysicalTable *table=nullptr, *ref_tab=nullptr, *recv_tab=nullptr;
+		BaseTable *base_tab = nullptr;
 		Constraint *constr=nullptr;
 		Column *col=nullptr;
 		Relationship *rel=nullptr;
 		map<QString, vector<BaseObject *> > dup_objects;
 		map<QString, vector<BaseObject *> >::iterator mitr;
 		QString name, signal_msg=QString("`%1' (%2)");
-		bool postgis_exists = db_model->getObjectIndex(QString("postgis"), OBJ_EXTENSION) >= 0;
+		bool postgis_exists = db_model->getObjectIndex(QString("postgis"), ObjectType::Extension) >= 0;
 
 		warn_count=error_count=progress=0;
 		val_infos.clear();
@@ -308,12 +312,13 @@ void ModelValidationHelper::validateModel(void)
 					emit s_objectProcessed(signal_msg.arg(object->getName()).arg(object->getTypeName()), object->getObjectType());
 
 					/* Special validation case: For generalization and copy relationships validates the ids of participant tables.
-		   * Reference table cannot own an id greater thant receiver table */
-					if(obj_type==OBJ_RELATIONSHIP)
+						 Reference table cannot own an id greater thant receiver table */
+					if(obj_type==ObjectType::Relationship)
 					{
 						rel=dynamic_cast<Relationship *>(object);
-						if(rel->getRelationshipType()==Relationship::RELATIONSHIP_GEN ||
-								rel->getRelationshipType()==Relationship::RELATIONSHIP_DEP)
+						if(rel->getRelationshipType()==Relationship::RelationshipGen ||
+								rel->getRelationshipType()==Relationship::RelationshipDep ||
+							 rel->getRelationshipType()==Relationship::RelationshipPart)
 						{
 							recv_tab=rel->getReceiverTable();
 							ref_tab=rel->getReferenceTable();
@@ -337,14 +342,13 @@ void ModelValidationHelper::validateModel(void)
 							col=dynamic_cast<Column *>(tab_obj);
 
 							/* If the current referrer object has an id less than reference object's id
-				then it will be pushed into the list of invalid references. The only exception is
-				for foreign keys that are discarded from any validation since they are always created
-				at end of code defintion being free of any reference breaking. */
+							 * then it will be pushed into the list of invalid references. The only exception is
+							 * for foreign keys that are discarded from any validation since they are always created
+							 * at end of code defintion being free of any reference breaking. */
 							if(object != refs.back() &&
 									(
-										((col || (constr && constr->getConstraintType()!=ConstraintType::foreign_key)) &&
-										 (tab_obj->getParentTable()->getObjectId() <= object->getObjectId()))
-										||
+										((col || (constr && constr->getConstraintType()!=ConstraintType::ForeignKey)) &&
+										 (tab_obj->getParentTable()->getObjectId() <= object->getObjectId())) ||
 										(!constr && refs.back()->getObjectId() <= object->getObjectId()))
 									)
 							{
@@ -360,29 +364,32 @@ void ModelValidationHelper::validateModel(void)
 						}
 
 						/* Validating a special object. The validation made here is to check if the special object
-				(constraint/index/trigger/view) references a column added by a relationship and
-				 that relationship is being created after the creation of the special object */
-						if(obj_type==OBJ_TABLE || obj_type==OBJ_VIEW /* || obj_type==OBJ_SEQUENCE */)
+						 * (constraint/index/trigger/view) references a column added by a relationship and
+						 *  that relationship is being created after the creation of the special object */
+						if(BaseTable::isBaseTable(obj_type) || obj_type == ObjectType::GenericSql)
 						{
-							vector<ObjectType> tab_aux_types={ OBJ_CONSTRAINT, OBJ_TRIGGER, OBJ_INDEX };
+							vector<ObjectType> tab_aux_types={ ObjectType::Constraint, ObjectType::Trigger, ObjectType::Index };
 							vector<TableObject *> *tab_objs;
 							vector<Column *> ref_cols;
 							vector<BaseObject *> rels;
 							BaseObject *rel=nullptr;
 							View *view=nullptr;
+							GenericSQL *gen_sql=nullptr;
 							Constraint *constr=nullptr;
 
-							table=dynamic_cast<Table *>(object);
+							table=dynamic_cast<PhysicalTable *>(object);
 							view=dynamic_cast<View *>(object);
+							gen_sql = dynamic_cast<GenericSQL *>(object);
 
 							if(table)
 							{
 								/* Checking the table children objects if they references some columns added by relationship.
-				If so, the id of the relationships are swapped with the child object if the first is created
-				after the latter. */
+								 * If so, the id of the relationships are swapped with the child object if the first is created
+								 * after the latter. */
 								for(auto &obj_tp : tab_aux_types)
 								{
 									tab_objs = table->getObjectList(obj_tp);
+									if(!tab_objs) continue;
 
 									for(auto &tab_obj : (*tab_objs))
 									{
@@ -391,14 +398,14 @@ void ModelValidationHelper::validateModel(void)
 
 										if(!tab_obj->isAddedByRelationship())
 										{
-											if(obj_tp==OBJ_CONSTRAINT)
+											if(obj_tp==ObjectType::Constraint)
 											{
 												constr=dynamic_cast<Constraint *>(tab_obj);
 
-												if(constr->getConstraintType()!=ConstraintType::primary_key)
+												if(constr->getConstraintType()!=ConstraintType::PrimaryKey)
 													ref_cols=constr->getRelationshipAddedColumns();
 											}
-											else if(obj_tp==OBJ_TRIGGER)
+											else if(obj_tp==ObjectType::Trigger)
 												ref_cols=dynamic_cast<Trigger *>(tab_obj)->getRelationshipAddedColumns();
 											else
 												ref_cols=dynamic_cast<Index *>(tab_obj)->getRelationshipAddedColumns();
@@ -412,11 +419,11 @@ void ModelValidationHelper::validateModel(void)
 												rels.push_back(rel);
 										}
 
-										generateValidationInfo(ValidationInfo::SP_OBJ_BROKEN_REFERENCE, tab_obj, rels);
+										generateValidationInfo(ValidationInfo::SpObjBrokenReference, tab_obj, rels);
 									}
 								}
 							}
-							else
+							else if(view)
 							{
 								ref_cols=view->getRelationshipAddedColumns();
 
@@ -428,42 +435,62 @@ void ModelValidationHelper::validateModel(void)
 										rels.push_back(rel);
 								}
 
-								generateValidationInfo(ValidationInfo::SP_OBJ_BROKEN_REFERENCE, object, rels);
+								generateValidationInfo(ValidationInfo::SpObjBrokenReference, object, rels);
+							}
+							else
+							{
+								Column *col = nullptr;
+
+								for(auto &ref_obj : gen_sql->getReferencedObjects())
+								{
+									col = dynamic_cast<Column *>(ref_obj);
+									if(!col || !col->isAddedByRelationship()) continue;
+
+									rel = col->getParentRelationship();
+
+									if(rel->getObjectId() > object->getObjectId() && std::find(rels.begin(), rels.end(), rel) == rels.end())
+										rels.push_back(rel);
+								}
+
+								generateValidationInfo(ValidationInfo::SpObjBrokenReference, object, rels);
 							}
 						}
 					}
 
-					generateValidationInfo(ValidationInfo::BROKEN_REFERENCE, object, refs_aux);
+					generateValidationInfo(ValidationInfo::BrokenReference, object, refs_aux);
 				}
 			}
 
 			//Emit a signal containing the validation progress
-			progress=((i+1)/static_cast<float>(count))*20;
+			progress=((i+1)/static_cast<double>(count))*20;
 			emit s_progressUpdated(progress, QString());
 		}
 
 
 		/* Step 2: Validating name conflitcs between primary keys, unique keys, exclude constraints
-	  and indexs of all tables/views. The table and view names are checked too. */
-		obj_list=db_model->getObjectList(OBJ_TABLE);
-		itr=obj_list->begin();
+		and indexs of all tables/foreign talbes/views. The tables/views names are checked too. */
+		aux_tables = *db_model->getObjectList(ObjectType::Table);
+		aux_tables.insert(aux_tables.end(),
+											db_model->getObjectList(ObjectType::View)->begin(),
+											db_model->getObjectList(ObjectType::View)->end());
+		itr = aux_tables.begin();
 
 		//Searching the model's tables and gathering all the constraints and index
-		while(itr!=obj_list->end() && !valid_canceled)
+		while(itr != aux_tables.end() && !valid_canceled)
 		{
-			table=dynamic_cast<Table *>(*itr);
-			emit s_objectProcessed(signal_msg.arg(table->getName()).arg(table->getTypeName()), table->getObjectType());
+			base_tab = dynamic_cast<BaseTable *>(*itr);
+			emit s_objectProcessed(signal_msg.arg(base_tab->getName()).arg(base_tab->getTypeName()), base_tab->getObjectType());
 
 			itr++;
 
 			for(i=0; i < count1 && !valid_canceled; i++)
 			{
-				cnt=table->getObjectCount(tab_obj_types[i]);
+				cnt=base_tab->getObjectCount(tab_obj_types[i]);
 
 				for(i1=0; i1 < cnt && !valid_canceled; i1++)
 				{
 					//Get the table object (constraint or index)
-					tab_obj=dynamic_cast<TableObject *>(table->getObject(i1, tab_obj_types[i]));
+					tab_obj=dynamic_cast<TableObject *>(base_tab->getObject(i1, tab_obj_types[i]));
 
 					//Configures the full name of the object including the parent name
 					name=tab_obj->getParentTable()->getSchema()->getName(true) + QString(".") + tab_obj->getName(true);
@@ -473,18 +500,18 @@ void ModelValidationHelper::validateModel(void)
 					constr=dynamic_cast<Constraint *>(tab_obj);
 
 					/* If the object is an index or	a primary key, unique or exclude constraint,
-		  insert the object on duplicated	objects map */
+					 * insert the object on duplicated	objects map */
 					if((!constr ||
-						(constr && (constr->getConstraintType()==ConstraintType::primary_key ||
-									constr->getConstraintType()==ConstraintType::unique ||
-									constr->getConstraintType()==ConstraintType::exclude))))
+						(constr && (constr->getConstraintType()==ConstraintType::PrimaryKey ||
+												constr->getConstraintType()==ConstraintType::Unique ||
+												constr->getConstraintType()==ConstraintType::Exclude))))
 						dup_objects[name].push_back(tab_obj);
 				}
 			}
 		}
 
-		/* Inserting the tables and views to the map in order to check if there are table objects
-	   that conflicts with thems */
+		/* Inserting the tables and views to the map in order to check if there are
+		 * other table objects that conflicts with them */
 		for(i=0; i < aux_cnt && !valid_canceled; i++)
 		{
 			obj_list=db_model->getObjectList(aux_types[i]);
@@ -506,12 +533,12 @@ void ModelValidationHelper::validateModel(void)
 			if(mitr->second.size() > 1)
 			{
 				refs.assign(mitr->second.begin() + 1, mitr->second.end());
-				generateValidationInfo(ValidationInfo::NO_UNIQUE_NAME, mitr->second.front(), refs);
+				generateValidationInfo(ValidationInfo::NoUniqueName, mitr->second.front(), refs);
 				refs.clear();
 			}
 
 			//Emit a signal containing the validation progress
-			progress=20 + ((i/static_cast<float>(dup_objects.size()))*20);
+			progress=20 + ((i/static_cast<double>(dup_objects.size()))*20);
 			emit s_progressUpdated(progress, QString());
 
 			i++; mitr++;
@@ -520,24 +547,31 @@ void ModelValidationHelper::validateModel(void)
 		// Step 3: Checking if columns of any table is using GiS data types and the postgis extension is not created.
 		if(!postgis_exists)
 		{
-			obj_list=db_model->getObjectList(OBJ_TABLE);
-			itr=obj_list->begin();
+			vector<BaseObject *> tabs;
+
+			tabs.assign(db_model->getObjectList(ObjectType::Table)->begin(),
+									db_model->getObjectList(ObjectType::Table)->end());
+			tabs.insert(tabs.end(),
+									db_model->getObjectList(ObjectType::ForeignTable)->begin(),
+									db_model->getObjectList(ObjectType::ForeignTable)->end());
+
+			itr=tabs.begin();
 			i=0;
 
-			while(itr!=obj_list->end() && !valid_canceled)
+			while(itr!=tabs.end() && !valid_canceled)
 			{
-				table = dynamic_cast<Table *>(*itr);
+				table = dynamic_cast<PhysicalTable *>(*itr);
 				itr++;
 
-				for(auto &obj : *table->getObjectList(OBJ_COLUMN))
+				for(auto &obj : *table->getObjectList(ObjectType::Column))
 				{
 					col = dynamic_cast<Column *>(obj);
 
 					if(col->getType().isGiSType())
-						generateValidationInfo(ValidationInfo::MISSING_EXTENSION, col, {});
+						generateValidationInfo(ValidationInfo::MissingExtension, col, {});
 				}
 
-				progress=30 + ((i/static_cast<float>(obj_list->size()))*20);
+				progress=30 + ((i/static_cast<double>(obj_list->size()))*20);
 			}
 		}
 
@@ -547,15 +581,15 @@ void ModelValidationHelper::validateModel(void)
 	   only when there is no validation infos generated because for each broken relationship there is the need to do a revalidation of all relationships */
 		if(val_infos.empty())
 		{
-			obj_list=db_model->getObjectList(OBJ_RELATIONSHIP);
-			itr=db_model->getObjectList(OBJ_RELATIONSHIP)->begin();
+			obj_list=db_model->getObjectList(ObjectType::Relationship);
+			itr=db_model->getObjectList(ObjectType::Relationship)->begin();
 
 			while(itr!=obj_list->end() && !valid_canceled)
 			{
-				progress=40 + ((i/static_cast<float>(obj_list->size()))*20);
+				progress=40 + ((i/static_cast<double>(obj_list->size()))*20);
 
 				if(dynamic_cast<Relationship *>(*itr)->isInvalidated())
-					generateValidationInfo(ValidationInfo::BROKEN_REL_CONFIG, *itr, {});
+					generateValidationInfo(ValidationInfo::BrokenRelConfig, *itr, {});
 
 				itr++;
 			}
@@ -590,7 +624,7 @@ void ModelValidationHelper::validateModel(void)
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(), e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
@@ -605,15 +639,15 @@ void ModelValidationHelper::applyFixes(void)
 			for(unsigned i=0; i < val_infos.size() && !valid_canceled; i++)
 			{
 				if(!validate_rels)
-					validate_rels=(val_infos[i].getValidationType()==ValidationInfo::BROKEN_REFERENCE ||
-												 val_infos[i].getValidationType()==ValidationInfo::SP_OBJ_BROKEN_REFERENCE ||
-												 val_infos[i].getValidationType()==ValidationInfo::NO_UNIQUE_NAME ||
-												 val_infos[i].getValidationType()==ValidationInfo::MISSING_EXTENSION);
+					validate_rels=(val_infos[i].getValidationType()==ValidationInfo::BrokenReference ||
+												 val_infos[i].getValidationType()==ValidationInfo::SpObjBrokenReference ||
+												 val_infos[i].getValidationType()==ValidationInfo::NoUniqueName ||
+												 val_infos[i].getValidationType()==ValidationInfo::MissingExtension);
 
 				/* Checking if a broken relatinship is found, when this is the case all the pending validation info
 		   will not be analyzed until no broken relationship is found */
 				if(!found_broken_rels)
-					found_broken_rels=(val_infos[i].getValidationType()==ValidationInfo::BROKEN_REL_CONFIG);
+					found_broken_rels=(val_infos[i].getValidationType()==ValidationInfo::BrokenRelConfig);
 
 				if(!valid_canceled)
 					resolveConflict(val_infos[i]);
@@ -658,7 +692,7 @@ void ModelValidationHelper::captureThreadError(Exception e)
 
 	emit s_validationInfoGenerated(val_info);
 
-	if(val_info.getValidationType()==ValidationInfo::SQL_VALIDATION_ERR)
+	if(val_info.getValidationType()==ValidationInfo::SqlValidationError)
 		emit s_validationFinished();
 }
 
