@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,7 +29,6 @@ based upon the code editor example provided by Qt
 #include <QPlainTextEdit>
 #include <QMenu>
 #include <QToolButton>
-#include <QTemporaryFile>
 #include <QProcess>
 #include <QLabel>
 #include "linenumberswidget.h"
@@ -72,7 +71,7 @@ class NumberedTextEditor : public QPlainTextEdit {
 		QToolButton *load_file_btn, *edit_src_btn, *clear_btn;
 
 		//! \brief The name of the temp file currently being used to edit the souce
-		QTemporaryFile tmp_src_file;
+		QString tmp_src_file;
 
 		//! \brief The process object that holds the source code editor app
 		QProcess src_editor_proc;
@@ -85,7 +84,7 @@ class NumberedTextEditor : public QPlainTextEdit {
 		void keyPressEvent(QKeyEvent *event);
 
 	public:
-		NumberedTextEditor(QWidget * parent = 0, bool handle_ext_files = false);
+		NumberedTextEditor(QWidget * parent = nullptr, bool handle_ext_files = false);
 		~NumberedTextEditor(void);
 
 		static void setDefaultFont(const QFont &font);
@@ -115,8 +114,10 @@ class NumberedTextEditor : public QPlainTextEdit {
 
 		void loadFile(void);
 		void editSource(void);
-		void updateSource(void);
+		void updateSource(int exit_code);
+		void handleProcessStart(void);
 		void handleProcessError(void);
+		void enableEditor(void);
 
 	public slots:
 		void setReadOnly(bool ro);
