@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -41,7 +41,14 @@ ObjectsTableWidget::ObjectsTableWidget(unsigned button_conf, bool conf_exclusion
 		emit s_cellClicked(row, col);
 	});
 
+	connect(resize_cols_tb, &QToolButton::clicked, [&](){
+	  table_tbw->resizeColumnsToContents();
+	  table_tbw->resizeRowsToContents();
+	  table_tbw->horizontalHeader()->setSectionResizeMode(table_tbw->horizontalHeader()->count() - 1, QHeaderView::Stretch);
+	});
+
 	this->conf_exclusion=conf_exclusion;
+	cells_editable = false;
 
 	setButtonConfiguration(button_conf);
 	setColumnCount(1);
@@ -63,23 +70,23 @@ void ObjectsTableWidget::setButtonConfiguration(unsigned button_conf)
 	bool move_btn = false;
 
 	//Checking via bitwise operation the buttons available on the 'button_conf'
-	move_btn=(button_conf & MOVE_BUTTONS) == MOVE_BUTTONS;
+	move_btn=(button_conf & MoveButtons) == MoveButtons;
 
 	move_down_tb->setVisible(move_btn);
 	move_up_tb->setVisible(move_btn);
 	move_first_tb->setVisible(move_btn);
 	move_last_tb->setVisible(move_btn);
 
-	edit_tb->setVisible((button_conf & EDIT_BUTTON) == EDIT_BUTTON);
-	remove_all_tb->setVisible((button_conf & REMOVE_ALL_BUTTON) == REMOVE_ALL_BUTTON);
+	edit_tb->setVisible((button_conf & EditButton) == EditButton);
+	remove_all_tb->setVisible((button_conf & RemoveAllButton) == RemoveAllButton);
 
-	add_tb->setVisible((button_conf & ADD_BUTTON) == ADD_BUTTON);
-	remove_tb->setVisible((button_conf & REMOVE_BUTTON) == REMOVE_BUTTON);
-	update_tb->setVisible((button_conf & UPDATE_BUTTON) == UPDATE_BUTTON);
-	duplicate_tb->setVisible((button_conf & DUPLICATE_BUTTON) == DUPLICATE_BUTTON);
+	add_tb->setVisible((button_conf & AddButton) == AddButton);
+	remove_tb->setVisible((button_conf & RemoveButton) == RemoveButton);
+	update_tb->setVisible((button_conf & UpdateButton) == UpdateButton);
+	duplicate_tb->setVisible((button_conf & DuplicateButton) == DuplicateButton);
 
 	//Disabling the horizontal spacers when no buttons are visible
-	if(button_conf==NO_BUTTONS)
+	if(button_conf==NoButtons)
 	{
 		left_spc->changeSize(0,0,QSizePolicy::Ignored,QSizePolicy::Ignored);
 		right_spc->changeSize(0,0,QSizePolicy::Ignored,QSizePolicy::Ignored);
@@ -95,10 +102,10 @@ void ObjectsTableWidget::setButtonConfiguration(unsigned button_conf)
 QTableWidgetItem *ObjectsTableWidget::getItem(unsigned row_idx, unsigned col_idx)
 {
 	if(row_idx >= static_cast<unsigned>(table_tbw->rowCount()))
-		throw Exception(ERR_REF_LIN_OBJTAB_INV_INDEX,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::RefRowObjectTabInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	if(col_idx >= static_cast<unsigned>(table_tbw->columnCount()))
-		throw Exception(ERR_REF_COL_OBJTAB_INV_INDEX,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::RefColObjectTabInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	return(table_tbw->item(row_idx, col_idx));
 }
@@ -133,18 +140,26 @@ void ObjectsTableWidget::setHeaderLabel(const QString &label, unsigned col_idx)
 	QTableWidgetItem *item=nullptr;
 
 	if(col_idx >= static_cast<unsigned>(table_tbw->columnCount()))
-		throw Exception(ERR_REF_COL_OBJTAB_INV_INDEX,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::RefColObjectTabInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	item=table_tbw->horizontalHeaderItem(col_idx);
 	item->setText(label);
 }
 
+void ObjectsTableWidget::setHeaderVisible(unsigned col_idx, bool visible)
+{
+  if(col_idx >= static_cast<unsigned>(table_tbw->columnCount()))
+		throw Exception(ErrorCode::RefColObjectTabInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+
+  table_tbw->horizontalHeader()->setSectionHidden(col_idx, !visible);
+}
+
 void ObjectsTableWidget::setHeaderIcon(const QIcon &icon, unsigned col_idx)
 {
 	QTableWidgetItem *item=nullptr;
 
 	if(col_idx >= static_cast<unsigned>(table_tbw->columnCount()))
-		throw Exception(ERR_REF_COL_OBJTAB_INV_INDEX,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::RefColObjectTabInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	item=table_tbw->horizontalHeaderItem(col_idx);
 	item->setIcon(icon);
@@ -168,7 +183,7 @@ void ObjectsTableWidget::clearCellText(unsigned row_idx, unsigned col_idx)
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(), e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
@@ -178,7 +193,7 @@ void ObjectsTableWidget::setRowFont(int row_idx, const QFont &font, const QColor
 	int col_count, i;
 
 	if(row_idx >= table_tbw->rowCount())
-		throw Exception(ERR_REF_LIN_OBJTAB_INV_INDEX,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::RefRowObjectTabInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	col_count=table_tbw->columnCount();
 	for(i=0; i < col_count; i++)
@@ -195,7 +210,7 @@ void ObjectsTableWidget::setRowData(const QVariant &data, unsigned row_idx)
 	QTableWidgetItem *item=nullptr;
 
 	if(row_idx >= static_cast<unsigned>(table_tbw->rowCount()))
-		throw Exception(ERR_REF_LIN_OBJTAB_INV_INDEX,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::RefRowObjectTabInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	//Gets the vertical header of the row. This header stores the whole row data.
 	item=table_tbw->verticalHeaderItem(row_idx);
@@ -217,7 +232,7 @@ QString ObjectsTableWidget::getHeaderLabel(unsigned col_idx)
 	QTableWidgetItem *item=nullptr;
 
 	if(col_idx >= static_cast<unsigned>(table_tbw->columnCount()))
-		throw Exception(ERR_REF_COL_OBJTAB_INV_INDEX,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::RefColObjectTabInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	item=table_tbw->horizontalHeaderItem(col_idx);
 	return(item->text());
@@ -258,7 +273,7 @@ QVariant ObjectsTableWidget::getRowData(unsigned row_idx)
 	QTableWidgetItem *item=nullptr;
 
 	if(row_idx >= static_cast<unsigned>(table_tbw->rowCount()))
-		throw Exception(ERR_REF_LIN_OBJTAB_INV_INDEX,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::RefRowObjectTabInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	item=table_tbw->verticalHeaderItem(row_idx);
 	return(item->data(Qt::UserRole));
@@ -331,7 +346,7 @@ void ObjectsTableWidget::addRow(unsigned lin_idx)
 
 	for(col_idx=0; col_idx < col_cont; col_idx++)
 	{
-		item=new QTableWidgetItem;
+		item=new QTableWidgetItem;		
 		table_tbw->setItem(lin_idx,col_idx,item);
 	}
 
@@ -355,7 +370,7 @@ void ObjectsTableWidget::removeRow(unsigned row_idx)
 	bool conf;
 
 	if(row_idx >= static_cast<unsigned>(table_tbw->rowCount()))
-		throw Exception(ERR_REF_LIN_OBJTAB_INV_INDEX,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::RefRowObjectTabInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	//Before remove the row, clears the selection
 	table_tbw->clearSelection();
@@ -386,16 +401,20 @@ void ObjectsTableWidget::removeRow(void)
 		{
 			if(conf_exclusion)
 				msg_box.show(trUtf8("Confirmation"),trUtf8("Do you really want to remove the selected item?"),
-							 Messagebox::CONFIRM_ICON, Messagebox::YES_NO_BUTTONS);
+							 Messagebox::ConfirmIcon, Messagebox::YesNoButtons);
 
 			if(!conf_exclusion || (conf_exclusion && msg_box.result()==QDialog::Accepted))
 			{
 				setRowData(QVariant::fromValue<void *>(nullptr), row_idx);
 				item->setData(Qt::UserRole, QVariant::fromValue<void *>(nullptr));
-				emit s_rowRemoved(row_idx);
+
+				emit s_rowAboutToRemove(row_idx);
+
 				table_tbw->removeRow(row_idx);
 				table_tbw->setCurrentItem(nullptr);
 				setButtonsEnabled();
+
+				emit s_rowRemoved(row_idx);
 			}
 		}
 	}
@@ -435,7 +454,7 @@ void ObjectsTableWidget::removeRows(void)
 			 activating the 'remove_all_tb' button */
 		if(conf_exclusion && sender_obj==remove_all_tb)
 			msg_box.show(trUtf8("Confirmation"),trUtf8("Do you really want to remove all the items?"),
-						 Messagebox::CONFIRM_ICON, Messagebox::YES_NO_BUTTONS);
+						 Messagebox::ConfirmIcon, Messagebox::YesNoButtons);
 
 		if(!conf_exclusion || (conf_exclusion && sender_obj!=remove_all_tb) ||
 				(conf_exclusion &&  sender_obj==remove_all_tb && msg_box.result()==QDialog::Accepted))
@@ -451,7 +470,7 @@ void ObjectsTableWidget::removeRows(void)
 void ObjectsTableWidget::removeColumn(unsigned col_idx)
 {
 	if(col_idx >= static_cast<unsigned>(table_tbw->columnCount()))
-		throw Exception(ERR_REF_COL_OBJTAB_INV_INDEX,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::RefColObjectTabInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	table_tbw->removeColumn(col_idx);
 	table_tbw->clearSelection();
@@ -570,7 +589,7 @@ void ObjectsTableWidget::setButtonsEnabled(unsigned button_conf, bool value)
 	if(item)
 		lin=item->row();
 
-	if((button_conf & MOVE_BUTTONS) == MOVE_BUTTONS)
+	if((button_conf & MoveButtons) == MoveButtons)
 	{
 		move_up_tb->setEnabled(value && lin > 0);
 		move_down_tb->setEnabled(value && lin >= 0 && lin < table_tbw->rowCount()-1);
@@ -578,28 +597,37 @@ void ObjectsTableWidget::setButtonsEnabled(unsigned button_conf, bool value)
 		move_last_tb->setEnabled(value && lin >=0 && lin < table_tbw->rowCount()-1);
 	}
 
-	if((button_conf & EDIT_BUTTON) == EDIT_BUTTON)
+	if((button_conf & EditButton) == EditButton)
 		edit_tb->setEnabled(value && lin >= 0);
 
-	if((button_conf & ADD_BUTTON) == ADD_BUTTON)
+	if((button_conf & AddButton) == AddButton)
 		add_tb->setEnabled(value);
 
-	if((button_conf & REMOVE_BUTTON) == REMOVE_BUTTON)
+	if((button_conf & RemoveButton) == RemoveButton)
 		remove_tb->setEnabled(value && lin >= 0);
 
-	if((button_conf & REMOVE_ALL_BUTTON) == REMOVE_ALL_BUTTON)
+	if((button_conf & RemoveAllButton) == RemoveAllButton)
 		remove_all_tb->setEnabled(value && table_tbw->rowCount() > 0);
 
-	if((button_conf & UPDATE_BUTTON) == UPDATE_BUTTON)
+	if((button_conf & UpdateButton) == UpdateButton)
 		update_tb->setEnabled(value && lin >= 0);
 
-	if((button_conf & DUPLICATE_BUTTON) == DUPLICATE_BUTTON)
+	if((button_conf & DuplicateButton) == DuplicateButton)
 		duplicate_tb->setEnabled(value && lin >= 0);
+
+	if((button_conf & ResizeColsButton) == ResizeColsButton)
+		resize_cols_tb->setEnabled(value && table_tbw->rowCount() > 0);
+}
+
+void ObjectsTableWidget::setCellsEditable(bool value)
+{
+	table_tbw->setSelectionBehavior(value ? QAbstractItemView::SelectItems : QAbstractItemView::SelectRows);
+	table_tbw->setEditTriggers(value ? QAbstractItemView::AllEditTriggers : QAbstractItemView::NoEditTriggers);
 }
 
 void ObjectsTableWidget::setButtonsEnabled(void)
 {
-	setButtonsEnabled(ALL_BUTTONS, true);
+	setButtonsEnabled(AllButtons, true);
 }
 
 void ObjectsTableWidget::emitRowSelected(void)
