@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ class OperationListWidget: public QWidget, public Ui::OperationListWidget {
 		void notifyUpdateOnModel(void);
 
 	public:
-		OperationListWidget(QWidget * parent = 0);
+		OperationListWidget(QWidget * parent = nullptr);
 
 	public slots:
 		void updateOperationList(void);
