@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
 #include "operatorwidget.h"
 
-OperatorWidget::OperatorWidget(QWidget *parent): BaseObjectWidget(parent, OBJ_OPERATOR)
+OperatorWidget::OperatorWidget(QWidget *parent): BaseObjectWidget(parent, ObjectType::Operator)
 {
 	try
 	{
@@ -47,24 +47,24 @@ OperatorWidget::OperatorWidget(QWidget *parent): BaseObjectWidget(parent, OBJ_OP
 
 
 		grid=dynamic_cast<QGridLayout *>(attributes_twg->widget(1)->layout());
-		for(i=Operator::FUNC_OPERATOR; i <= Operator::FUNC_RESTRICT; i++)
+		for(i=Operator::FuncOperator; i <= Operator::FuncRestrict; i++)
 		{
 			functions_sel[i]=nullptr;
-			functions_sel[i]=new ObjectSelectorWidget(OBJ_FUNCTION, true, this);
+			functions_sel[i]=new ObjectSelectorWidget(ObjectType::Function, true, this);
 
-			if(i!=Operator::FUNC_OPERATOR)
+			if(i!=Operator::FuncOperator)
 				grid->addWidget(functions_sel[i],i,1,1,1);
 		}
 
-		for(i=Operator::OPER_COMMUTATOR, i1=3; i <= Operator::OPER_NEGATOR; i++,i1++)
+		for(i=Operator::OperCommutator, i1=3; i <= Operator::OperNegator; i++,i1++)
 		{
 			operators_sel[i]=nullptr;
-			operators_sel[i]=new ObjectSelectorWidget(OBJ_OPERATOR, true, this);
+			operators_sel[i]=new ObjectSelectorWidget(ObjectType::Operator, true, this);
 			grid->addWidget(operators_sel[i],i1,1,1,1);
 		}
 
 		operator_grid->addWidget(functions_sel[0],0,1,1,3);
-		configureFormLayout(operator_grid, OBJ_OPERATOR);
+		configureFormLayout(operator_grid, ObjectType::Operator);
 
 		setRequiredField(operator_func_lbl);
 		setRequiredField(functions_sel[0]);
@@ -74,21 +74,21 @@ OperatorWidget::OperatorWidget(QWidget *parent): BaseObjectWidget(parent, OBJ_OP
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
 void OperatorWidget::setAttributes(DatabaseModel *model, OperationList *op_list, Schema *schema, Operator *oper)
 {
 	unsigned i;
-	PgSQLType left_type, right_type;
+	PgSqlType left_type, right_type;
 
 	BaseObjectWidget::setAttributes(model,op_list, oper, schema);
 
-	for(i=Operator::FUNC_OPERATOR; i <= Operator::FUNC_RESTRICT; i++)
+	for(i=Operator::FuncOperator; i <= Operator::FuncRestrict; i++)
 		functions_sel[i]->setModel(model);
 
-	for(i=Operator::OPER_COMMUTATOR; i <= Operator::OPER_NEGATOR; i++)
+	for(i=Operator::OperCommutator; i <= Operator::OperNegator; i++)
 		operators_sel[i]->setModel(model);
 
 	if(oper)
@@ -96,14 +96,14 @@ void OperatorWidget::setAttributes(DatabaseModel *model, OperationList *op_list,
 		hashes_chk->setChecked(oper->isHashes());
 		merges_chk->setChecked(oper->isMerges());
 
-		for(i=Operator::FUNC_OPERATOR; i <= Operator::FUNC_RESTRICT; i++)
+		for(i=Operator::FuncOperator; i <= Operator::FuncRestrict; i++)
 			functions_sel[i]->setSelectedObject(oper->getFunction(i));
 
-		for(i=Operator::OPER_COMMUTATOR; i <= Operator::OPER_NEGATOR; i++)
+		for(i=Operator::OperCommutator; i <= Operator::OperNegator; i++)
 			operators_sel[i]->setSelectedObject(oper->getOperator(i));
 
-		left_type=oper->getArgumentType(Operator::LEFT_ARG);
-		right_type=oper->getArgumentType(Operator::RIGHT_ARG);
+		left_type=oper->getArgumentType(Operator::LeftArg);
+		right_type=oper->getArgumentType(Operator::RightArg);
 	}
 
 	arg_types[0]->setAttributes(left_type, model);
@@ -125,13 +125,13 @@ void OperatorWidget::applyConfiguration(void)
 		oper->setHashes(hashes_chk->isChecked());
 		oper->setMerges(merges_chk->isChecked());
 
-		for(i=Operator::LEFT_ARG; i <= Operator::RIGHT_ARG; i++)
+		for(i=Operator::LeftArg; i <= Operator::RightArg; i++)
 			oper->setArgumentType(arg_types[i]->getPgSQLType(), i);
 
-		for(i=Operator::FUNC_OPERATOR; i <= Operator::FUNC_RESTRICT; i++)
+		for(i=Operator::FuncOperator; i <= Operator::FuncRestrict; i++)
 			oper->setFunction(dynamic_cast<Function *>(functions_sel[i]->getSelectedObject()), i);
 
-		for(i=Operator::OPER_COMMUTATOR; i <= Operator::OPER_NEGATOR; i++)
+		for(i=Operator::OperCommutator; i <= Operator::OperNegator; i++)
 			oper->setOperator(dynamic_cast<Operator *>(operators_sel[i]->getSelectedObject()), i);
 
 		finishConfiguration();
@@ -139,7 +139,7 @@ void OperatorWidget::applyConfiguration(void)
 	catch(Exception &e)
 	{
 		cancelConfiguration();
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
