@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ class ParameterWidget: public BaseObjectWidget, public Ui::ParameterWidget {
 		Parameter parameter;
 
 	public:
-		ParameterWidget(QWidget * parent = 0);
+		ParameterWidget(QWidget * parent = nullptr);
 		void setAttributes(Parameter parameter, DatabaseModel *model);
 		Parameter getParameter(void);
 
