@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ class PermissionWidget: public BaseObjectWidget, public Ui::PermissionWidget {
 		bool perms_changed;
 
 	public:
-		PermissionWidget(QWidget * parent = 0);
+		PermissionWidget(QWidget * parent = nullptr);
 		~PermissionWidget(void);
 
 		void setAttributes(DatabaseModel *model, BaseObject *objeto_pai, BaseObject *object);
