@@ -1,7 +1,7 @@
 /*
 # Projeto: Modelador de Banco de Dados PostgreSQL (pgsqlDBM)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -51,6 +51,8 @@ class PgModelerPlugin {
 	protected:
 		BaseForm *plugin_info_frm;
 
+		QMainWindow *main_window;
+
 	private:
 		QLabel	*icon_lbl,
 		*title_lbl,
@@ -63,6 +65,12 @@ class PgModelerPlugin {
 
 		virtual ~PgModelerPlugin(void);
 
+		/*! \brief This method is executed right before the main window is created and can be used to perform
+		 * plugin's initializations like UI modications and other miscellaneous initialization that can't be done
+		 * in the constructor. Additionally, a main window instance can be passed to the plugin in order to facilitate
+		 * customization on the UI. The default implementation is to do nothing else then only expose main window to the plugin. */
+		virtual void initPlugin(QMainWindow *main_window);
+
 		//! \brief Executes the plugins having a ModelWidget as input parameter.
 		virtual void executePlugin(ModelWidget *modelo)=0;
 
@@ -81,12 +89,17 @@ class PgModelerPlugin {
 		//! \brief Shows the plugin's information dialog
 		virtual void showPluginInfo(void) = 0;
 
-		//! \brief Returns the plugin's action shortcut
-		virtual QKeySequence getPluginShortcut(void) = 0;
+		/*! \brief Returns the plugin's action shortcut
+		 * The default implementation is to return an empty shortcut */
+		virtual QKeySequence getPluginShortcut(void);
+
+		/*! \brief Indicates if the plugin's has an action to be installed in a Qmenu instance
+		 * The default implementation is to indicate the presence of an action */
+		virtual bool hasMenuAction(void);
 
 		//! \brief Sets the plugin's all attributes at once.
 		void configurePluginInfo(const QString &title, const QString &version, const QString &author,
-								 const QString &description, const QString &ico_filename);
+														 const QString &description, const QString &ico_filename);
 };
 
 /* Declares the class PgModelerPlugin as interface, this means that the class is a base
