@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,14 +23,14 @@ PluginsConfigWidget::PluginsConfigWidget(QWidget *parent) : BaseConfigWidget(par
 	setupUi(this);
 
 	QGridLayout *grid=new QGridLayout(loaded_plugins_gb);
-	QDir dir=QDir(GlobalAttributes::PLUGINS_DIR);
+	QDir dir=QDir(GlobalAttributes::PluginsDir);
 
 	root_dir_edt->setText(dir.absolutePath());
 
-	plugins_tab=new ObjectsTableWidget(ObjectsTableWidget::EDIT_BUTTON, false, this);
+	plugins_tab=new ObjectsTableWidget(ObjectsTableWidget::EditButton, false, this);
 	plugins_tab->setColumnCount(3);
 	plugins_tab->setHeaderLabel(trUtf8("Plugin"),0);
-	plugins_tab->setHeaderIcon(QPixmap(PgModelerUiNS::getIconPath("plugins")),0);
+	plugins_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("plugins")),0);
 	plugins_tab->setHeaderLabel(trUtf8("Version"),1);
 	plugins_tab->setHeaderLabel(trUtf8("Library"),2);
 
@@ -65,8 +65,8 @@ void PluginsConfigWidget::loadConfiguration(void)
 {
 	vector<Exception> errors;
 	QString lib, plugin_name,
-			dir_plugins=GlobalAttributes::PLUGINS_DIR +
-						GlobalAttributes::DIR_SEPARATOR;
+			dir_plugins=GlobalAttributes::PluginsDir +
+						GlobalAttributes::DirSeparator;
 	QPluginLoader plugin_loader;
 	QStringList dir_list;
 	PgModelerPlugin *plugin=nullptr;
@@ -90,16 +90,16 @@ void PluginsConfigWidget::loadConfiguration(void)
 		 [PLUGINS ROOT DIR]/[PLUGIN NAME]/lib[PLUGIN NAME].[EXTENSION] */
 #ifdef Q_OS_WIN
 		lib=dir_plugins + plugin_name +
-			GlobalAttributes::DIR_SEPARATOR  +
+            GlobalAttributes::DirSeparator  +
 			plugin_name + QString(".dll");
 #else
 #ifdef Q_OS_MAC
 		lib=dir_plugins + plugin_name +
-			GlobalAttributes::DIR_SEPARATOR  +
+            GlobalAttributes::DirSeparator  +
 			QString("lib") + plugin_name + QString(".dylib");
 #else
 		lib=dir_plugins + plugin_name +
-			GlobalAttributes::DIR_SEPARATOR  +
+			GlobalAttributes::DirSeparator  +
 			QString("lib") + plugin_name + QString(".so");
 #endif
 #endif
@@ -111,21 +111,25 @@ void PluginsConfigWidget::loadConfiguration(void)
 			fi.setFile(lib);
 
 			//Inserts the loaded plugin on the vector
-			plugin=qobject_cast<PgModelerPlugin *>(plugin_loader.instance());
+			plugin = qobject_cast<PgModelerPlugin *>(plugin_loader.instance());
 			plugins.push_back(plugin);
 
-			//Configures the action related to plugin
-			plugin_action=new QAction(this);
-			plugin_action->setText(plugin->getPluginTitle());
-			plugin_action->setData(QVariant::fromValue<void *>(reinterpret_cast<void *>(plugin)));
-			plugin_action->setShortcut(plugin->getPluginShortcut());
+			if(plugin->hasMenuAction())
+			{
+				//Configures the action related to plugin
+				plugin_action=new QAction(this);
+				plugin_action->setText(plugin->getPluginTitle());
+				plugin_action->setData(QVariant::fromValue<void *>(reinterpret_cast<void *>(plugin)));
+				plugin_action->setShortcut(plugin->getPluginShortcut());
 
-			icon.load(dir_plugins + plugin_name +
-					  GlobalAttributes::DIR_SEPARATOR  +
-					  plugin_name + QString(".png"));
-			plugin_action->setIcon(icon);
+				icon.load(dir_plugins + plugin_name +
+									GlobalAttributes::DirSeparator  +
+									plugin_name + QString(".png"));
+
+				plugin_action->setIcon(icon);
+				plugins_actions.push_back(plugin_action);
+			}
 
-			plugins_actions.push_back(plugin_action);
 			plugins_tab->addRow();
 			plugins_tab->setCellText(plugin->getPluginTitle(), plugins_tab->getRowCount()-1, 0);
 			plugins_tab->setCellText(plugin->getPluginVersion(), plugins_tab->getRowCount()-1, 1);
@@ -133,31 +137,29 @@ void PluginsConfigWidget::loadConfiguration(void)
 		}
 		else
 		{
-			errors.push_back(Exception(Exception::getErrorMessage(ERR_PLUGIN_NOT_LOADED)
-									   .arg(dir_list.front())
-									   .arg(lib)
-									   .arg(plugin_loader.errorString()),
-									   ERR_PLUGIN_NOT_LOADED, __PRETTY_FUNCTION__,__FILE__,__LINE__));
+			errors.push_back(Exception(Exception::getErrorMessage(ErrorCode::PluginNotLoaded)
+																 .arg(dir_list.front())
+																 .arg(lib)
+																 .arg(plugin_loader.errorString()),
+																 ErrorCode::PluginNotLoaded, __PRETTY_FUNCTION__,__FILE__,__LINE__));
 		}
+
 		dir_list.pop_front();
 		plugins_tab->clearSelection();
 	}
 
 	if(!errors.empty())
-		throw Exception(ERR_PLUGINS_NOT_LOADED,__PRETTY_FUNCTION__,__FILE__,__LINE__, errors);
+		throw Exception(ErrorCode::PluginsNotLoaded,__PRETTY_FUNCTION__,__FILE__,__LINE__, errors);
 }
 
-void PluginsConfigWidget::installPluginsActions(QToolBar *toolbar, QMenu *menu, QObject *recv, const char *slot)
+void PluginsConfigWidget::installPluginsActions(QMenu *menu, QObject *recv, const char *slot)
 {
-	if((toolbar || menu) && slot)
+	if(menu && slot)
 	{
 		vector<QAction *>::iterator itr=plugins_actions.begin();
 
 		while(itr!=plugins_actions.end())
 		{
-			if(toolbar)
-				toolbar->addAction(*itr);
-
 			if(menu)
 				menu->addAction(*itr);
 
@@ -166,3 +168,9 @@ void PluginsConfigWidget::installPluginsActions(QToolBar *toolbar, QMenu *menu,
 		}
 	}
 }
+
+void PluginsConfigWidget::initPlugins(QMainWindow *main_window)
+{
+	for(auto &plugin : plugins)
+		plugin->initPlugin(main_window);
+}
