@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -50,15 +50,18 @@ class PluginsConfigWidget: public BaseConfigWidget, public Ui::PluginsConfigWidg
 		void addConfigurationParam(const QString &, const attribs_map &){}
 
 	public:
-		PluginsConfigWidget(QWidget *parent = 0);
+		PluginsConfigWidget(QWidget *parent = nullptr);
 		~PluginsConfigWidget(void);
 
 		//! \brief Since plugins has its own configurations this method load all plugins instead
 		void loadConfiguration(void);
 
-		/*! \brief Install the created actions on menu and toolbars. Additionally the user must specify the
+		/*! \brief Install the created actions on menu. Additionally the user must specify the
 		 receiver object and slot executed when the actions is activated */
-		void installPluginsActions(QToolBar *toolbar, QMenu *menu, QObject *recv, const char *slot);
+		void installPluginsActions(QMenu *menu, QObject *recv, const char *slot);
+
+		//*! \brief Performs the initialization of all loaded plugins (see PgModelerPlugin::initPlugin())
+		void initPlugins(QMainWindow *main_window);
 
 	private slots:
 		void showPluginInfo(int idx);
