@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,16 +35,20 @@ class RelationshipWidget: public BaseObjectWidget, public Ui::RelationshipWidget
 	private:
 		Q_OBJECT
 
-		static const unsigned GENERAL_TAB=0,
-		ATTRIBUTES_TAB=1,
-		CONSTRAINTS_TAB=2,
-		SPECIAL_PK_TAB=3,
-		ADVANCED_TAB=4;
+		static constexpr unsigned GeneralTab=0,
+		SettingsTab=1,
+		AttributesTab=2,
+		ConstraintsTab=3,
+		SpecialPkTab=4,
+		AdvancedTab=5;
 
-		HintTextWidget *gen_tab_name_ht, *ref_table_ht, *recv_table_ht, *identifier_ht, *single_pk_ht;
+		HintTextWidget *gen_tab_name_ht, *ref_table_ht, *recv_table_ht,
+		*identifier_ht, *single_pk_ht, *default_part_ht;
 
 		ColorPickerWidget *color_picker;
 
+		NumberedTextEditor *part_bound_expr_txt;
+
 		//! \brief Stores the tab objects to change the configuration of the form depending on the type of the relationship
 		QWidgetList tabs;
 
@@ -53,7 +57,8 @@ class RelationshipWidget: public BaseObjectWidget, public Ui::RelationshipWidget
 
 		SyntaxHighlighter *table1_hl,
 		*table2_hl,
-		*patterns_hl[7];
+		*patterns_hl[7],
+		*part_bound_expr_hl;
 
 		//! \brief Table widgets that stores the attributes, constraint and advanced objects of relationship
 		ObjectsTableWidget *attributes_tab,
@@ -76,10 +81,10 @@ class RelationshipWidget: public BaseObjectWidget, public Ui::RelationshipWidget
 		int openEditingForm(TableObject *object, BaseObject *parent = nullptr);
 
 	protected:
-		void setAttributes(DatabaseModel *model, OperationList *op_list, Table *src_tab, Table *dst_tab, unsigned rel_type);
+		void setAttributes(DatabaseModel *model, OperationList *op_list, PhysicalTable *src_tab, PhysicalTable *dst_tab, unsigned rel_type);
 
 	public:
-		RelationshipWidget(QWidget * parent = 0);
+		RelationshipWidget(QWidget * parent = nullptr);
 		void setAttributes(DatabaseModel *model, OperationList *op_list, BaseRelationship *base_rel);
 
 		QSize getIdealSize(void);
@@ -93,9 +98,9 @@ class RelationshipWidget: public BaseObjectWidget, public Ui::RelationshipWidget
 		void selectCopyOptions(void);
 		void listSpecialPkColumns(void);
 		void duplicateObject(int curr_row, int new_row);
-
 		void useFKGlobalSettings(bool value);
 		void usePatternGlobalSettings(bool value);
+		void generateBoundingExpr(void);
 
 	public slots:
 		void applyConfiguration(void);
