@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ class SceneInfoWidget: public QWidget, public Ui::SceneInfoWidget {
 		Q_OBJECT
 
 	public:
-		SceneInfoWidget(QWidget * parent = 0);
+		SceneInfoWidget(QWidget * parent = nullptr);
 
 	public slots:
 		void updateSelectedObject(BaseObjectView *object);
