@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,15 +23,15 @@
 
 map<QString, attribs_map> SnippetsConfigWidget::config_params;
 
-const QRegExp SnippetsConfigWidget::ID_FORMAT_REGEXP=QRegExp(QString("^([a-z])([a-z]*|(\\d)*|(_)*)+"), Qt::CaseInsensitive);
+const QRegExp SnippetsConfigWidget::IdFormatRegExp=QRegExp(QString("^([a-z])([a-z]*|(\\d)*|(_)*)+"), Qt::CaseInsensitive);
 
 SnippetsConfigWidget::SnippetsConfigWidget(QWidget * parent) : BaseConfigWidget(parent)
 {
 	QPixmap ico;
 	QString gen_purpose=trUtf8("General purpose");
 	map<QString, ObjectType> types_map;
-	vector<ObjectType> types=BaseObject::getObjectTypes(true, {OBJ_RELATIONSHIP, OBJ_TAG, OBJ_TEXTBOX,
-															   OBJ_PERMISSION, BASE_RELATIONSHIP });
+	vector<ObjectType> types=BaseObject::getObjectTypes(true, {ObjectType::Relationship, ObjectType::Tag, ObjectType::Textbox,
+																														 ObjectType::Permission, ObjectType::BaseRelationship });
 
 	setupUi(this);
 
@@ -41,15 +41,15 @@ SnippetsConfigWidget::SnippetsConfigWidget(QWidget * parent) : BaseConfigWidget(
 	//Creates a combo with the accepted object type
 	for(auto &itr : types_map)
 	{
-		ico.load(PgModelerUiNS::getIconPath(itr.second));
-		applies_to_cmb->addItem(ico, itr.first, itr.second);
-		filter_cmb->addItem(ico, itr.first, itr.second);
+		ico.load(PgModelerUiNs::getIconPath(itr.second));
+		applies_to_cmb->addItem(ico, itr.first, enum_cast(itr.second));
+		filter_cmb->addItem(ico, itr.first, enum_cast(itr.second));
 	}
 
-	applies_to_cmb->insertItem(0, gen_purpose, BASE_OBJECT);
+	applies_to_cmb->insertItem(0, gen_purpose, enum_cast(ObjectType::BaseObject));
 	applies_to_cmb->setCurrentIndex(0);
 
-	filter_cmb->insertItem(0, gen_purpose, BASE_OBJECT);
+	filter_cmb->insertItem(0, gen_purpose, enum_cast(ObjectType::BaseObject));
 	filter_cmb->insertItem(0, trUtf8("All snippets"));
 	filter_cmb->setCurrentIndex(0);
 
@@ -59,16 +59,16 @@ SnippetsConfigWidget::SnippetsConfigWidget(QWidget * parent) : BaseConfigWidget(
 	placeholders_ht=new HintTextWidget(placeholders_hint, this);
 	placeholders_ht->setText(placeholders_chk->statusTip());
 
-	snippet_txt=PgModelerUiNS::createNumberedTextEditor(snippet_wgt);
+	snippet_txt=PgModelerUiNs::createNumberedTextEditor(snippet_wgt);
 
 	try
 	{
 		snippet_hl=new SyntaxHighlighter(snippet_txt);
-		snippet_hl->loadConfiguration(GlobalAttributes::SQL_HIGHLIGHT_CONF_PATH);
+		snippet_hl->loadConfiguration(GlobalAttributes::SQLHighlightConfPath);
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__,&e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__,&e);
 	}
 
 	enableEditMode(false);
@@ -106,13 +106,13 @@ attribs_map SnippetsConfigWidget::getSnippetById(const QString &snip_id)
 QStringList SnippetsConfigWidget::getSnippetsIdsByObject(ObjectType obj_type)
 {
 	QStringList ids;
-	QString type_name=(obj_type==BASE_OBJECT ?
-						   ParsersAttributes::GENERAL : BaseObject::getSchemaName(obj_type));
+	QString type_name=(obj_type==ObjectType::BaseObject ?
+						   Attributes::General : BaseObject::getSchemaName(obj_type));
 
 	for(auto &snip : config_params)
 	{
-		if(snip.second[ParsersAttributes::OBJECT]==type_name)
-			ids.push_back(snip.second[ParsersAttributes::ID]);
+		if(snip.second[Attributes::Object]==type_name)
+			ids.push_back(snip.second[Attributes::Id]);
 	}
 
 	return(ids);
@@ -121,12 +121,12 @@ QStringList SnippetsConfigWidget::getSnippetsIdsByObject(ObjectType obj_type)
 vector<attribs_map> SnippetsConfigWidget::getSnippetsByObject(ObjectType obj_type)
 {
 	vector<attribs_map> snippets;
-	QString type_name=(obj_type==BASE_OBJECT ?
-						   ParsersAttributes::GENERAL : BaseObject::getSchemaName(obj_type));
+	QString type_name=(obj_type==ObjectType::BaseObject ?
+						   Attributes::General : BaseObject::getSchemaName(obj_type));
 
 	for(auto &snip : config_params)
 	{
-		if(snip.second[ParsersAttributes::OBJECT]==type_name)
+		if(snip.second[Attributes::Object]==type_name)
 			snippets.push_back(snip.second);
 	}
 
@@ -160,9 +160,9 @@ QString SnippetsConfigWidget::parseSnippet(attribs_map snippet, attribs_map attr
 { 
 	SchemaParser schparser;
 	QStringList aux_attribs;
-	QString buf=snippet[ParsersAttributes::CONTENTS];
+	QString buf=snippet[Attributes::Contents];
 
-	if(snippet[ParsersAttributes::PARSABLE]!=ParsersAttributes::_TRUE_)
+	if(snippet[Attributes::Parsable]!=Attributes::True)
 		return(buf);
 
 	try
@@ -170,7 +170,7 @@ QString SnippetsConfigWidget::parseSnippet(attribs_map snippet, attribs_map attr
 		schparser.loadBuffer(buf);
 
 		//Assigning dummy values for empty attributes
-		if(snippet[ParsersAttributes::PLACEHOLDERS]==ParsersAttributes::_TRUE_)
+		if(snippet[Attributes::Placeholders]==Attributes::True)
 		{
 			aux_attribs=schparser.extractAttributes();
 			for(QString attr : aux_attribs)
@@ -187,7 +187,7 @@ QString SnippetsConfigWidget::parseSnippet(attribs_map snippet, attribs_map attr
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__,&e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__,&e);
 	}
 }
 
@@ -213,24 +213,24 @@ void SnippetsConfigWidget::fillSnippetsCombo(map<QString, attribs_map> &config)
 	snippets_cmb->clear();
 
 	for(auto &cfg : config)
-		snippets_cmb->addItem(QString("[%1] %2").arg(cfg.first, cfg.second.at(ParsersAttributes::LABEL)), cfg.first);
+		snippets_cmb->addItem(QString("[%1] %2").arg(cfg.first, cfg.second.at(Attributes::Label)), cfg.first);
 }
 
 bool SnippetsConfigWidget::isSnippetValid(attribs_map &attribs, const QString &orig_id)
 {
 	Messagebox msg_box;
-	QString snip_id=attribs.at(ParsersAttributes::ID),
+	QString snip_id=attribs.at(Attributes::Id),
 			err_msg;
 
 	if(!orig_id.isEmpty() && snip_id!=orig_id && config_params.count(snip_id)!=0)
 		err_msg=trUtf8("Duplicated snippet id <strong>%1</strong> detected. Please, specify a different one!").arg(snip_id);
-	else if(!ID_FORMAT_REGEXP.exactMatch(snip_id))
+	else if(!IdFormatRegExp.exactMatch(snip_id))
 		err_msg=trUtf8("Invalid ID pattern detected <strong>%1</strong>. This one must start with at leat one letter and be composed by letters, numbers and/or underscore!").arg(snip_id);
-	else if(attribs[ParsersAttributes::LABEL].isEmpty())
+	else if(attribs[Attributes::Label].isEmpty())
 		err_msg=trUtf8("Empty label for snippet <strong>%1</strong>. Please, specify a value for it!").arg(snip_id);
-	else if(attribs[ParsersAttributes::CONTENTS].isEmpty())
+	else if(attribs[Attributes::Contents].isEmpty())
 		err_msg=trUtf8("Empty code for snippet <strong>%1</strong>. Please, specify a value for it!").arg(snip_id);
-	else if(attribs[ParsersAttributes::PARSABLE]==ParsersAttributes::_TRUE_)
+	else if(attribs[Attributes::Parsable]==Attributes::True)
 	{
 		try
 		{
@@ -251,7 +251,7 @@ bool SnippetsConfigWidget::isSnippetValid(attribs_map &attribs, const QString &o
 
 	if(!err_msg.isEmpty())
 	{
-		msg_box.show(err_msg, Messagebox::ERROR_ICON, Messagebox::OK_BUTTON);
+		msg_box.show(err_msg, Messagebox::ErrorIcon, Messagebox::OkButton);
 		return(false);
 	}
 	else
@@ -270,7 +270,7 @@ void SnippetsConfigWidget::loadConfiguration(void)
 		QStringList inv_snippets;
 
 		this->resetForm();
-		BaseConfigWidget::loadConfiguration(GlobalAttributes::SNIPPETS_CONF, config_params, { ParsersAttributes::ID });
+		BaseConfigWidget::loadConfiguration(GlobalAttributes::SnippetsConf, config_params, { Attributes::Id });
 
 		//Check if there are invalid snippets loaded
 		for(auto &snip : config_params)
@@ -287,7 +287,7 @@ void SnippetsConfigWidget::loadConfiguration(void)
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e, e.getExtraInfo());
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e, e.getExtraInfo());
 	}
 }
 
@@ -306,28 +306,28 @@ attribs_map SnippetsConfigWidget::getSnippetAttributes(void)
 	QString object_id=BaseObject::getSchemaName(static_cast<ObjectType>(applies_to_cmb->currentData().toUInt()));
 
 	if(object_id.isEmpty())
-		object_id=ParsersAttributes::GENERAL;
+		object_id=Attributes::General;
 
-	return(attribs_map{ {ParsersAttributes::ID, id_edt->text()},
-						{ParsersAttributes::LABEL, label_edt->text()},
-						{ParsersAttributes::OBJECT, object_id},
-						{ParsersAttributes::PARSABLE, (parsable_chk->isChecked() ? ParsersAttributes::_TRUE_ : ParsersAttributes::_FALSE_)},
-						{ParsersAttributes::PLACEHOLDERS, (parsable_chk->isChecked() && placeholders_chk->isChecked() ?
-						 ParsersAttributes::_TRUE_ : ParsersAttributes::_FALSE_)},
-						{ParsersAttributes::CONTENTS, snippet_txt->toPlainText()} });
+	return(attribs_map{ {Attributes::Id, id_edt->text()},
+						{Attributes::Label, label_edt->text()},
+						{Attributes::Object, object_id},
+						{Attributes::Parsable, (parsable_chk->isChecked() ? Attributes::True : Attributes::False)},
+						{Attributes::Placeholders, (parsable_chk->isChecked() && placeholders_chk->isChecked() ?
+						 Attributes::True : Attributes::False)},
+						{Attributes::Contents, snippet_txt->toPlainText()} });
 }
 
 void SnippetsConfigWidget::editSnippet(void)
 {
 	QString snip_id=snippets_cmb->currentData().toString();
-	ObjectType obj_type=BaseObject::getObjectType(config_params[snip_id].at(ParsersAttributes::OBJECT));
+	ObjectType obj_type=BaseObject::getObjectType(config_params[snip_id].at(Attributes::Object));
 
 	enableEditMode(true);
-	snippet_txt->setPlainText(config_params[snip_id].at(ParsersAttributes::CONTENTS));
+	snippet_txt->setPlainText(config_params[snip_id].at(Attributes::Contents));
 	id_edt->setText(snip_id);
-	label_edt->setText(config_params[snip_id].at(ParsersAttributes::LABEL));
-	parsable_chk->setChecked(config_params[snip_id].at(ParsersAttributes::PARSABLE)==ParsersAttributes::_TRUE_);
-	placeholders_chk->setChecked(config_params[snip_id].at(ParsersAttributes::PLACEHOLDERS)==ParsersAttributes::_TRUE_);
+	label_edt->setText(config_params[snip_id].at(Attributes::Label));
+	parsable_chk->setChecked(config_params[snip_id].at(Attributes::Parsable)==Attributes::True);
+	placeholders_chk->setChecked(config_params[snip_id].at(Attributes::Placeholders)==Attributes::True);
 	applies_to_cmb->setCurrentText(BaseObject::getTypeName(obj_type));
 }
 
@@ -364,7 +364,7 @@ void SnippetsConfigWidget::removeAllSnippets(void)
 	Messagebox msg_box;
 
 	msg_box.show(trUtf8("Do you really want to remove all snippets?"),
-				 Messagebox::CONFIRM_ICON, Messagebox::YES_NO_BUTTONS);
+				 Messagebox::ConfirmIcon, Messagebox::YesNoButtons);
 
 	if(msg_box.result()==QDialog::Accepted)
 	{
@@ -414,11 +414,11 @@ void SnippetsConfigWidget::filterSnippets(int idx)
 		QString object_id=BaseObject::getSchemaName(obj_type);
 
 		if(object_id.isEmpty())
-			object_id=ParsersAttributes::GENERAL;
+			object_id=Attributes::General;
 
 		for(auto &cfg : config_params)
 		{
-			if(cfg.second.at(ParsersAttributes::OBJECT)==object_id)
+			if(cfg.second.at(Attributes::Object)==object_id)
 				flt_snippets[cfg.first]=cfg.second;
 		}
 
@@ -433,7 +433,7 @@ void SnippetsConfigWidget::parseSnippet(void)
 	try
 	{
 		parseSnippet(getSnippetAttributes(), attribs_map());
-		msg_box.show(trUtf8("No syntax errors found in the snippet."), Messagebox::INFO_ICON);
+		msg_box.show(trUtf8("No syntax errors found in the snippet."), Messagebox::InfoIcon);
 	}
 	catch(Exception &e)
 	{
@@ -445,14 +445,14 @@ void SnippetsConfigWidget::saveConfiguration(void)
 { 
 	try
 	{
-		QString root_dir=GlobalAttributes::TMPL_CONFIGURATIONS_DIR +
-						 GlobalAttributes::DIR_SEPARATOR,
+		QString root_dir=GlobalAttributes::TmplConfigurationDir +
+						 GlobalAttributes::DirSeparator,
 
 				snippet_sch=root_dir +
-							GlobalAttributes::SCHEMAS_DIR +
-							GlobalAttributes::DIR_SEPARATOR +
-							ParsersAttributes::SNIPPET +
-							GlobalAttributes::SCHEMA_EXT;
+							GlobalAttributes::SchemasDir +
+							GlobalAttributes::DirSeparator +
+							Attributes::Snippet +
+							GlobalAttributes::SchemaExt;
 
 		attribs_map attribs;
 		ObjectType obj_type;
@@ -466,17 +466,17 @@ void SnippetsConfigWidget::saveConfiguration(void)
 
 			for(auto &snip : snippets)
 			{
-				attribs[ParsersAttributes::SNIPPET]+=
+				attribs[Attributes::Snippet]+=
 						schparser.convertCharsToXMLEntities(schparser.getCodeDefinition(snippet_sch, snip));
 			}
 		}
 
-		config_params[GlobalAttributes::SNIPPETS_CONF]=attribs;
-		BaseConfigWidget::saveConfiguration(GlobalAttributes::SNIPPETS_CONF, config_params);
+		config_params[GlobalAttributes::SnippetsConf]=attribs;
+		BaseConfigWidget::saveConfiguration(GlobalAttributes::SnippetsConf, config_params);
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
@@ -484,13 +484,13 @@ void SnippetsConfigWidget::restoreDefaults(void)
 {
 	try
 	{
-		BaseConfigWidget::restoreDefaults(GlobalAttributes::SNIPPETS_CONF, false);
+		BaseConfigWidget::restoreDefaults(GlobalAttributes::SnippetsConf, false);
 		this->loadConfiguration();
 		setConfigurationChanged(true);
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
@@ -520,8 +520,8 @@ void SnippetsConfigWidget::configureSnippetsMenu(QMenu *snip_menu, vector<Object
 
 	for(attribs_map snip : snippets)
 	{
-		object=snip[ParsersAttributes::OBJECT];
-		snip_id=snip[ParsersAttributes::ID];
+		object=snip[Attributes::Object];
+		snip_id=snip[Attributes::Id];
 
 		//Creating the snippet submenu for the current object type
 		if(submenus.count(object)==0)
@@ -534,7 +534,7 @@ void SnippetsConfigWidget::configureSnippetsMenu(QMenu *snip_menu, vector<Object
 				type_name=trUtf8("General");
 			}
 			else
-				ico=QPixmap(PgModelerUiNS::getIconPath(object));
+				ico=QPixmap(PgModelerUiNs::getIconPath(object));
 
 			menu=new QMenu(type_name, snip_menu);
 			menu->setIcon(ico);
@@ -543,19 +543,28 @@ void SnippetsConfigWidget::configureSnippetsMenu(QMenu *snip_menu, vector<Object
 
 			/* If the current group (object) is general does not include the submenu yet.
 		 This will be included as the last submenu */
-			if(object!=ParsersAttributes::GENERAL)
+			if(object!=Attributes::General)
 				snip_menu->addMenu(menu);
 		}
 
 		//Creating the action for the current snippet
-		act=new QAction(QPixmap(PgModelerUiNS::getIconPath("codesnippet")), snip_id, submenus[object]);
-		act->setToolTip(snip[ParsersAttributes::LABEL]);
+		act=new QAction(QPixmap(PgModelerUiNs::getIconPath("codesnippet")), snip_id, submenus[object]);
+		act->setToolTip(snip[Attributes::Label]);
 		submenus[object]->addAction(act);
 	}
 
 	//Include the "general" submenu at the end of snippet menu
-	if(submenus.count(ParsersAttributes::GENERAL)!=0)
-		snip_menu->addMenu(submenus[ParsersAttributes::GENERAL]);
+	if(submenus.count(Attributes::General)!=0)
+	{
+		if(snip_menu->isEmpty())
+		  snip_menu->addMenu(submenus[Attributes::General]);
+		else
+		{
+		  //Inserting the "general" submenu at the top of snippets actions
+		  snip_menu->insertMenu(snip_menu->actions().at(0), submenus[Attributes::General]);
+		  snip_menu->insertSeparator(snip_menu->actions().at(1));
+		}
+	}
 }
 
 bool SnippetsConfigWidget::isSnippetExists(const QString &snip_id)
