@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,21 +25,21 @@ SourceCodeWidget::SourceCodeWidget(QWidget *parent): BaseObjectWidget(parent)
 	try
 	{
 		Ui_SourceCodeWidget::setupUi(this);
-		configureFormLayout(codigofonte_grid, BASE_OBJECT);
+		configureFormLayout(codigofonte_grid, ObjectType::BaseObject);
 		comment_lbl->setVisible(false);
 		comment_edt->setVisible(false);
 
 		hl_sqlcode=nullptr;
 		hl_xmlcode=nullptr;
 
-		sqlcode_txt=PgModelerUiNS::createNumberedTextEditor(sqlcode_wgt);
+		sqlcode_txt=PgModelerUiNs::createNumberedTextEditor(sqlcode_wgt);
 		sqlcode_txt->setReadOnly(true);
 
-		xmlcode_txt=PgModelerUiNS::createNumberedTextEditor(xmlcode_wgt);
+		xmlcode_txt=PgModelerUiNs::createNumberedTextEditor(xmlcode_wgt);
 		xmlcode_txt->setReadOnly(true);
 
 		name_edt->setReadOnly(true);
-		version_cmb->addItems(PgSQLVersions::ALL_VERSIONS);
+		version_cmb->addItems(PgSqlVersions::AllVersions);
 
 		code_options_ht=new HintTextWidget(code_options_hint, this);
 		code_options_ht->setText(
@@ -59,7 +59,7 @@ SourceCodeWidget::SourceCodeWidget(QWidget *parent): BaseObjectWidget(parent)
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
@@ -76,11 +76,11 @@ void SourceCodeWidget::setSourceCodeTab(int)
 		code_icon=QString("codigoxml");
 
 	enabled=(sourcecode_twg->currentIndex()==0 &&
-			 ((obj_type==BASE_RELATIONSHIP &&
-			   dynamic_cast<BaseRelationship *>(object)->getRelationshipType()==BaseRelationship::RELATIONSHIP_FK)
-			  || (obj_type!=BASE_RELATIONSHIP && obj_type!=OBJ_TEXTBOX)));
+			 ((obj_type==ObjectType::BaseRelationship &&
+			   dynamic_cast<BaseRelationship *>(object)->getRelationshipType()==BaseRelationship::RelationshipFk)
+			  || (obj_type!=ObjectType::BaseRelationship && obj_type!=ObjectType::Textbox)));
 
-	icone=QPixmap(PgModelerUiNS::getIconPath(code_icon));
+	icone=QPixmap(PgModelerUiNs::getIconPath(code_icon));
 	icon_lbl->setPixmap(icone);
 	version_cmb->setEnabled(enabled);
 	pgsql_lbl->setEnabled(enabled);
@@ -109,8 +109,8 @@ void SourceCodeWidget::saveSQLCode(void)
 			out.setFileName(file_dlg.selectedFiles().at(0));
 
 			if(!out.open(QFile::WriteOnly))
-				throw Exception(Exception::getErrorMessage(ERR_FILE_DIR_NOT_WRITTEN).arg(file_dlg.selectedFiles().at(0)),
-								ERR_FILE_DIR_NOT_WRITTEN,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+				throw Exception(Exception::getErrorMessage(ErrorCode::FileDirectoryNotWritten).arg(file_dlg.selectedFiles().at(0)),
+												ErrorCode::FileDirectoryNotWritten,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 			buf.append(sqlcode_txt->toPlainText());
 			out.write(buf.data(), buf.size());
@@ -130,31 +130,31 @@ void SourceCodeWidget::generateSourceCode(int)
 		xmlcode_txt->clear();
 
 		obj_type=object->getObjectType();
-		if(obj_type!=OBJ_TEXTBOX ||
-				(obj_type==BASE_RELATIONSHIP &&
-				 dynamic_cast<BaseRelationship *>(object)->getRelationshipType()==BaseRelationship::RELATIONSHIP_FK))
+		if(obj_type!=ObjectType::Textbox ||
+				(obj_type==ObjectType::BaseRelationship &&
+				 dynamic_cast<BaseRelationship *>(object)->getRelationshipType()==BaseRelationship::RelationshipFk))
 		{
 			QString aux_def;
 			BaseObject::setPgSQLVersion(version_cmb->currentText());
 
-			if(obj_type==OBJ_DATABASE)
+			if(obj_type==ObjectType::Database)
 			{
 				task_prog_wgt=new TaskProgressWidget;
 				task_prog_wgt->setWindowTitle(trUtf8("Generating source code..."));
 				task_prog_wgt->show();
 				connect(this->model, SIGNAL(s_objectLoaded(int,QString,unsigned)), task_prog_wgt, SLOT(updateProgress(int,QString,unsigned)));
-				sqlcode_txt->setPlainText(object->getCodeDefinition(SchemaParser::SQL_DEFINITION));
+				sqlcode_txt->setPlainText(object->getCodeDefinition(SchemaParser::SqlDefinition));
 			}
 			else
 			{
-				if(code_options_cmb->currentIndex()==ORIGINAL_SQL)
-					sqlcode_txt->setPlainText(object->getCodeDefinition(SchemaParser::SQL_DEFINITION));
+				if(code_options_cmb->currentIndex()==OriginalSql)
+					sqlcode_txt->setPlainText(object->getCodeDefinition(SchemaParser::SqlDefinition));
 				else
 				{
-					vector<BaseObject *> objs=model->getCreationOrder(object, code_options_cmb->currentIndex()==CHILDREN_SQL);
+					vector<BaseObject *> objs=model->getCreationOrder(object, code_options_cmb->currentIndex()==ChildrenSql);
 
 					for(BaseObject *obj : objs)
-						aux_def+=obj->getCodeDefinition(SchemaParser::SQL_DEFINITION);
+						aux_def+=obj->getCodeDefinition(SchemaParser::SqlDefinition);
 				}
 
 				if(!aux_def.isEmpty())
@@ -193,7 +193,7 @@ void SourceCodeWidget::generateSourceCode(int)
 #warning "DEMO VERSION: XML code preview disabled."
 		xmlcode_txt->setPlainText(trUtf8("<!-- XML code preview disabled in demonstration version -->"));
 #else
-		xmlcode_txt->setPlainText(object->getCodeDefinition(SchemaParser::XML_DEFINITION));
+		xmlcode_txt->setPlainText(object->getCodeDefinition(SchemaParser::XmlDefinition));
 #endif
 
 		setSourceCodeTab();
@@ -213,7 +213,7 @@ void SourceCodeWidget::generateSourceCode(int)
 			disconnect(this->model, nullptr, task_prog_wgt, nullptr);
 			delete(task_prog_wgt);
 		}
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
@@ -229,29 +229,29 @@ void SourceCodeWidget::setAttributes(DatabaseModel *model, BaseObject *object)
 			this->name_edt->setText(QString("%1 (%2)").arg(object->getSignature()).arg(object->getTypeName()));
 			this->protected_obj_frm->setVisible(false);
 			this->obj_id_lbl->setVisible(false);
-			this->code_options_cmb->setEnabled(obj_type!=OBJ_DATABASE &&
-																					obj_type!=OBJ_TEXTBOX &&
-																					obj_type!=BASE_RELATIONSHIP &&
-																					obj_type!=OBJ_RELATIONSHIP);
+			this->code_options_cmb->setEnabled(obj_type!=ObjectType::Database &&
+																					obj_type!=ObjectType::Textbox &&
+																					obj_type!=ObjectType::BaseRelationship &&
+																					obj_type!=ObjectType::Relationship);
 
 #ifdef DEMO_VERSION
 #warning "DEMO VERSION: SQL code display options disabled."
 			code_options_cmb->setEnabled(false);
 #endif
 
-			obj_icon_lbl->setPixmap(QPixmap(PgModelerUiNS::getIconPath(object->getObjectType())));
+			obj_icon_lbl->setPixmap(QPixmap(PgModelerUiNs::getIconPath(object->getObjectType())));
 
 			if(!hl_sqlcode->isConfigurationLoaded())
-				hl_sqlcode->loadConfiguration(GlobalAttributes::SQL_HIGHLIGHT_CONF_PATH);
+				hl_sqlcode->loadConfiguration(GlobalAttributes::SQLHighlightConfPath);
 
 			if(!hl_xmlcode->isConfigurationLoaded())
-				hl_xmlcode->loadConfiguration(GlobalAttributes::XML_HIGHLIGHT_CONF_PATH);
+				hl_xmlcode->loadConfiguration(GlobalAttributes::XMLHighlightConfPath);
 
 			generateSourceCode();
 		}
 		catch(Exception &e)
 		{
-			throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+			throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 		}
 	}
 }
