@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,16 +27,14 @@
 map<QString, QString> SQLExecutionWidget::cmd_history;
 
 int SQLExecutionWidget::cmd_history_max_len = 1000;
-const QString SQLExecutionWidget::COLUMN_NULL_VALUE = QString("␀");
+const QString SQLExecutionWidget::ColumnNullValue = QString("␀");
 
 SQLExecutionWidget::SQLExecutionWidget(QWidget * parent) : QWidget(parent)
 {
 	setupUi(this);
 
-	result_model = nullptr;
-
-	sql_cmd_txt=PgModelerUiNS::createNumberedTextEditor(sql_cmd_wgt);
-	cmd_history_txt=PgModelerUiNS::createNumberedTextEditor(cmd_history_parent);
+	sql_cmd_txt=PgModelerUiNs::createNumberedTextEditor(sql_cmd_wgt);
+	cmd_history_txt=PgModelerUiNs::createNumberedTextEditor(cmd_history_parent);
 	cmd_history_txt->setCustomContextMenuEnabled(false);
 
 	cmd_history_txt->setTabStopWidth(sql_cmd_txt->getTabWidth());
@@ -55,10 +53,10 @@ SQLExecutionWidget::SQLExecutionWidget(QWidget * parent) : QWidget(parent)
 	connect(find_history_wgt->hide_tb, SIGNAL(clicked(bool)), find_history_parent, SLOT(hide()));
 
 	sql_cmd_hl=new SyntaxHighlighter(sql_cmd_txt, false);
-	sql_cmd_hl->loadConfiguration(GlobalAttributes::SQL_HIGHLIGHT_CONF_PATH);
+	sql_cmd_hl->loadConfiguration(GlobalAttributes::SQLHighlightConfPath);
 
 	cmd_history_hl=new SyntaxHighlighter(cmd_history_txt, false);
-	cmd_history_hl->loadConfiguration(GlobalAttributes::SQL_HIGHLIGHT_CONF_PATH);
+	cmd_history_hl->loadConfiguration(GlobalAttributes::SQLHighlightConfPath);
 
 	results_parent->setVisible(false);
 	output_tbw->setTabEnabled(0, false);
@@ -79,22 +77,50 @@ SQLExecutionWidget::SQLExecutionWidget(QWidget * parent) : QWidget(parent)
 	connect(find_replace_wgt->hide_tb, SIGNAL(clicked(bool)), find_tb, SLOT(toggle()));
 
 	run_sql_tb->setToolTip(run_sql_tb->toolTip() + QString(" (%1)").arg(run_sql_tb->shortcut().toString()));
+	stop_tb->setToolTip(stop_tb->toolTip() + QString(" (%1)").arg(stop_tb->shortcut().toString()));
 	export_tb->setToolTip(export_tb->toolTip() + QString(" (%1)").arg(export_tb->shortcut().toString()));
 	file_tb->setToolTip(file_tb->toolTip() + QString(" (%1)").arg(file_tb->shortcut().toString()));
 	output_tb->setToolTip(output_tb->toolTip() + QString(" (%1)").arg(output_tb->shortcut().toString()));
 	find_tb->setToolTip(find_tb->toolTip() + QString(" (%1)").arg(find_tb->shortcut().toString()));
+	filter_tb->setToolTip(filter_tb->toolTip() + QString(" (%1)").arg(filter_tb->shortcut().toString()));
 
 	results_tbw->setItemDelegate(new PlainTextItemDelegate(this, true));
 
-	action_load=new QAction(QIcon(PgModelerUiNS::getIconPath("abrir")), trUtf8("Load"), this);
-	action_save=new QAction(QIcon(PgModelerUiNS::getIconPath("salvar")), trUtf8("Save"), this);
-	action_save_as=new QAction(QIcon(PgModelerUiNS::getIconPath("salvar_como")), trUtf8("Save as"), this);
+	action_load=new QAction(QIcon(PgModelerUiNs::getIconPath("abrir")), trUtf8("Load"), this);
+	action_save=new QAction(QIcon(PgModelerUiNs::getIconPath("salvar")), trUtf8("Save"), this);
+	action_save_as=new QAction(QIcon(PgModelerUiNs::getIconPath("salvar_como")), trUtf8("Save as"), this);
 
 	file_menu.addAction(action_load);
 	file_menu.addAction(action_save);
 	file_menu.addAction(action_save_as);
 	file_tb->setMenu(&file_menu);
 
+	filter_wgt->setVisible(false);
+
+	connect(columns_cmb, SIGNAL(currentIndexChanged(int)), this, SLOT(filterResults()));
+	connect(filter_edt, SIGNAL(textChanged(QString)), this, SLOT(filterResults()));
+	connect(hide_tb, SIGNAL(clicked(bool)), filter_tb, SLOT(click()));
+
+	connect(filter_tb, &QToolButton::toggled, [&](bool checked){
+		filter_wgt->setVisible(checked);
+
+		if(checked)
+			filter_edt->setFocus();
+		else
+			sql_cmd_txt->setFocus();
+	});
+
+	connect(exact_chk, SIGNAL(toggled(bool)), this, SLOT(filterResults()));
+	connect(exact_chk, &QCheckBox::toggled, [&](bool checked){
+		regexp_chk->setChecked(false);
+		regexp_chk->setEnabled(!checked);
+		case_sensitive_chk->setChecked(false);
+		case_sensitive_chk->setEnabled(!checked);
+	});
+
+	connect(regexp_chk, SIGNAL(toggled(bool)), this, SLOT(filterResults()));
+	connect(case_sensitive_chk, SIGNAL(toggled(bool)), this, SLOT(filterResults()));
+
 	connect(action_load, SIGNAL(triggered(bool)), this, SLOT(loadCommands()));
 	connect(action_save, SIGNAL(triggered(bool)), this, SLOT(saveCommands()));
 	connect(action_save_as, SIGNAL(triggered(bool)), this, SLOT(saveCommands()));
@@ -128,16 +154,27 @@ SQLExecutionWidget::SQLExecutionWidget(QWidget * parent) : QWidget(parent)
 	toggleOutputPane(false);
 	filename_wgt->setVisible(false);
 	v_splitter->handle(1)->installEventFilter(this);
+
+	stop_tb->setVisible(false);
+	sql_exec_hlp.moveToThread(&sql_exec_thread);
+
+	connect(&sql_exec_thread, SIGNAL(started()), &sql_exec_hlp, SLOT(executeCommand()));
+	connect(&sql_exec_hlp, SIGNAL(s_executionFinished(int)), this, SLOT(finishExecution(int)));
+	connect(&sql_exec_hlp, SIGNAL(s_executionAborted(Exception)), &sql_exec_thread, SLOT(quit()));
+	connect(&sql_exec_hlp, SIGNAL(s_executionAborted(Exception)), this, SLOT(handleExecutionAborted(Exception)));
+	connect(stop_tb, SIGNAL(clicked(bool)), &sql_exec_hlp, SLOT(cancelCommand()), Qt::DirectConnection);
 }
 
 SQLExecutionWidget::~SQLExecutionWidget(void)
 {
-	if(result_model)
+	if(sql_exec_thread.isRunning())
 	{
-		results_tbw->blockSignals(true);
-		results_tbw->setModel(nullptr);
-		delete(result_model);
+		sql_exec_hlp.cancelCommand();
+		sql_exec_thread.quit();
+		sql_exec_thread.wait();
 	}
+
+	destroyResultModel();
 }
 
 bool SQLExecutionWidget::eventFilter(QObject *object, QEvent *event)
@@ -173,12 +210,20 @@ bool SQLExecutionWidget::eventFilter(QObject *object, QEvent *event)
 
 void SQLExecutionWidget::setConnection(Connection conn)
 {
-	sql_cmd_conn=conn;
+	sql_exec_hlp.setConnection(conn);
+	sql_cmd_conn = conn;
+
 	db_name_lbl->setText(QString("<strong>%1</strong>@<em>%2:%3</em>")
-						 .arg(conn.getConnectionParam(Connection::PARAM_DB_NAME))
-						 .arg(conn.getConnectionParam(Connection::PARAM_SERVER_IP).isEmpty() ?
-								  conn.getConnectionParam(Connection::PARAM_SERVER_FQDN) : conn.getConnectionParam(Connection::PARAM_SERVER_IP))
-						 .arg(conn.getConnectionParam(Connection::PARAM_PORT)));
+						 .arg(conn.getConnectionParam(Connection::ParamDbName))
+						 .arg(conn.getConnectionParam(Connection::ParamServerIp).isEmpty() ?
+								  conn.getConnectionParam(Connection::ParamServerFqdn) : conn.getConnectionParam(Connection::ParamServerIp))
+											 .arg(conn.getConnectionParam(Connection::ParamPort)));
+}
+
+void SQLExecutionWidget::setSQLCommand(const QString &sql)
+{
+	sql_cmd_txt->clear();
+	sql_cmd_txt->setPlainText(sql);
 }
 
 void SQLExecutionWidget::enableCommandButtons(void)
@@ -188,38 +233,6 @@ void SQLExecutionWidget::enableCommandButtons(void)
 	clear_btn->setEnabled(run_sql_tb->isEnabled());
 }
 
-void SQLExecutionWidget::fillResultsTable(ResultSet &res)
-{
-	try
-	{
-		Catalog catalog;
-		Connection aux_conn;
-
-		aux_conn.setConnectionParams(sql_cmd_conn.getConnectionParams());
-		export_tb->setEnabled(res.getTupleCount() > 0);
-		catalog.setConnection(aux_conn);
-
-		results_tbw->setSortingEnabled(false);
-		results_tbw->blockSignals(true);
-		results_tbw->setUpdatesEnabled(false);
-		results_tbw->setModel(nullptr);
-
-		if(result_model)
-			delete(result_model);
-
-		result_model = new ResultSetModel(res, catalog);
-
-		results_tbw->setModel(result_model);
-		results_tbw->resizeColumnsToContents();
-		results_tbw->setUpdatesEnabled(true);
-		results_tbw->blockSignals(false);
-	}
-	catch(Exception &e)
-	{
-		throw Exception(e.getErrorMessage(), e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
-	}
-}
-
 void SQLExecutionWidget::showEvent(QShowEvent *)
 {
 	sql_cmd_txt->setFocus();
@@ -242,13 +255,15 @@ void SQLExecutionWidget::resizeEvent(QResizeEvent *event)
 		snippets_tb->setToolButtonStyle(style);
 		export_tb->setToolButtonStyle(style);
 		output_tb->setToolButtonStyle(style);
+		stop_tb->setToolButtonStyle(style);
+		filter_tb->setToolButtonStyle(style);
 	}
 }
 
 void SQLExecutionWidget::fillResultsTable(Catalog &catalog, ResultSet &res, QTableWidget *results_tbw, bool store_data)
 {
 	if(!results_tbw)
-		throw Exception(ERR_OPR_NOT_ALOC_OBJECT ,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::OprNotAllocatedObject ,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	try
 	{
@@ -277,15 +292,15 @@ void SQLExecutionWidget::fillResultsTable(Catalog &catalog, ResultSet &res, QTab
 		}
 
 		//Retrieving the data type names for each column
-		catalog.setFilter(Catalog::LIST_ALL_OBJS);
+		catalog.setFilter(Catalog::ListAllObjects);
 		std::sort(type_ids.begin(), type_ids.end());
 		end=std::unique(type_ids.begin(), type_ids.end());
 		type_ids.erase(end, type_ids.end());
 
-		types=catalog.getObjectsAttributes(OBJ_TYPE, QString(), QString(), type_ids);
+		types=catalog.getObjectsAttributes(ObjectType::Type, QString(), QString(), type_ids);
 
 		for(auto &tp : types)
-			type_names[tp[ParsersAttributes::OID].toUInt()]=tp[ParsersAttributes::NAME];
+			type_names[tp[Attributes::Oid].toUInt()]=tp[Attributes::Name];
 
 		catalog.setFilter(orig_filter);
 
@@ -297,7 +312,7 @@ void SQLExecutionWidget::fillResultsTable(Catalog &catalog, ResultSet &res, QTab
 			item->setData(Qt::UserRole, type_names[res.getColumnTypeId(col)]);
 		}
 
-		if(res.accessTuple(ResultSet::FIRST_TUPLE))
+		if(res.accessTuple(ResultSet::FirstTuple))
 		{
 			results_tbw->setRowCount(res.getTupleCount());
 
@@ -321,7 +336,7 @@ void SQLExecutionWidget::fillResultsTable(Catalog &catalog, ResultSet &res, QTab
 						/* When storing column values in the QTableWidget items we need distinguish empty from null values
 						 * Since it may affect the generation of SQL like delete when the field value is used somehow (see DataManipulationForm::getDMLCommand) */
 						if(store_data)
-							item->setData(Qt::UserRole, res.isColumnValueNull(col) ? COLUMN_NULL_VALUE : item->text());
+							item->setData(Qt::UserRole, res.isColumnValueNull(col) ? ColumnNullValue : item->text());
 					}
 
 					results_tbw->setItem(row, col, item);
@@ -331,7 +346,7 @@ void SQLExecutionWidget::fillResultsTable(Catalog &catalog, ResultSet &res, QTab
 				results_tbw->setVerticalHeaderItem(row, new QTableWidgetItem(QString::number(row + 1)));
 				row++;
 			}
-			while(res.accessTuple(ResultSet::NEXT_TUPLE));
+			while(res.accessTuple(ResultSet::NextTuple));
 		}
 
 		results_tbw->setUpdatesEnabled(true);
@@ -341,36 +356,155 @@ void SQLExecutionWidget::fillResultsTable(Catalog &catalog, ResultSet &res, QTab
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(), e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
-void SQLExecutionWidget::showError(Exception &e)
+void SQLExecutionWidget::handleExecutionAborted(Exception e)
 {
 	QString time_str=QString("[%1]:").arg(QTime::currentTime().toString(QString("hh:mm:ss.zzz")));
 
+	switchToExecutionMode(false);
 	msgoutput_lst->clear();
 
-	PgModelerUiNS::createOutputListItem(msgoutput_lst,
-																			QString("%1 %2").arg(time_str).arg(e.getErrorMessage()),
-																			QPixmap(PgModelerUiNS::getIconPath("msgbox_erro")), false);
+	PgModelerUiNs::createOutputListItem(msgoutput_lst,
+										PgModelerUiNs::formatMessage(QString("%1 %2").arg(time_str).arg(e.getErrorMessage())),
+										QPixmap(PgModelerUiNs::getIconPath("msgbox_erro")));
 
-	if(e.getErrorType()==ERR_CONNECTION_TIMEOUT ||
-		 e.getErrorType()==ERR_CONNECTION_BROKEN)
+	if(e.getErrorCode()==ErrorCode::ConnectionTimeout ||
+		 e.getErrorCode()==ErrorCode::ConnectionBroken)
 	{
-		PgModelerUiNS::createOutputListItem(msgoutput_lst,
-																				QString("%1 %2").arg(time_str).arg(trUtf8("No results retrieved or changes done due to the error above.")),
-																				QPixmap(PgModelerUiNS::getIconPath("msgbox_alerta")), false);
+		PgModelerUiNs::createOutputListItem(msgoutput_lst,
+											QString("%1 %2").arg(time_str).arg(trUtf8("No results retrieved or changes done due to the error above! Run the command again.")),
+											QPixmap(PgModelerUiNs::getIconPath("msgbox_alerta")), false);
 	}
 
 	msgoutput_lst->setVisible(true);
 	results_parent->setVisible(false);
 	export_tb->setEnabled(false);
+	filter_tb->setEnabled(false);
+	filter_tb->setChecked(false);
 
 	output_tbw->setTabText(0, trUtf8("Results"));
 	output_tbw->setTabText(1, trUtf8("Messages (%1)").arg(msgoutput_lst->count()));
 	output_tbw->setCurrentIndex(1);
 	output_tbw->setTabEnabled(0, false);
+
+	addToSQLHistory(sql_cmd_txt->toPlainText(), 0, e.getErrorMessage());
+}
+
+void SQLExecutionWidget::finishExecution(int rows_affected)
+{
+	if(sql_exec_hlp.isCancelled())
+		destroyResultModel();
+	else
+	{
+		bool empty = false;
+		ResultSetModel *res_model = sql_exec_hlp.getResultSetModel();
+
+		end_exec=QDateTime::currentDateTime().toMSecsSinceEpoch();
+		total_exec = end_exec - start_exec;
+
+		results_tbw->setSortingEnabled(false);
+		results_tbw->blockSignals(true);
+		results_tbw->setUpdatesEnabled(false);
+
+		destroyResultModel();
+
+		results_tbw->setModel(res_model);
+		results_tbw->resizeColumnsToContents();
+		results_tbw->setUpdatesEnabled(true);
+		results_tbw->blockSignals(false);
+
+		filter_edt->blockSignals(true);
+		filter_edt->clear();
+		filter_edt->blockSignals(false);
+
+		columns_cmb->blockSignals(true);
+		columns_cmb->clear();
+
+		for(int col = 0; res_model && col < res_model->columnCount(QModelIndex()); col++)
+			columns_cmb->addItem(res_model->headerData(col, Qt::Horizontal, Qt::DisplayRole).toString());
+
+		columns_cmb->blockSignals(false);
+
+		addToSQLHistory(sql_cmd_txt->toPlainText(), rows_affected);
+
+		empty = (!res_model || res_model->rowCount() == 0);
+		output_tbw->setTabEnabled(0, !empty);
+		results_parent->setVisible(!empty);
+		export_tb->setEnabled(!empty);
+		filter_tb->setEnabled(!empty);
+
+		if(!empty)
+		{
+			output_tbw->setTabText(0, trUtf8("Results (%1)").arg(res_model->rowCount()));
+			output_tbw->setCurrentIndex(0);
+		}
+		else
+		{
+			output_tbw->setTabText(0, trUtf8("Results"));
+			output_tbw->setCurrentIndex(1);
+		}
+
+		msgoutput_lst->clear();
+
+		for(QString notice : sql_exec_hlp.getNotices())
+		{
+			PgModelerUiNs::createOutputListItem(msgoutput_lst,
+																					QString("[%1]: %2").arg(QTime::currentTime().toString(QString("hh:mm:ss.zzz"))).arg(notice.trimmed()),
+																					QPixmap(PgModelerUiNs::getIconPath("msgbox_alerta")), false);
+		}
+
+		PgModelerUiNs::createOutputListItem(msgoutput_lst,
+																				PgModelerUiNs::formatMessage(trUtf8("[%1]: SQL command successfully executed in <em><strong>%2</strong></em>. <em>%3 <strong>%4</strong></em>")
+																																		 .arg(QTime::currentTime().toString(QString("hh:mm:ss.zzz")))
+																																		 .arg(total_exec >= 1000 ? QString("%1 s").arg(total_exec/1000.0) : QString("%1 ms").arg(total_exec))
+																																		 .arg(!res_model ? trUtf8("Rows affected") :  trUtf8("Rows retrieved"))
+																																		 .arg(rows_affected)),
+																				QPixmap(PgModelerUiNs::getIconPath("msgbox_info")));
+
+		output_tbw->setTabText(1, trUtf8("Messages (%1)").arg(msgoutput_lst->count()));
+	}
+
+	switchToExecutionMode(false);
+	sql_exec_thread.quit();
+}
+
+void SQLExecutionWidget::filterResults(void)
+{
+	QModelIndexList list;
+	Qt::MatchFlags flags = Qt::MatchStartsWith;
+	int rows_cnt = results_tbw->model()->rowCount();
+
+	if(exact_chk->isChecked())
+		flags = Qt::MatchExactly;
+	else if(regexp_chk->isChecked())
+		flags = Qt::MatchRegExp;
+	else
+		flags = Qt::MatchContains;
+
+	if(case_sensitive_chk->isChecked())
+		flags |= Qt::MatchCaseSensitive;
+
+	list = results_tbw->model()->match(results_tbw->model()->index(0, columns_cmb->currentIndex()),
+																		 Qt::DisplayRole, filter_edt->text(), -1, flags);
+
+	results_tbw->blockSignals(true);
+	results_tbw->setUpdatesEnabled(false);
+
+	for(int row = 0; row < rows_cnt; row++)
+		results_tbw->hideRow(row);
+
+	if(!list.isEmpty())
+	{
+		for(auto &idx : list)
+			results_tbw->showRow(idx.row());
+	}
+
+	results_tbw->blockSignals(false);
+	results_tbw->setUpdatesEnabled(true);
+	results_tbw->update();
 }
 
 void SQLExecutionWidget::addToSQLHistory(const QString &cmd, unsigned rows, const QString &error)
@@ -382,20 +516,22 @@ void SQLExecutionWidget::addToSQLHistory(const QString &cmd, unsigned rows, cons
 		if(!cmd_history_txt->toPlainText().isEmpty())
 			fmt_cmd += QString("\n");
 
-		fmt_cmd += QString("-- Executed at [%1] -- \n").arg(QDateTime::currentDateTime().toString(QString("yyyy-MM-dd hh:mm:ss.zzz")));
+		fmt_cmd += QString("-- %1 [%2] -- \n")
+							 .arg(trUtf8("Executed at"))
+							 .arg(QDateTime::currentDateTime().toString(QString("yyyy-MM-dd hh:mm:ss.zzz")));
 		fmt_cmd += cmd;
 		fmt_cmd += QChar('\n');
 
 		if(!error.isEmpty())
 		{
-			fmt_cmd += QString("-- Query failed --\n");
+			fmt_cmd += QString("-- %1 --\n").arg(trUtf8("Command failed"));
 			fmt_cmd += QString("/*\n%1\n*/\n").arg(error);
 		}
 		else
-			fmt_cmd += QString("-- Rows retrieved: %1\n").arg(rows);
+			fmt_cmd += QString("-- %1 %2\n").arg(trUtf8("Rows:")).arg(rows);
 
-		if(!fmt_cmd.trimmed().endsWith(ParsersAttributes::DDL_END_TOKEN))
-			fmt_cmd += ParsersAttributes::DDL_END_TOKEN + QChar('\n');
+		if(!fmt_cmd.trimmed().endsWith(Attributes::DdlEndToken))
+			fmt_cmd += Attributes::DdlEndToken + QChar('\n');
 
 		SQLExecutionWidget::validateSQLHistoryLength(sql_cmd_conn.getConnectionId(true,true), fmt_cmd, cmd_history_txt);
 	}
@@ -414,7 +550,7 @@ void SQLExecutionWidget::validateSQLHistoryLength(const QString &conn_id, const
 	{
 		QStringList buffer = cmds.split(QChar('\n'));
 		cmds = buffer.mid(buffer.size()/2).join(QChar('\n'));
-		cmds = cmds.mid(cmds.indexOf(ParsersAttributes::DDL_END_TOKEN) + ParsersAttributes::DDL_END_TOKEN.length());
+		cmds = cmds.mid(cmds.indexOf(Attributes::DdlEndToken) + Attributes::DdlEndToken.length());
 		cmd_history[conn_id] = cmds.trimmed();
 
 		if(cmd_history_txt)
@@ -430,89 +566,71 @@ void SQLExecutionWidget::validateSQLHistoryLength(const QString &conn_id, const
 		cmd_history_txt->appendPlainText(fmt_cmd);
 }
 
+void SQLExecutionWidget::switchToExecutionMode(bool value)
+{
+	run_sql_tb->setVisible(!value);
+	stop_tb->setVisible(value);
+	file_tb->setEnabled(!value);
+	find_tb->setEnabled(!value);
+	clear_btn->setEnabled(!value);
+	snippets_tb->setEnabled(!value);
+	export_tb->setEnabled(!value);
+	output_tb->setEnabled(!value);
+	sql_cmd_txt->setEnabled(!value);
+	cmd_history_parent->setEnabled(!value);
+	find_history_parent->setEnabled(!value);
+	filter_tb->setEnabled(!value);
+
+	if(value)
+	{
+		this->setCursor(Qt::WaitCursor);
+		sql_cmd_txt->setCursor(Qt::WaitCursor);
+		sql_cmd_txt->clearFocus();
+	}
+	else
+	{
+		this->setCursor(Qt::ArrowCursor);
+		sql_cmd_txt->setCursor(Qt::ArrowCursor);
+		sql_cmd_txt->setFocus();
+	}
+}
+
+void SQLExecutionWidget::destroyResultModel(void)
+{
+	if(results_tbw->model())
+	{
+		ResultSetModel *result_model = dynamic_cast<ResultSetModel *>(results_tbw->model());
+		results_tbw->blockSignals(true);
+		results_tbw->setModel(nullptr);
+		delete(result_model);
+		results_tbw->blockSignals(false);
+	}
+}
+
 void SQLExecutionWidget::runSQLCommand(void)
 {
 	QString cmd=sql_cmd_txt->textCursor().selectedText();
 
-	try
-	{
-		ResultSet res;
-		QStringList conn_notices;
-		qint64 start_exec=0, end_exec=0, total_exec = 0;
+	output_tb->setChecked(true);
 
-		output_tb->setChecked(true);
+	if(cmd.isEmpty())
+		cmd=sql_cmd_txt->toPlainText();
+	else
+		cmd.replace(QChar::ParagraphSeparator, '\n');
 
-		if(cmd.isEmpty())
-			cmd=sql_cmd_txt->toPlainText();
-		else
-			cmd.replace(QChar::ParagraphSeparator, '\n');
+	msgoutput_lst->clear();
+	sql_exec_hlp.setCommand(cmd);
+	start_exec=QDateTime::currentDateTime().toMSecsSinceEpoch();
+	sql_exec_thread.start();
+	switchToExecutionMode(true);
 
-		msgoutput_lst->clear();
-
-		if(!sql_cmd_conn.isStablished())
-		{
-			sql_cmd_conn.setNoticeEnabled(true);
-			sql_cmd_conn.connect();
-
-			//The connection will break the execution if it keeps idle for one hour or more
-			sql_cmd_conn.setSQLExecutionTimout(3600);
-		}
-
-		QApplication::setOverrideCursor(Qt::WaitCursor);
-
-		start_exec=QDateTime::currentDateTime().toMSecsSinceEpoch();
-		sql_cmd_conn.executeDMLCommand(cmd, res);
-
-		conn_notices=sql_cmd_conn.getNotices();
-		addToSQLHistory(cmd, res.getTupleCount());
-
-		output_tbw->setTabEnabled(0, !res.isEmpty());
-		results_parent->setVisible(!res.isEmpty());
-		export_tb->setEnabled(!res.isEmpty());
-
-		if(!res.isEmpty())
-		{
-			fillResultsTable(res);
-			output_tbw->setTabText(0, trUtf8("Results (%1)").arg(results_tbw->model()->rowCount()));
-			output_tbw->setCurrentIndex(0);
-		}
-		else
-		{
-			output_tbw->setTabText(0, trUtf8("Results"));
-			output_tbw->setCurrentIndex(1);
-		}
-
-		msgoutput_lst->clear();
-
-		for(QString notice : conn_notices)
-		{
-			PgModelerUiNS::createOutputListItem(msgoutput_lst,
-																					PgModelerUiNS::formatMessage(QString("[%1]: %2").arg(QTime::currentTime().toString(QString("hh:mm:ss.zzz"))).arg(notice)),
-																					QPixmap(PgModelerUiNS::getIconPath("msgbox_alerta")));
-		}
-
-		end_exec=QDateTime::currentDateTime().toMSecsSinceEpoch();
-		total_exec = end_exec - start_exec;
-
-		PgModelerUiNS::createOutputListItem(msgoutput_lst,
-																				PgModelerUiNS::formatMessage(trUtf8("[%1]: SQL command successfully executed in <em><strong>%2</strong></em>. <em>%3 <strong>%4</strong></em>")
-																																		 .arg(QTime::currentTime().toString(QString("hh:mm:ss.zzz")))
-																																		 .arg(total_exec >= 1000 ? QString("%1 s").arg(total_exec/1000) : QString("%1 ms").arg(total_exec))
-																																		 .arg(res.isEmpty() ? trUtf8("Rows affected") :  trUtf8("Rows retrieved"))
-																																		 .arg(res.getTupleCount())),
-																				QPixmap(PgModelerUiNS::getIconPath("msgbox_info")));
-
-		output_tbw->setTabText(1, trUtf8("Messages (%1)").arg(msgoutput_lst->count()));
-
-		QApplication::restoreOverrideCursor();
-	}
-	catch(Exception &e)
-	{
-		addToSQLHistory(cmd, 0, e.getErrorMessage());
-		QApplication::restoreOverrideCursor();
-		sql_cmd_conn.close();
-		showError(e);
-	}
+	output_tbw->setTabEnabled(0, false);
+	output_tbw->setTabText(0, trUtf8("Results"));
+	output_tbw->setCurrentIndex(1);
+	PgModelerUiNs::createOutputListItem(msgoutput_lst,
+																			trUtf8("[%1]: SQL command is running...")
+																			.arg(QTime::currentTime().toString(QString("hh:mm:ss.zzz"))),
+																			QPixmap(PgModelerUiNs::getIconPath("msgbox_info")), false);
 }
 
 void SQLExecutionWidget::saveCommands(void)
@@ -538,8 +656,8 @@ void SQLExecutionWidget::saveCommands(void)
 		file.setFileName(filename);
 
 		if(!file.open(QFile::WriteOnly))
-			throw Exception(Exception::getErrorMessage(ERR_FILE_DIR_NOT_ACCESSED).arg(filename),
-											ERR_FILE_DIR_NOT_ACCESSED ,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+			throw Exception(Exception::getErrorMessage(ErrorCode::FileDirectoryNotAccessed).arg(filename),
+											ErrorCode::FileDirectoryNotAccessed ,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 		file.write(sql_cmd_txt->toPlainText().toUtf8());
 		file.close();
@@ -561,9 +679,9 @@ void SQLExecutionWidget::loadCommands(void)
 		file.setFileName(sql_file_dlg.selectedFiles().at(0));
 
 		if(!file.open(QFile::ReadOnly))
-			throw Exception(Exception::getErrorMessage(ERR_FILE_DIR_NOT_ACCESSED)
-							.arg(sql_file_dlg.selectedFiles().at(0))
-							,ERR_FILE_DIR_NOT_ACCESSED ,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+			throw Exception(Exception::getErrorMessage(ErrorCode::FileDirectoryNotAccessed)
+											.arg(sql_file_dlg.selectedFiles().at(0)),
+											ErrorCode::FileDirectoryNotAccessed ,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 		sql_cmd_txt->clear();
 		sql_cmd_txt->setPlainText(file.readAll());
@@ -577,7 +695,7 @@ void SQLExecutionWidget::loadCommands(void)
 void SQLExecutionWidget::exportResults(QTableView *results_tbw)
 {
 	if(!results_tbw)
-		throw Exception(ERR_OPR_NOT_ALOC_OBJECT ,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::OprNotAllocatedObject ,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	QFileDialog csv_file_dlg;
 
@@ -596,9 +714,9 @@ void SQLExecutionWidget::exportResults(QTableView *results_tbw)
 		file.setFileName(csv_file_dlg.selectedFiles().at(0));
 
 		if(!file.open(QFile::WriteOnly))
-			throw Exception(Exception::getErrorMessage(ERR_FILE_DIR_NOT_ACCESSED)
-							.arg(csv_file_dlg.selectedFiles().at(0))
-							, ERR_FILE_DIR_NOT_ACCESSED ,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+			throw Exception(Exception::getErrorMessage(ErrorCode::FileDirectoryNotAccessed)
+											.arg(csv_file_dlg.selectedFiles().at(0)),
+											ErrorCode::FileDirectoryNotAccessed ,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 		QApplication::setOverrideCursor(Qt::WaitCursor);
 		results_tbw->setUpdatesEnabled(false);
@@ -621,7 +739,7 @@ int SQLExecutionWidget::clearAll(void)
 	int res = 0;
 
 	msg_box.show(trUtf8("The SQL input field and the results grid will be cleared! Want to proceed?"),
-							 Messagebox::CONFIRM_ICON, Messagebox::YES_NO_BUTTONS);
+							 Messagebox::ConfirmIcon, Messagebox::YesNoButtons);
 
 	res = msg_box.result();
 
@@ -639,18 +757,18 @@ int SQLExecutionWidget::clearAll(void)
 
 QByteArray SQLExecutionWidget::generateCSVBuffer(QTableView *results_tbw)
 {
-	return(generateBuffer(results_tbw, QChar(';'), true, true));
+	return(generateBuffer(results_tbw, QChar(';'), true, true, true));
 }
 
 QByteArray SQLExecutionWidget::generateTextBuffer(QTableView *results_tbw)
 {
-	return(generateBuffer(results_tbw, QChar('\t'), false, false));
+	return(generateBuffer(results_tbw, QChar('\t'), false, false, false));
 }
 
-QByteArray SQLExecutionWidget::generateBuffer(QTableView *results_tbw, QChar separator, bool incl_col_names, bool use_quotes)
+QByteArray SQLExecutionWidget::generateBuffer(QTableView *results_tbw, QChar separator, bool incl_col_names, bool use_quotes, bool escape_chars)
 {
 	if(!results_tbw)
-		throw Exception(ERR_OPR_NOT_ALOC_OBJECT ,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::OprNotAllocatedObject ,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	if(!results_tbw->selectionModel())
 		return (QByteArray());
@@ -660,7 +778,7 @@ QByteArray SQLExecutionWidget::generateBuffer(QTableView *results_tbw, QChar sep
 	QByteArray buf;
 	QStringList line;
 	QModelIndex index;
-	QString str_pattern = use_quotes ? QString("\"%1\"") : QString("%1");
+	QString str_pattern = use_quotes ? QString("\"%1\"") : QString("%1"), value;
 	int start_row = -1, start_col = -1,
 			row_cnt = 0, col_cnt = 0;
 
@@ -677,7 +795,24 @@ QByteArray SQLExecutionWidget::generateBuffer(QTableView *results_tbw, QChar sep
 	{
 		//Creating the header
 		for(col=start_col; col < max_col; col++)
-			line.append(str_pattern.arg(model->headerData(col, Qt::Horizontal).toString()));
+		{
+			if(results_tbw->isColumnHidden(col))
+				continue;
+
+			value = model->headerData(col, Qt::Horizontal).toString();
+
+			if(escape_chars)
+			{
+				value.replace(separator, QString("\\%1").arg(separator));
+				value.replace(QChar::Tabulation, QString("\\t"));
+				value.replace(QChar::LineFeed, QString("\\n"));
+
+				if(use_quotes)
+					value.replace('"', QString("\\%1").arg('"'));
+			}
+
+			line.append(str_pattern.arg(value));
+		}
 
 		buf.append(line.join(separator));
 		buf.append('\n');
@@ -689,8 +824,23 @@ QByteArray SQLExecutionWidget::generateBuffer(QTableView *results_tbw, QChar sep
 	{
 		for(col=start_col; col < max_col; col++)
 		{
+			if(results_tbw->isColumnHidden(col))
+				continue;
+
 			index = model->index(row, col);
-			line.append(str_pattern.arg(index.data().toString()));
+			value = index.data().toString();
+
+			if(escape_chars)
+			{
+				value.replace(separator, QString("\\%1").arg(separator));
+				value.replace(QChar::Tabulation, QString("\\t"));
+				value.replace(QChar::LineFeed, QString("\\n"));
+
+				if(use_quotes)
+					value.replace('"', QString("\\%1").arg('"'));
+			}
+
+			line.append(str_pattern.arg(value));
 		}
 
 		buf.append(line.join(separator));
@@ -704,13 +854,12 @@ QByteArray SQLExecutionWidget::generateBuffer(QTableView *results_tbw, QChar sep
 void SQLExecutionWidget::copySelection(QTableView *results_tbw, bool use_popup, bool csv_is_default)
 {
 	if(!results_tbw)
-		throw Exception(ERR_OPR_NOT_ALOC_OBJECT ,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::OprNotAllocatedObject ,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	QItemSelectionModel *selection = results_tbw->selectionModel();
 
 	if(selection && (!use_popup || (use_popup && QApplication::mouseButtons()==Qt::RightButton)))
 	{
-		QModelIndexList sel_indexes = selection->selectedIndexes();
 		QMenu copy_menu, copy_mode_menu;
 		QAction *act = nullptr, *act_csv = nullptr, *act_txt = nullptr;
 
@@ -725,17 +874,12 @@ void SQLExecutionWidget::copySelection(QTableView *results_tbw, bool use_popup,
 
 		if(!use_popup || act)
 		{
-			//QTableWidgetSelectionRange selection=sel_ranges.at(0);
 			QByteArray buf;
 
 			if((use_popup && act == act_csv) || (!use_popup && csv_is_default))
 			{
 				//Generates the csv buffer and assigns it to application's clipboard
 				buf=generateCSVBuffer(results_tbw);
-
-				/* Making DataManipulationForm instances know that the clipboard has csv buffer
-				 * in order to paste the contents properly */
-				DataManipulationForm::setHasCsvClipboard(true);
 			}
 			else if((use_popup && act == act_txt) || (!use_popup && !csv_is_default))
 			{
@@ -796,44 +940,44 @@ void SQLExecutionWidget::saveSQLHistory(void)
 
 		for(auto hist : cmd_history)
 		{
-			attribs[ParsersAttributes::CONNECTION] = hist.first;
-			attribs[ParsersAttributes::COMMANDS] = hist.second;
+			attribs[Attributes::Connection] = hist.first;
+			attribs[Attributes::Commands] = hist.second;
 			schparser.ignoreEmptyAttributes(true);
-			commands += schparser.getCodeDefinition(GlobalAttributes::TMPL_CONFIGURATIONS_DIR +
-																							GlobalAttributes::DIR_SEPARATOR +
-																							GlobalAttributes::SCHEMAS_DIR +
-																							GlobalAttributes::DIR_SEPARATOR +
-																							ParsersAttributes::COMMANDS +
-																							GlobalAttributes::SCHEMA_EXT, attribs);
+			commands += schparser.getCodeDefinition(GlobalAttributes::TmplConfigurationDir +
+																							GlobalAttributes::DirSeparator +
+																							GlobalAttributes::SchemasDir +
+																							GlobalAttributes::DirSeparator +
+																							Attributes::Commands +
+																							GlobalAttributes::SchemaExt, attribs);
 		}
 
-		schparser.loadFile(GlobalAttributes::TMPL_CONFIGURATIONS_DIR +
-											 GlobalAttributes::DIR_SEPARATOR +
-											 GlobalAttributes::SCHEMAS_DIR +
-											 GlobalAttributes::DIR_SEPARATOR +
-											 GlobalAttributes::SQL_HISTORY_CONF +
-											 GlobalAttributes::SCHEMA_EXT);
+		schparser.loadFile(GlobalAttributes::TmplConfigurationDir +
+											 GlobalAttributes::DirSeparator +
+											 GlobalAttributes::SchemasDir +
+											 GlobalAttributes::DirSeparator +
+											 GlobalAttributes::SQLHistoryConf +
+											 GlobalAttributes::SchemaExt);
 
 		attribs.clear();
-		attribs[ParsersAttributes::COMMANDS] = commands;
+		attribs[Attributes::Commands] = commands;
 		buffer.append(schparser.getCodeDefinition(attribs));
 
 
-		file.setFileName(GlobalAttributes::CONFIGURATIONS_DIR +
-										 GlobalAttributes::DIR_SEPARATOR +
-										 GlobalAttributes::SQL_HISTORY_CONF +
-										 GlobalAttributes::CONFIGURATION_EXT);
+		file.setFileName(GlobalAttributes::ConfigurationsDir +
+										 GlobalAttributes::DirSeparator +
+										 GlobalAttributes::SQLHistoryConf +
+										 GlobalAttributes::ConfigurationExt);
 
 		if(!file.open(QFile::WriteOnly))
-			throw Exception(Exception::getErrorMessage(ERR_FILE_DIR_NOT_ACCESSED).arg(file.fileName()),
-											ERR_FILE_DIR_NOT_ACCESSED, __PRETTY_FUNCTION__, __FILE__ ,__LINE__);
+			throw Exception(Exception::getErrorMessage(ErrorCode::FileDirectoryNotAccessed).arg(file.fileName()),
+											ErrorCode::FileDirectoryNotAccessed, __PRETTY_FUNCTION__, __FILE__ ,__LINE__);
 
 		file.write(buffer);
 		file.close();
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(), e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
@@ -841,45 +985,45 @@ void SQLExecutionWidget::loadSQLHistory(void)
 {
 	try
 	{
-		XMLParser xmlparser;
+		XmlParser xmlparser;
 		attribs_map attribs;
 
-		xmlparser.setDTDFile(GlobalAttributes::TMPL_CONFIGURATIONS_DIR +
-												 GlobalAttributes::DIR_SEPARATOR +
-												 GlobalAttributes::OBJECT_DTD_DIR +
-												 GlobalAttributes::DIR_SEPARATOR +
-												 GlobalAttributes::SQL_HISTORY_CONF +
-												 GlobalAttributes::OBJECT_DTD_EXT,
-												 GlobalAttributes::SQL_HISTORY_CONF);
+		xmlparser.setDTDFile(GlobalAttributes::TmplConfigurationDir +
+												 GlobalAttributes::DirSeparator +
+												 GlobalAttributes::ObjectDTDDir +
+												 GlobalAttributes::DirSeparator +
+												 GlobalAttributes::SQLHistoryConf +
+												 GlobalAttributes::ObjectDTDExt,
+												 GlobalAttributes::SQLHistoryConf);
 
-		xmlparser.loadXMLFile(GlobalAttributes::CONFIGURATIONS_DIR +
-													GlobalAttributes::DIR_SEPARATOR +
-													GlobalAttributes::SQL_HISTORY_CONF +
-													GlobalAttributes::CONFIGURATION_EXT);
+		xmlparser.loadXMLFile(GlobalAttributes::ConfigurationsDir +
+													GlobalAttributes::DirSeparator +
+													GlobalAttributes::SQLHistoryConf +
+													GlobalAttributes::ConfigurationExt);
 
 		cmd_history.clear();
 
-		if(xmlparser.accessElement(XMLParser::CHILD_ELEMENT))
+		if(xmlparser.accessElement(XmlParser::ChildElement))
 		{
 			do
 			{
-				if(xmlparser.getElementName() == ParsersAttributes::COMMANDS)
+				if(xmlparser.getElementName() == Attributes::Commands)
 				{
 					xmlparser.getElementAttributes(attribs);
 					xmlparser.savePosition();
 
-					if(xmlparser.accessElement(XMLParser::CHILD_ELEMENT))
-						cmd_history[attribs[ParsersAttributes::CONNECTION]].append(xmlparser.getElementContent());
+					if(xmlparser.accessElement(XmlParser::ChildElement))
+						cmd_history[attribs[Attributes::Connection]].append(xmlparser.getElementContent());
 
 					xmlparser.restorePosition();
 				}
 			}
-			while(xmlparser.accessElement(XMLParser::NEXT_ELEMENT));
+			while(xmlparser.accessElement(XmlParser::NextElement));
 		}
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(), e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
@@ -888,14 +1032,14 @@ void SQLExecutionWidget::destroySQLHistory(void)
 	Messagebox msg_box;
 
 	msg_box.show(trUtf8("This action will wipe out all the SQL commands history for all connections! Do you really want to proceed?"),
-								Messagebox::CONFIRM_ICON, Messagebox::YES_NO_BUTTONS);
+								Messagebox::ConfirmIcon, Messagebox::YesNoButtons);
 
 	if(msg_box.result() == QDialog::Accepted)
 	{
-		QFile::remove(GlobalAttributes::CONFIGURATIONS_DIR +
-									GlobalAttributes::DIR_SEPARATOR +
-									GlobalAttributes::SQL_HISTORY_CONF +
-									GlobalAttributes::CONFIGURATION_EXT);
+		QFile::remove(GlobalAttributes::ConfigurationsDir +
+									GlobalAttributes::DirSeparator +
+									GlobalAttributes::SQLHistoryConf +
+									GlobalAttributes::ConfigurationExt);
 
 		SQLExecutionWidget::cmd_history.clear();
 	}
@@ -903,7 +1047,7 @@ void SQLExecutionWidget::destroySQLHistory(void)
 
 void SQLExecutionWidget::setSQLHistoryMaxLength(int len)
 {
-	if(len < 100 || len > 2000)
+	if(len < 1000 || len > 20000)
 		len = 1000;
 
 	SQLExecutionWidget::cmd_history_max_len = len;
@@ -927,21 +1071,21 @@ void SQLExecutionWidget::enableSQLExecution(bool enable)
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(), e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
 void SQLExecutionWidget::showHistoryContextMenu(void)
 {
 	QMenu *ctx_menu=cmd_history_txt->createStandardContextMenu();
-	QAction *action_clear = new QAction(QPixmap(PgModelerUiNS::getIconPath("limpartexto")), trUtf8("Clear history"), ctx_menu),
-			*action_save = new QAction(QPixmap(PgModelerUiNS::getIconPath("salvar")), trUtf8("Save history"), ctx_menu),
-			*action_reload = new QAction(QPixmap(PgModelerUiNS::getIconPath("atualizar")), trUtf8("Reload history"), ctx_menu),
+	QAction *action_clear = new QAction(QPixmap(PgModelerUiNs::getIconPath("limpartexto")), trUtf8("Clear history"), ctx_menu),
+			*action_save = new QAction(QPixmap(PgModelerUiNs::getIconPath("salvar")), trUtf8("Save history"), ctx_menu),
+			*action_reload = new QAction(QPixmap(PgModelerUiNs::getIconPath("atualizar")), trUtf8("Reload history"), ctx_menu),
 			*action_toggle_find = nullptr,
 			*exec_act = nullptr;
 
 	if(!find_history_parent->isVisible())
-		action_toggle_find = new QAction(QPixmap(PgModelerUiNS::getIconPath("buscar")), trUtf8("Find in history"), ctx_menu);
+		action_toggle_find = new QAction(QPixmap(PgModelerUiNs::getIconPath("buscar")), trUtf8("Find in history"), ctx_menu);
 	else
 		action_toggle_find = new QAction(trUtf8("Hide find tool"), ctx_menu);
 
@@ -959,7 +1103,7 @@ void SQLExecutionWidget::showHistoryContextMenu(void)
 		Messagebox msg_box;
 
 		msg_box.show(trUtf8("This action will wipe out all the SQL commands history for the current connection! Do you really want to proceed?"),
-									Messagebox::CONFIRM_ICON, Messagebox::YES_NO_BUTTONS);
+									Messagebox::ConfirmIcon, Messagebox::YesNoButtons);
 
 		if(msg_box.result() == QDialog::Accepted)
 		{
