@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,14 +29,19 @@
 #include "ui_tablewidget.h"
 #include "objectstablewidget.h"
 #include "tableview.h"
+#include "elementstablewidget.h"
 
 class TableWidget: public BaseObjectWidget, public Ui::TableWidget {
 	private:
 		Q_OBJECT
 
-		ObjectsTableWidget *parent_tables;
+		ObjectsTableWidget *parent_tables, *options_tab;
 
-		ObjectSelectorWidget *tag_sel;
+		ElementsTableWidget *partition_keys_tab;
+
+		ObjectSelectorWidget *tag_sel, *server_sel;
+
+		QFrame *warn_frame;
 
 		//! \brief Stores the objects tables used to handle columns, constraints, indexes, rules and triggers
 		map<ObjectType, ObjectsTableWidget *> objects_tab_map;
@@ -58,10 +63,13 @@ class TableWidget: public BaseObjectWidget, public Ui::TableWidget {
 		template<class Class, class ClassWidget>
 		int openEditingForm(TableObject *object);
 
+		void __setAttributes(DatabaseModel *model, OperationList *op_list, Schema *schema, PhysicalTable *table, double pos_x, double pos_y);
+
 	public:
-		TableWidget(QWidget * parent = 0);
+		TableWidget(QWidget * parent = nullptr, ObjectType tab_type = ObjectType::Table);
 
 		void setAttributes(DatabaseModel *model, OperationList *op_list, Schema *schema, Table *table, double pos_x, double pos_y);
+		void setAttributes(DatabaseModel *model, OperationList *op_list, Schema *schema, ForeignTable *ftable, double pos_x, double pos_y);
 
 	private slots:
 		//! \brief Adds or edit a object on the object table that calls the slot
