@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,9 +33,9 @@ class TextboxWidget: public BaseObjectWidget, public Ui::TextboxWidget {
 		Q_OBJECT
 
 	public:
-		TextboxWidget(QWidget * parent = 0);
+		TextboxWidget(QWidget * parent = nullptr);
 
-		void setAttributes(DatabaseModel *model, OperationList *op_list, Textbox *txtbox=nullptr, double obj_px=NAN, double obj_py=NAN);
+		void setAttributes(DatabaseModel *model, OperationList *op_list, Textbox *txtbox=nullptr, double obj_px=DNaN, double obj_py=DNaN);
 
 	private slots:
 		void selectTextColor(void);
