@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
 #include "triggerwidget.h"
 
-TriggerWidget::TriggerWidget(QWidget *parent): BaseObjectWidget(parent, OBJ_TRIGGER)
+TriggerWidget::TriggerWidget(QWidget *parent): BaseObjectWidget(parent, ObjectType::Trigger)
 {
 	try
 	{
@@ -27,30 +27,30 @@ TriggerWidget::TriggerWidget(QWidget *parent): BaseObjectWidget(parent, OBJ_TRIG
 		Ui_TriggerWidget::setupUi(this);
 
 		cond_expr_hl=new SyntaxHighlighter(cond_expr_txt, false, true);
-		cond_expr_hl->loadConfiguration(GlobalAttributes::SQL_HIGHLIGHT_CONF_PATH);
+		cond_expr_hl->loadConfiguration(GlobalAttributes::SQLHighlightConfPath);
 
-		columns_tab=new ObjectsTableWidget(ObjectsTableWidget::ALL_BUTTONS ^
-										  (ObjectsTableWidget::EDIT_BUTTON |
-											 ObjectsTableWidget::UPDATE_BUTTON |
-											 ObjectsTableWidget::DUPLICATE_BUTTON), true, this);
+		columns_tab=new ObjectsTableWidget(ObjectsTableWidget::AllButtons ^
+										  (ObjectsTableWidget::EditButton |
+											 ObjectsTableWidget::UpdateButton |
+											 ObjectsTableWidget::DuplicateButton), true, this);
 
-		arguments_tab=new ObjectsTableWidget(ObjectsTableWidget::ALL_BUTTONS ^ ObjectsTableWidget::DUPLICATE_BUTTON, true, this);
+		arguments_tab=new ObjectsTableWidget(ObjectsTableWidget::AllButtons ^ ObjectsTableWidget::DuplicateButton, true, this);
 
-		ref_table_sel=new ObjectSelectorWidget(OBJ_TABLE, true, this);
-		function_sel=new ObjectSelectorWidget(OBJ_FUNCTION, true, this);
+		ref_table_sel=new ObjectSelectorWidget(ObjectType::Table, true, this);
+		function_sel=new ObjectSelectorWidget(ObjectType::Function, true, this);
 		ref_table_sel->setEnabled(false);
 
-		trigger_grid->addWidget(function_sel, 2, 2, 1, 1);
-		trigger_grid->addWidget(ref_table_sel, 6, 2, 1, 1);
+		trigger_grid->addWidget(function_sel, 3, 1, 1, 5);
 
 		columns_tab->setColumnCount(2);
 		columns_tab->setHeaderLabel(trUtf8("Column"), 0);
-		columns_tab->setHeaderIcon(QPixmap(PgModelerUiNS::getIconPath("column")),0);
+		columns_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("column")),0);
 		columns_tab->setHeaderLabel(trUtf8("Type"), 1);
-		columns_tab->setHeaderIcon(QPixmap(PgModelerUiNS::getIconPath("usertype")),1);
+		columns_tab->setHeaderIcon(QPixmap(PgModelerUiNs::getIconPath("usertype")),1);
 
 		dynamic_cast<QGridLayout *>(arg_cols_tbw->widget(1)->layout())->addWidget(columns_tab, 1,0,1,3);
 		dynamic_cast<QGridLayout *>(arg_cols_tbw->widget(0)->layout())->addWidget(arguments_tab, 1,0,1,3);
+		dynamic_cast<QGridLayout *>(arg_cols_tbw->widget(2)->layout())->addWidget(ref_table_sel, 1, 1, 1, 1);
 
 		DeferralType::getTypes(list);
 		deferral_type_cmb->addItems(list);
@@ -58,7 +58,7 @@ TriggerWidget::TriggerWidget(QWidget *parent): BaseObjectWidget(parent, OBJ_TRIG
 		FiringType::getTypes(list);
 		firing_mode_cmb->addItems(list);
 
-		configureFormLayout(trigger_grid, OBJ_TRIGGER);
+		configureFormLayout(trigger_grid, ObjectType::Trigger);
 
 		connect(deferrable_chk, SIGNAL(toggled(bool)), deferral_type_cmb, SLOT(setEnabled(bool)));
 		connect(columns_tab, SIGNAL(s_rowAdded(int)), this, SLOT(addColumn(int)));
@@ -67,19 +67,25 @@ TriggerWidget::TriggerWidget(QWidget *parent): BaseObjectWidget(parent, OBJ_TRIG
 		connect(arguments_tab, SIGNAL(s_rowAdded(int)), this, SLOT(handleArgument(int)));
 		connect(arguments_tab, SIGNAL(s_rowUpdated(int)), this, SLOT(handleArgument(int)));
 		connect(arguments_tab, SIGNAL(s_rowEdited(int)), this, SLOT(editArgument(int)));
-		connect(constr_trig_chk, SIGNAL(toggled(bool)), this, SLOT(setConstraintTrigger(bool)));
+		connect(constraint_rb, SIGNAL(toggled(bool)), this, SLOT(setConstraintTrigger(bool)));
 		connect(update_chk, SIGNAL(toggled(bool)), this, SLOT(selectUpdateEvent(void)));
 
+		connect(insert_chk, SIGNAL(toggled(bool)), this, SLOT(enableTransitionTableNames()));
+		connect(delete_chk, SIGNAL(toggled(bool)), this, SLOT(enableTransitionTableNames()));
+		connect(update_chk, SIGNAL(toggled(bool)), this, SLOT(enableTransitionTableNames()));
+		connect(truncate_chk, SIGNAL(toggled(bool)), this, SLOT(enableTransitionTableNames()));
+		connect(firing_mode_cmb, SIGNAL(currentIndexChanged(int)), this, SLOT(enableTransitionTableNames()));
+
 		setRequiredField(event_lbl);
 		setRequiredField(firing_mode_lbl);
 		setRequiredField(function_lbl);
 		setRequiredField(function_sel);
 
-		setMinimumSize(580, 580);
+		setMinimumSize(580, 500);
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
@@ -91,7 +97,7 @@ void TriggerWidget::selectUpdateEvent(void)
 	/* Disable the columns tab when the trigger belongs to a view.
 	pgModeler does not support triggers reference view columns (yet) */
 	arg_cols_tbw->widget(1)->setEnabled(update_chk->isChecked() &&
-										table->getObjectType()==OBJ_TABLE);
+										table->getObjectType()==ObjectType::Table);
 }
 
 void TriggerWidget::setConstraintTrigger(bool value)
@@ -109,7 +115,27 @@ void TriggerWidget::setConstraintTrigger(bool value)
 		deferrable_chk->setChecked(false);
 	}
 	else
-		firing_mode_cmb->setCurrentText(~FiringType(FiringType::after));
+		firing_mode_cmb->setCurrentText(~FiringType(FiringType::After));
+}
+
+void TriggerWidget::enableTransitionTableNames(void)
+{
+	int num_evnts = 0;
+	QWidget *wgt = nullptr;
+	QCheckBox *chk = nullptr;
+	FiringType firing_type = firing_mode_cmb->currentText();
+
+	for(auto &obj : events_wgt->children())
+	{
+		wgt = qobject_cast<QWidget *>(obj);
+		chk = dynamic_cast<QCheckBox *>(wgt);
+
+		if(chk && chk->isChecked())
+			num_evnts++;
+	}
+
+	old_table_edt->setEnabled(firing_type == FiringType::After && num_evnts == 1 && (update_chk->isChecked() || delete_chk->isChecked()));
+	new_table_edt->setEnabled(firing_type == FiringType::After && num_evnts == 1 && (update_chk->isChecked() || insert_chk->isChecked()));
 }
 
 void TriggerWidget::addColumn(int lin_idx)
@@ -121,12 +147,12 @@ void TriggerWidget::addColumn(int lin_idx)
 		column=reinterpret_cast<Column *>(column_cmb->itemData(column_cmb->currentIndex(),Qt::UserRole).value<void *>());
 		column_cmb->removeItem(column_cmb->currentIndex());
 		addColumn(column, lin_idx);
-		columns_tab->setButtonsEnabled(ObjectsTableWidget::ADD_BUTTON, (column_cmb->count()!=0));
+		columns_tab->setButtonsEnabled(ObjectsTableWidget::AddButton, (column_cmb->count()!=0));
 	}
 	catch(Exception &e)
 	{
 		columns_tab->removeRow(lin_idx);
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
@@ -147,14 +173,14 @@ void TriggerWidget::updateColumnsCombo(void)
 
 	try
 	{
-		if(this->table->getObjectType()==OBJ_TABLE)
+		if(this->table->getObjectType()==ObjectType::Table)
 		{
-			col_count=table->getObjectCount(OBJ_COLUMN);
+			col_count=table->getObjectCount(ObjectType::Column);
 			column_cmb->clear();
 
 			for(i=0; i < col_count; i++)
 			{
-				column=dynamic_cast<Column *>(table->getObject(i, OBJ_COLUMN));
+				column=dynamic_cast<Column *>(table->getObject(i, ObjectType::Column));
 
 				if(columns_tab->getRowIndex(QVariant::fromValue<void *>(column)) < 0)
 				{
@@ -164,12 +190,12 @@ void TriggerWidget::updateColumnsCombo(void)
 				}
 			}
 
-			columns_tab->setButtonsEnabled(ObjectsTableWidget::ADD_BUTTON, (column_cmb->count()!=0));
+			columns_tab->setButtonsEnabled(ObjectsTableWidget::AddButton, (column_cmb->count()!=0));
 		}
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
@@ -195,7 +221,7 @@ void TriggerWidget::setAttributes(DatabaseModel *model, OperationList *op_list,
 	Column *column=nullptr;
 
 	if(!parent_table)
-		throw Exception(ERR_ASG_NOT_ALOC_OBJECT,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+		throw Exception(ErrorCode::AsgNotAllocattedObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	BaseObjectWidget::setAttributes(model, op_list, trigger, parent_table);
 	ref_table_sel->setModel(model);
@@ -203,7 +229,7 @@ void TriggerWidget::setAttributes(DatabaseModel *model, OperationList *op_list,
 
 	if(trigger)
 	{
-		constr_trig_chk->setChecked(trigger->isConstraint());
+		constraint_rb->setChecked(trigger->isConstraint());
 
 		exec_per_row_chk->setChecked(trigger->isExecutePerRow());
 		cond_expr_txt->setPlainText(trigger->getCondition());
@@ -211,10 +237,10 @@ void TriggerWidget::setAttributes(DatabaseModel *model, OperationList *op_list,
 		deferral_type_cmb->setCurrentIndex(deferral_type_cmb->findText(~trigger->getDeferralType()));
 		firing_mode_cmb->setCurrentIndex(firing_mode_cmb->findText(~trigger->getFiringType()));
 
-		insert_chk->setChecked(trigger->isExecuteOnEvent(EventType::on_insert));
-		delete_chk->setChecked(trigger->isExecuteOnEvent(EventType::on_delete));
-		update_chk->setChecked(trigger->isExecuteOnEvent(EventType::on_update));
-		truncate_chk->setChecked(trigger->isExecuteOnEvent(EventType::on_truncate));
+		insert_chk->setChecked(trigger->isExecuteOnEvent(EventType::OnInsert));
+		delete_chk->setChecked(trigger->isExecuteOnEvent(EventType::OnDelete));
+		update_chk->setChecked(trigger->isExecuteOnEvent(EventType::OnUpdate));
+		truncate_chk->setChecked(trigger->isExecuteOnEvent(EventType::OnTruncate));
 		ref_table_sel->setSelectedObject(trigger->getReferencedTable());
 		function_sel->setSelectedObject(trigger->getFunction());
 
@@ -236,9 +262,12 @@ void TriggerWidget::setAttributes(DatabaseModel *model, OperationList *op_list,
 			arguments_tab->setCellText(trigger->getArgument(i), i, 0);
 		}
 
-		columns_tab->setButtonsEnabled(ObjectsTableWidget::ADD_BUTTON, (column_cmb->count()!=0));
+		columns_tab->setButtonsEnabled(ObjectsTableWidget::AddButton, (column_cmb->count()!=0));
 		arguments_tab->blockSignals(false);
 		columns_tab->blockSignals(false);
+
+		old_table_edt->setText(trigger->getTransitionTableName(Trigger::OldTableName));
+		new_table_edt->setText(trigger->getTransitionTableName(Trigger::NewTableName));
 	}
 
 	updateColumnsCombo();
@@ -255,7 +284,7 @@ void TriggerWidget::applyConfiguration(void)
 		startConfiguration<Trigger>();
 
 		trigger=dynamic_cast<Trigger *>(this->object);
-		trigger->setConstraint(constr_trig_chk->isChecked());
+		trigger->setConstraint(constraint_rb->isChecked());
 		trigger->setFiringType(FiringType(firing_mode_cmb->currentText()));
 		trigger->setExecutePerRow(exec_per_row_chk->isChecked());
 		trigger->setDeferrable(deferrable_chk->isChecked());
@@ -263,10 +292,12 @@ void TriggerWidget::applyConfiguration(void)
 		trigger->setCondition(cond_expr_txt->toPlainText());
 		trigger->setFunction(dynamic_cast<Function *>(function_sel->getSelectedObject()));
 		trigger->setReferecendTable(dynamic_cast<Table *>(ref_table_sel->getSelectedObject()));
-		trigger->setEvent(EventType::on_insert, insert_chk->isChecked());
-		trigger->setEvent(EventType::on_update, update_chk->isChecked());
-		trigger->setEvent(EventType::on_delete, delete_chk->isChecked());
-		trigger->setEvent(EventType::on_truncate, truncate_chk->isChecked());
+		trigger->setEvent(EventType::OnInsert, insert_chk->isChecked());
+		trigger->setEvent(EventType::OnUpdate, update_chk->isChecked());
+		trigger->setEvent(EventType::OnDelete, delete_chk->isChecked());
+		trigger->setEvent(EventType::OnTruncate, truncate_chk->isChecked());
+		trigger->setTransitionTableName(Trigger::OldTableName, old_table_edt->isEnabled() ? old_table_edt->text() : QString());
+		trigger->setTransitionTableName(Trigger::NewTableName, new_table_edt->isEnabled() ? new_table_edt->text() : QString());
 		trigger->removeArguments();
 		trigger->removeColumns();
 
@@ -290,7 +321,7 @@ void TriggerWidget::applyConfiguration(void)
 	catch(Exception &e)
 	{
 		cancelConfiguration();
-		throw Exception(e.getErrorMessage(),e.getErrorType(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
 
