@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ class TriggerWidget: public BaseObjectWidget, public Ui::TriggerWidget {
 		void addColumn(Column *column, int row);
 
 	public:
-		TriggerWidget(QWidget * parent = 0);
+		TriggerWidget(QWidget * parent  = nullptr);
 
 		void setAttributes(DatabaseModel *model, OperationList *op_list, BaseTable *parent_table, Trigger *trigger);
 
@@ -59,6 +59,7 @@ class TriggerWidget: public BaseObjectWidget, public Ui::TriggerWidget {
 		void editArgument(int lin_idx);
 		void updateColumnsCombo(void);
 		void setConstraintTrigger(bool value);
+		void enableTransitionTableNames(void);
 
 	public slots:
 		void applyConfiguration(void);
