@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@
 #include "ui_updatenotifierwidget.h"
 #include "messagebox.h"
 #include "globalattributes.h"
-#include "parsersattributes.h"
+#include "attributes.h"
 
 class UpdateNotifierWidget: public QWidget, public Ui::UpdateNotifierWidget {
 	private:
@@ -75,7 +75,7 @@ class UpdateNotifierWidget: public QWidget, public Ui::UpdateNotifierWidget {
 		void activateLink(const QString &link);
 
 	public:
-		UpdateNotifierWidget(QWidget * parent = 0);
+		UpdateNotifierWidget(QWidget * parent = nullptr);
 
 	public slots:
 		void checkForUpdate(void);
