@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ class WelcomeWidget: public QWidget, public Ui::WelcomeWidget {
 		Q_OBJECT
 		
 	public:
-		WelcomeWidget(QWidget * parent = 0);
+		WelcomeWidget(QWidget * parent = nullptr);
 		
 	public slots:
 };
