@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2018 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@ class SchemaParserTest: public QObject {
 
   private slots:
 		void testExpressionEvaluationWithCasts(void);
+		void testSetOperationInIf(void);
 };
 
 void SchemaParserTest::testExpressionEvaluationWithCasts(void)
@@ -51,5 +52,32 @@ void SchemaParserTest::testExpressionEvaluationWithCasts(void)
 	}
 }
 
+void SchemaParserTest::testSetOperationInIf(void)
+{
+	SchemaParser schparser;
+	QString buffer;
+	attribs_map attribs;
+
+	buffer = "%set {ver} 10.0\n";
+	buffer += "\n%if ({ver} <=f \"9.3\") %then";
+	buffer += "\n %set {variable1} [don't ]";
+	buffer += "\n %set {variable2} [extract]";
+	buffer += "\n%else";
+	buffer += "\n %set {variable3} [extract ]";
+	buffer += "\n %set {variable4} [in else]";
+	buffer +=	"\n{variable3}{variable4}";
+	buffer += "\n%end";
+
+	try
+	{
+		schparser.loadBuffer(buffer);
+		QCOMPARE(schparser.getCodeDefinition(attribs) == "extract in else", true);
+	}
+	catch(Exception &e)
+	{
+		QFAIL(e.getExceptionsText().toStdString().c_str());
+	}
+}
+
 QTEST_MAIN(SchemaParserTest)
 #include "schemaparsertest.moc"
